John Smith - Messages

# John Smith

John Smith, Foo Bar
John SmithMonday, 17 September 2012 at 17:00 EDT

Hello!

John SmithMonday, 17 September 2012 at 17:01 EDT

How are you?

Foo BarMonday, 17 September 2012 at 17:06 EDT

Hey, sorry for being late

Foo BarMonday, 17 September 2012 at 17:06 EDT

I'm fine

Foo BarMonday, 17 September 2012 at 17:07 EDT

How about you?

John SmithMonday, 17 September 2012 at 17:08 EDT

I'm doing great tHanks!

John Smith, Linus Torvalds
Linus TorvaldsTuesday, 18 September 2012 at 11:44 EDT

Hey John, did you check out my pull request?

John SmithTuesday, 18 September 2012 at 11:45 EDT

I sure did!

John SmithTuesday, 18 September 2012 at 11:45 EDT

I'm thinking that you could probably cHange how the counting of events happens

Linus TorvaldsTuesday, 18 September 2012 at 11:46 EDT

I agree, I wasn't too sure on how to Handle it. If I just use ++ would that work fine?

John SmithTuesday, 18 September 2012 at 11:47 EDT

Kiss It Simple Stupid!

John Smith, Foo Bar
Foo BarFriday, December 25, 2015 at 11:23am EST

Sorry, didn't reply, I was busy.

John SmithFriday, December 25, 2015 at 11:32am EST

It's okay, I've been too

Foo BarFriday, December 25, 2015 at 11:40am EST

Alright, well good-bye!

John SmithFriday, December 25, 2015 at 11:40am EST

Ciao!

John Smith, Foo Bar, Bobby Notalastname
Foo BarWednesday, 19 September 2012 at 14:00 EDT

Known test message #1.

John SmithWednesday, 19 September 2012 at 14:00 EDT

Known test message #2.

John Smith, Foo Bar
Foo BarWednesday, 19 September 2012 at 14:14 EDT

Project Gutenberg's Alice's Adventures in Wonderland, by Lewis Carroll This eBook is for the use of anyone anywhere at no cost and with almost no restrictions whatsoever. You may copy it, give it away or re-use it under the terms of the Project Gutenberg License included with this eBook or online at www.gutenberg.org Title: Alice's Adventures in Wonderland Author: Lewis Carroll Posting Date: June 25, 2008 [EBook #11] Release Date: March, 1994 [Last updated: December 20, 2011] Language: English *** START OF THIS PROJECT GUTENBERG EBOOK ALICE'S ADVENTURES IN WONDERLAND *** ALICE'S ADVENTURES IN WONDERLAND Lewis Carroll THE MILLENNIUM FULCRUM EDITION 3.0 CHAPTER I. Down the Rabbit-Hole Alice was beginning to get very tired of sitting by her sister on the bank, and of having nothing to do: once or twice she had peeped into the book her sister was reading, but it had no pictures or conversations in it, 'and what is the use of a book,' thought Alice 'without pictures or conversation?' So she was considering in her own mind (as well as she could, for the hot day made her feel very sleepy and stupid), whether the pleasure of making a daisy-chain would be worth the trouble of getting up and picking the daisies, when suddenly a White Rabbit with pink eyes ran close by her. There was nothing so VERY remarkable in that; nor did Alice think it so VERY much out of the way to hear the Rabbit say to itself, 'Oh dear! Oh dear! I shall be late!' (when she thought it over afterwards, it occurred to her that she ought to have wondered at this, but at the time it all seemed quite natural); but when the Rabbit actually TOOK A WATCH OUT OF ITS WAISTCOAT-POCKET, and looked at it, and then hurried on, Alice started to her feet, for it flashed across her mind that she had never before seen a rabbit with either a waistcoat-pocket, or a watch to take out of it, and burning with curiosity, she ran across the field after it, and fortunately was just in time to see it pop down a large rabbit-hole under the hedge. In another moment down went Alice after it, never once considering how in the world she was to get out again. The rabbit-hole went straight on like a tunnel for some way, and then dipped suddenly down, so suddenly that Alice had not a moment to think about stopping herself before she found herself falling down a very deep well. Either the well was very deep, or she fell very slowly, for she had plenty of time as she went down to look about her and to wonder what was going to happen next. First, she tried to look down and make out what she was coming to, but it was too dark to see anything; then she looked at the sides of the well, and noticed that they were filled with cupboards and book-shelves; here and there she saw maps and pictures hung upon pegs. She took down a jar from one of the shelves as she passed; it was labelled 'ORANGE MARMALADE', but to her great disappointment it was empty: she did not like to drop the jar for fear of killing somebody, so managed to put it into one of the cupboards as she fell past it. 'Well!' thought Alice to herself, 'after such a fall as this, I shall think nothing of tumbling down stairs! How brave they'll all think me at home! Why, I wouldn't say anything about it, even if I fell off the top of the house!' (Which was very likely true.) Down, down, down. Would the fall NEVER come to an end! 'I wonder how many miles I've fallen by this time?' she said aloud. 'I must be getting somewhere near the centre of the earth. Let me see: that would be four thousand miles down, I think--' (for, you see, Alice had learnt several things of this sort in her lessons in the schoolroom, and though this was not a VERY good opportunity for showing off her knowledge, as there was no one to listen to her, still it was good practice to say it over) '--yes, that's about the right distance--but then I wonder what Latitude or Longitude I've got to?' (Alice had no idea what Latitude was, or Longitude either, but thought they were nice grand words to say.) Presently she began again. 'I wonder if I shall fall right THROUGH the earth! How funny it'll seem to come out among the people that walk with their heads downward! The Antipathies, I think--' (she was rather glad there WAS no one listening, this time, as it didn't sound at all the right word) '--but I shall have to ask them what the name of the country is, you know. Please, Ma'am, is this New Zealand or Australia?' (and she tried to curtsey as she spoke--fancy CURTSEYING as you're falling through the air! Do you think you could manage it?) 'And what an ignorant little girl she'll think me for asking! No, it'll never do to ask: perhaps I shall see it written up somewhere.' Down, down, down. There was nothing else to do, so Alice soon began talking again. 'Dinah'll miss me very much to-night, I should think!' (Dinah was the cat.) 'I hope they'll remember her saucer of milk at tea-time. Dinah my dear! I wish you were down here with me! There are no mice in the air, I'm afraid, but you might catch a bat, and that's very like a mouse, you know. But do cats eat bats, I wonder?' And here Alice began to get rather sleepy, and went on saying to herself, in a dreamy sort of way, 'Do cats eat bats? Do cats eat bats?' and sometimes, 'Do bats eat cats?' for, you see, as she couldn't answer either question, it didn't much matter which way she put it. She felt that she was dozing off, and had just begun to dream that she was walking hand in hand with Dinah, and saying to her very earnestly, 'Now, Dinah, tell me the truth: did you ever eat a bat?' when suddenly, thump! thump! down she came upon a heap of sticks and dry leaves, and the fall was over. Alice was not a bit hurt, and she jumped up on to her feet in a moment: she looked up, but it was all dark overhead; before her was another long passage, and the White Rabbit was still in sight, hurrying down it. There was not a moment to be lost: away went Alice like the wind, and was just in time to hear it say, as it turned a corner, 'Oh my ears and whiskers, how late it's getting!' She was close behind it when she turned the corner, but the Rabbit was no longer to be seen: she found herself in a long, low hall, which was lit up by a row of lamps hanging from the roof. There were doors all round the hall, but they were all locked; and when Alice had been all the way down one side and up the other, trying every door, she walked sadly down the middle, wondering how she was ever to get out again. Suddenly she came upon a little three-legged table, all made of solid glass; there was nothing on it except a tiny golden key, and Alice's first thought was that it might belong to one of the doors of the hall; but, alas! either the locks were too large, or the key was too small, but at any rate it would not open any of them. However, on the second time round, she came upon a low curtain she had not noticed before, and behind it was a little door about fifteen inches high: she tried the little golden key in the lock, and to her great delight it fitted! Alice opened the door and found that it led into a small passage, not much larger than a rat-hole: she knelt down and looked along the passage into the loveliest garden you ever saw. How she longed to get out of that dark hall, and wander about among those beds of bright flowers and those cool fountains, but she could not even get her head through the doorway; 'and even if my head would go through,' thought poor Alice, 'it would be of very little use without my shoulders. Oh, how I wish I could shut up like a telescope! I think I could, if I only know how to begin.' For, you see, so many out-of-the-way things had happened lately, that Alice had begun to think that very few things indeed were really impossible. There seemed to be no use in waiting by the little door, so she went back to the table, half hoping she might find another key on it, or at any rate a book of rules for shutting people up like telescopes: this time she found a little bottle on it, ('which certainly was not here before,' said Alice,) and round the neck of the bottle was a paper label, with the words 'DRINK ME' beautifully printed on it in large letters. It was all very well to say 'Drink me,' but the wise little Alice was not going to do THAT in a hurry. 'No, I'll look first,' she said, 'and see whether it's marked "poison" or not'; for she had read several nice little histories about children who had got burnt, and eaten up by wild beasts and other unpleasant things, all because they WOULD not remember the simple rules their friends had taught them: such as, that a red-hot poker will burn you if you hold it too long; and that if you cut your finger VERY deeply with a knife, it usually bleeds; and she had never forgotten that, if you drink much from a bottle marked 'poison,' it is almost certain to disagree with you, sooner or later. However, this bottle was NOT marked 'poison,' so Alice ventured to taste it, and finding it very nice, (it had, in fact, a sort of mixed flavour of cherry-tart, custard, pine-apple, roast turkey, toffee, and hot buttered toast,) she very soon finished it off. * * * * * * * * * * * * * * * * * * * * 'What a curious feeling!' said Alice; 'I must be shutting up like a telescope.' And so it was indeed: she was now only ten inches high, and her face brightened up at the thought that she was now the right size for going through the little door into that lovely garden. First, however, she waited for a few minutes to see if she was going to shrink any further: she felt a little nervous about this; 'for it might end, you know,' said Alice to herself, 'in my going out altogether, like a candle. I wonder what I should be like then?' And she tried to fancy what the flame of a candle is like after the candle is blown out, for she could not remember ever having seen such a thing. After a while, finding that nothing more happened, she decided on going into the garden at once; but, alas for poor Alice! when she got to the door, she found she had forgotten the little golden key, and when she went back to the table for it, she found she could not possibly reach it: she could see it quite plainly through the glass, and she tried her best to climb up one of the legs of the table, but it was too slippery; and when she had tired herself out with trying, the poor little thing sat down and cried. 'Come, there's no use in crying like that!' said Alice to herself, rather sharply; 'I advise you to leave off this minute!' She generally gave herself very good advice, (though she very seldom followed it), and sometimes she scolded herself so severely as to bring tears into her eyes; and once she remembered trying to box her own ears for having cheated herself in a game of croquet she was playing against herself, for this curious child was very fond of pretending to be two people. 'But it's no use now,' thought poor Alice, 'to pretend to be two people! Why, there's hardly enough of me left to make ONE respectable person!' Soon her eye fell on a little glass box that was lying under the table: she opened it, and found in it a very small cake, on which the words 'EAT ME' were beautifully marked in currants. 'Well, I'll eat it,' said Alice, 'and if it makes me grow larger, I can reach the key; and if it makes me grow smaller, I can creep under the door; so either way I'll get into the garden, and I don't care which happens!' She ate a little bit, and said anxiously to herself, 'Which way? Which way?', holding her hand on the top of her head to feel which way it was growing, and she was quite surprised to find that she remained the same size: to be sure, this generally happens when one eats cake, but Alice had got so much into the way of expecting nothing but out-of-the-way things to happen, that it seemed quite dull and stupid for life to go on in the common way. So she set to work, and very soon finished off the cake. * * * * * * * * * * * * * * * * * * * * CHAPTER II. The Pool of Tears 'Curiouser and curiouser!' cried Alice (she was so much surprised, that for the moment she quite forgot how to speak good English); 'now I'm opening out like the largest telescope that ever was! Good-bye, feet!' (for when she looked down at her feet, they seemed to be almost out of sight, they were getting so far off). 'Oh, my poor little feet, I wonder who will put on your shoes and stockings for you now, dears? I'm sure _I_ shan't be able! I shall be a great deal too far off to trouble myself about you: you must manage the best way you can;--but I must be kind to them,' thought Alice, 'or perhaps they won't walk the way I want to go! Let me see: I'll give them a new pair of boots every Christmas.' And she went on planning to herself how she would manage it. 'They must go by the carrier,' she thought; 'and how funny it'll seem, sending presents to one's own feet! And how odd the directions will look! ALICE'S RIGHT FOOT, ESQ. HEARTHRUG, NEAR THE FENDER, (WITH ALICE'S LOVE). Oh dear, what nonsense I'm talking!' Just then her head struck against the roof of the hall: in fact she was now more than nine feet high, and she at once took up the little golden key and hurried off to the garden door. Poor Alice! It was as much as she could do, lying down on one side, to look through into the garden with one eye; but to get through was more hopeless than ever: she sat down and began to cry again. 'You ought to be ashamed of yourself,' said Alice, 'a great girl like you,' (she might well say this), 'to go on crying in this way! Stop this moment, I tell you!' But she went on all the same, shedding gallons of tears, until there was a large pool all round her, about four inches deep and reaching half down the hall. After a time she heard a little pattering of feet in the distance, and she hastily dried her eyes to see what was coming. It was the White Rabbit returning, splendidly dressed, with a pair of white kid gloves in one hand and a large fan in the other: he came trotting along in a great hurry, muttering to himself as he came, 'Oh! the Duchess, the Duchess! Oh! won't she be savage if I've kept her waiting!' Alice felt so desperate that she was ready to ask help of any one; so, when the Rabbit came near her, she began, in a low, timid voice, 'If you please, sir--' The Rabbit started violently, dropped the white kid gloves and the fan, and skurried away into the darkness as hard as he could go. Alice took up the fan and gloves, and, as the hall was very hot, she kept fanning herself all the time she went on talking: 'Dear, dear! How queer everything is to-day! And yesterday things went on just as usual. I wonder if I've been changed in the night? Let me think: was I the same when I got up this morning? I almost think I can remember feeling a little different. But if I'm not the same, the next question is, Who in the world am I? Ah, THAT'S the great puzzle!' And she began thinking over all the children she knew that were of the same age as herself, to see if she could have been changed for any of them. 'I'm sure I'm not Ada,' she said, 'for her hair goes in such long ringlets, and mine doesn't go in ringlets at all; and I'm sure I can't be Mabel, for I know all sorts of things, and she, oh! she knows such a very little! Besides, SHE'S she, and I'm I, and--oh dear, how puzzling it all is! I'll try if I know all the things I used to know. Let me see: four times five is twelve, and four times six is thirteen, and four times seven is--oh dear! I shall never get to twenty at that rate! However, the Multiplication Table doesn't signify: let's try Geography. London is the capital of Paris, and Paris is the capital of Rome, and Rome--no, THAT'S all wrong, I'm certain! I must have been changed for Mabel! I'll try and say "How doth the little--"' and she crossed her hands on her lap as if she were saying lessons, and began to repeat it, but her voice sounded hoarse and strange, and the words did not come the same as they used to do:-- 'How doth the little crocodile Improve his shining tail, And pour the waters of the Nile On every golden scale! 'How cheerfully he seems to grin, How neatly spread his claws, And welcome little fishes in With gently smiling jaws!' 'I'm sure those are not the right words,' said poor Alice, and her eyes filled with tears again as she went on, 'I must be Mabel after all, and I shall have to go and live in that poky little house, and have next to no toys to play with, and oh! ever so many lessons to learn! No, I've made up my mind about it; if I'm Mabel, I'll stay down here! It'll be no use their putting their heads down and saying "Come up again, dear!" I shall only look up and say "Who am I then? Tell me that first, and then, if I like being that person, I'll come up: if not, I'll stay down here till I'm somebody else"--but, oh dear!' cried Alice, with a sudden burst of tears, 'I do wish they WOULD put their heads down! I am so VERY tired of being all alone here!' As she said this she looked down at her hands, and was surprised to see that she had put on one of the Rabbit's little white kid gloves while she was talking. 'How CAN I have done that?' she thought. 'I must be growing small again.' She got up and went to the table to measure herself by it, and found that, as nearly as she could guess, she was now about two feet high, and was going on shrinking rapidly: she soon found out that the cause of this was the fan she was holding, and she dropped it hastily, just in time to avoid shrinking away altogether. 'That WAS a narrow escape!' said Alice, a good deal frightened at the sudden change, but very glad to find herself still in existence; 'and now for the garden!' and she ran with all speed back to the little door: but, alas! the little door was shut again, and the little golden key was lying on the glass table as before, 'and things are worse than ever,' thought the poor child, 'for I never was so small as this before, never! And I declare it's too bad, that it is!' As she said these words her foot slipped, and in another moment, splash! she was up to her chin in salt water. Her first idea was that she had somehow fallen into the sea, 'and in that case I can go back by railway,' she said to herself. (Alice had been to the seaside once in her life, and had come to the general conclusion, that wherever you go to on the English coast you find a number of bathing machines in the sea, some children digging in the sand with wooden spades, then a row of lodging houses, and behind them a railway station.) However, she soon made out that she was in the pool of tears which she had wept when she was nine feet high. 'I wish I hadn't cried so much!' said Alice, as she swam about, trying to find her way out. 'I shall be punished for it now, I suppose, by being drowned in my own tears! That WILL be a queer thing, to be sure! However, everything is queer to-day.' Just then she heard something splashing about in the pool a little way off, and she swam nearer to make out what it was: at first she thought it must be a walrus or hippopotamus, but then she remembered how small she was now, and she soon made out that it was only a mouse that had slipped in like herself. 'Would it be of any use, now,' thought Alice, 'to speak to this mouse? Everything is so out-of-the-way down here, that I should think very likely it can talk: at any rate, there's no harm in trying.' So she began: 'O Mouse, do you know the way out of this pool? I am very tired of swimming about here, O Mouse!' (Alice thought this must be the right way of speaking to a mouse: she had never done such a thing before, but she remembered having seen in her brother's Latin Grammar, 'A mouse--of a mouse--to a mouse--a mouse--O mouse!') The Mouse looked at her rather inquisitively, and seemed to her to wink with one of its little eyes, but it said nothing. 'Perhaps it doesn't understand English,' thought Alice; 'I daresay it's a French mouse, come over with William the Conqueror.' (For, with all her knowledge of history, Alice had no very clear notion how long ago anything had happened.) So she began again: 'Ou est ma chatte?' which was the first sentence in her French lesson-book. The Mouse gave a sudden leap out of the water, and seemed to quiver all over with fright. 'Oh, I beg your pardon!' cried Alice hastily, afraid that she had hurt the poor animal's feelings. 'I quite forgot you didn't like cats.' 'Not like cats!' cried the Mouse, in a shrill, passionate voice. 'Would YOU like cats if you were me?' 'Well, perhaps not,' said Alice in a soothing tone: 'don't be angry about it. And yet I wish I could show you our cat Dinah: I think you'd take a fancy to cats if you could only see her. She is such a dear quiet thing,' Alice went on, half to herself, as she swam lazily about in the pool, 'and she sits purring so nicely by the fire, licking her paws and washing her face--and she is such a nice soft thing to nurse--and she's such a capital one for catching mice--oh, I beg your pardon!' cried Alice again, for this time the Mouse was bristling all over, and she felt certain it must be really offended. 'We won't talk about her any more if you'd rather not.' 'We indeed!' cried the Mouse, who was trembling down to the end of his tail. 'As if I would talk on such a subject! Our family always HATED cats: nasty, low, vulgar things! Don't let me hear the name again!' 'I won't indeed!' said Alice, in a great hurry to change the subject of conversation. 'Are you--are you fond--of--of dogs?' The Mouse did not answer, so Alice went on eagerly: 'There is such a nice little dog near our house I should like to show you! A little bright-eyed terrier, you know, with oh, such long curly brown hair! And it'll fetch things when you throw them, and it'll sit up and beg for its dinner, and all sorts of things--I can't remember half of them--and it belongs to a farmer, you know, and he says it's so useful, it's worth a hundred pounds! He says it kills all the rats and--oh dear!' cried Alice in a sorrowful tone, 'I'm afraid I've offended it again!' For the Mouse was swimming away from her as hard as it could go, and making quite a commotion in the pool as it went. So she called softly after it, 'Mouse dear! Do come back again, and we won't talk about cats or dogs either, if you don't like them!' When the Mouse heard this, it turned round and swam slowly back to her: its face was quite pale (with passion, Alice thought), and it said in a low trembling voice, 'Let us get to the shore, and then I'll tell you my history, and you'll understand why it is I hate cats and dogs.' It was high time to go, for the pool was getting quite crowded with the birds and animals that had fallen into it: there were a Duck and a Dodo, a Lory and an Eaglet, and several other curious creatures. Alice led the way, and the whole party swam to the shore. CHAPTER III. A Caucus-Race and a Long Tale They were indeed a queer-looking party that assembled on the bank--the birds with draggled feathers, the animals with their fur clinging close to them, and all dripping wet, cross, and uncomfortable. The first question of course was, how to get dry again: they had a consultation about this, and after a few minutes it seemed quite natural to Alice to find herself talking familiarly with them, as if she had known them all her life. Indeed, she had quite a long argument with the Lory, who at last turned sulky, and would only say, 'I am older than you, and must know better'; and this Alice would not allow without knowing how old it was, and, as the Lory positively refused to tell its age, there was no more to be said. At last the Mouse, who seemed to be a person of authority among them, called out, 'Sit down, all of you, and listen to me! I'LL soon make you dry enough!' They all sat down at once, in a large ring, with the Mouse in the middle. Alice kept her eyes anxiously fixed on it, for she felt sure she would catch a bad cold if she did not get dry very soon. 'Ahem!' said the Mouse with an important air, 'are you all ready? This is the driest thing I know. Silence all round, if you please! "William the Conqueror, whose cause was favoured by the pope, was soon submitted to by the English, who wanted leaders, and had been of late much accustomed to usurpation and conquest. Edwin and Morcar, the earls of Mercia and Northumbria--"' 'Ugh!' said the Lory, with a shiver. 'I beg your pardon!' said the Mouse, frowning, but very politely: 'Did you speak?' 'Not I!' said the Lory hastily. 'I thought you did,' said the Mouse. '--I proceed. "Edwin and Morcar, the earls of Mercia and Northumbria, declared for him: and even Stigand, the patriotic archbishop of Canterbury, found it advisable--"' 'Found WHAT?' said the Duck. 'Found IT,' the Mouse replied rather crossly: 'of course you know what "it" means.' 'I know what "it" means well enough, when I find a thing,' said the Duck: 'it's generally a frog or a worm. The question is, what did the archbishop find?' The Mouse did not notice this question, but hurriedly went on, '"--found it advisable to go with Edgar Atheling to meet William and offer him the crown. William's conduct at first was moderate. But the insolence of his Normans--" How are you getting on now, my dear?' it continued, turning to Alice as it spoke. 'As wet as ever,' said Alice in a melancholy tone: 'it doesn't seem to dry me at all.' 'In that case,' said the Dodo solemnly, rising to its feet, 'I move that the meeting adjourn, for the immediate adoption of more energetic remedies--' 'Speak English!' said the Eaglet. 'I don't know the meaning of half those long words, and, what's more, I don't believe you do either!' And the Eaglet bent down its head to hide a smile: some of the other birds tittered audibly. 'What I was going to say,' said the Dodo in an offended tone, 'was, that the best thing to get us dry would be a Caucus-race.' 'What IS a Caucus-race?' said Alice; not that she wanted much to know, but the Dodo had paused as if it thought that SOMEBODY ought to speak, and no one else seemed inclined to say anything. 'Why,' said the Dodo, 'the best way to explain it is to do it.' (And, as you might like to try the thing yourself, some winter day, I will tell you how the Dodo managed it.) First it marked out a race-course, in a sort of circle, ('the exact shape doesn't matter,' it said,) and then all the party were placed along the course, here and there. There was no 'One, two, three, and away,' but they began running when they liked, and left off when they liked, so that it was not easy to know when the race was over. However, when they had been running half an hour or so, and were quite dry again, the Dodo suddenly called out 'The race is over!' and they all crowded round it, panting, and asking, 'But who has won?' This question the Dodo could not answer without a great deal of thought, and it sat for a long time with one finger pressed upon its forehead (the position in which you usually see Shakespeare, in the pictures of him), while the rest waited in silence. At last the Dodo said, 'EVERYBODY has won, and all must have prizes.' 'But who is to give the prizes?' quite a chorus of voices asked. 'Why, SHE, of course,' said the Dodo, pointing to Alice with one finger; and the whole party at once crowded round her, calling out in a confused way, 'Prizes! Prizes!' Alice had no idea what to do, and in despair she put her hand in her pocket, and pulled out a box of comfits, (luckily the salt water had not got into it), and handed them round as prizes. There was exactly one a-piece all round. 'But she must have a prize herself, you know,' said the Mouse. 'Of course,' the Dodo replied very gravely. 'What else have you got in your pocket?' he went on, turning to Alice. 'Only a thimble,' said Alice sadly. 'Hand it over here,' said the Dodo. Then they all crowded round her once more, while the Dodo solemnly presented the thimble, saying 'We beg your acceptance of this elegant thimble'; and, when it had finished this short speech, they all cheered. Alice thought the whole thing very absurd, but they all looked so grave that she did not dare to laugh; and, as she could not think of anything to say, she simply bowed, and took the thimble, looking as solemn as she could. The next thing was to eat the comfits: this caused some noise and confusion, as the large birds complained that they could not taste theirs, and the small ones choked and had to be patted on the back. However, it was over at last, and they sat down again in a ring, and begged the Mouse to tell them something more. 'You promised to tell me your history, you know,' said Alice, 'and why it is you hate--C and D,' she added in a whisper, half afraid that it would be offended again. 'Mine is a long and a sad tale!' said the Mouse, turning to Alice, and sighing. 'It IS a long tail, certainly,' said Alice, looking down with wonder at the Mouse's tail; 'but why do you call it sad?' And she kept on puzzling about it while the Mouse was speaking, so that her idea of the tale was something like this:-- 'Fury said to a mouse, That he met in the house, "Let us both go to law: I will prosecute YOU.--Come, I'll take no denial; We must have a trial: For really this morning I've nothing to do." Said the mouse to the cur, "Such a trial, dear Sir, With no jury or judge, would be wasting our breath." "I'll be judge, I'll be jury," Said cunning old Fury: "I'll try the whole cause, and condemn you to death."' 'You are not attending!' said the Mouse to Alice severely. 'What are you thinking of?' 'I beg your pardon,' said Alice very humbly: 'you had got to the fifth bend, I think?' 'I had NOT!' cried the Mouse, sharply and very angrily. 'A knot!' said Alice, always ready to make herself useful, and looking anxiously about her. 'Oh, do let me help to undo it!' 'I shall do nothing of the sort,' said the Mouse, getting up and walking away. 'You insult me by talking such nonsense!' 'I didn't mean it!' pleaded poor Alice. 'But you're so easily offended, you know!' The Mouse only growled in reply. 'Please come back and finish your story!' Alice called after it; and the others all joined in chorus, 'Yes, please do!' but the Mouse only shook its head impatiently, and walked a little quicker. 'What a pity it wouldn't stay!' sighed the Lory, as soon as it was quite out of sight; and an old Crab took the opportunity of saying to her daughter 'Ah, my dear! Let this be a lesson to you never to lose YOUR temper!' 'Hold your tongue, Ma!' said the young Crab, a little snappishly. 'You're enough to try the patience of an oyster!' 'I wish I had our Dinah here, I know I do!' said Alice aloud, addressing nobody in particular. 'She'd soon fetch it back!' 'And who is Dinah, if I might venture to ask the question?' said the Lory. Alice replied eagerly, for she was always ready to talk about her pet: 'Dinah's our cat. And she's such a capital one for catching mice you can't think! And oh, I wish you could see her after the birds! Why, she'll eat a little bird as soon as look at it!' This speech caused a remarkable sensation among the party. Some of the birds hurried off at once: one old Magpie began wrapping itself up very carefully, remarking, 'I really must be getting home; the night-air doesn't suit my throat!' and a Canary called out in a trembling voice to its children, 'Come away, my dears! It's high time you were all in bed!' On various pretexts they all moved off, and Alice was soon left alone. 'I wish I hadn't mentioned Dinah!' she said to herself in a melancholy tone. 'Nobody seems to like her, down here, and I'm sure she's the best cat in the world! Oh, my dear Dinah! I wonder if I shall ever see you any more!' And here poor Alice began to cry again, for she felt very lonely and low-spirited. In a little while, however, she again heard a little pattering of footsteps in the distance, and she looked up eagerly, half hoping that the Mouse had changed his mind, and was coming back to finish his story. CHAPTER IV. The Rabbit Sends in a Little Bill It was the White Rabbit, trotting slowly back again, and looking anxiously about as it went, as if it had lost something; and she heard it muttering to itself 'The Duchess! The Duchess! Oh my dear paws! Oh my fur and whiskers! She'll get me executed, as sure as ferrets are ferrets! Where CAN I have dropped them, I wonder?' Alice guessed in a moment that it was looking for the fan and the pair of white kid gloves, and she very good-naturedly began hunting about for them, but they were nowhere to be seen--everything seemed to have changed since her swim in the pool, and the great hall, with the glass table and the little door, had vanished completely. Very soon the Rabbit noticed Alice, as she went hunting about, and called out to her in an angry tone, 'Why, Mary Ann, what ARE you doing out here? Run home this moment, and fetch me a pair of gloves and a fan! Quick, now!' And Alice was so much frightened that she ran off at once in the direction it pointed to, without trying to explain the mistake it had made. 'He took me for his housemaid,' she said to herself as she ran. 'How surprised he'll be when he finds out who I am! But I'd better take him his fan and gloves--that is, if I can find them.' As she said this, she came upon a neat little house, on the door of which was a bright brass plate with the name 'W. RABBIT' engraved upon it. She went in without knocking, and hurried upstairs, in great fear lest she should meet the real Mary Ann, and be turned out of the house before she had found the fan and gloves. 'How queer it seems,' Alice said to herself, 'to be going messages for a rabbit! I suppose Dinah'll be sending me on messages next!' And she began fancying the sort of thing that would happen: '"Miss Alice! Come here directly, and get ready for your walk!" "Coming in a minute, nurse! But I've got to see that the mouse doesn't get out." Only I don't think,' Alice went on, 'that they'd let Dinah stop in the house if it began ordering people about like that!' By this time she had found her way into a tidy little room with a table in the window, and on it (as she had hoped) a fan and two or three pairs of tiny white kid gloves: she took up the fan and a pair of the gloves, and was just going to leave the room, when her eye fell upon a little bottle that stood near the looking-glass. There was no label this time with the words 'DRINK ME,' but nevertheless she uncorked it and put it to her lips. 'I know SOMETHING interesting is sure to happen,' she said to herself, 'whenever I eat or drink anything; so I'll just see what this bottle does. I do hope it'll make me grow large again, for really I'm quite tired of being such a tiny little thing!' It did so indeed, and much sooner than she had expected: before she had drunk half the bottle, she found her head pressing against the ceiling, and had to stoop to save her neck from being broken. She hastily put down the bottle, saying to herself 'That's quite enough--I hope I shan't grow any more--As it is, I can't get out at the door--I do wish I hadn't drunk quite so much!' Alas! it was too late to wish that! She went on growing, and growing, and very soon had to kneel down on the floor: in another minute there was not even room for this, and she tried the effect of lying down with one elbow against the door, and the other arm curled round her head. Still she went on growing, and, as a last resource, she put one arm out of the window, and one foot up the chimney, and said to herself 'Now I can do no more, whatever happens. What WILL become of me?' Luckily for Alice, the little magic bottle had now had its full effect, and she grew no larger: still it was very uncomfortable, and, as there seemed to be no sort of chance of her ever getting out of the room again, no wonder she felt unhappy. 'It was much pleasanter at home,' thought poor Alice, 'when one wasn't always growing larger and smaller, and being ordered about by mice and rabbits. I almost wish I hadn't gone down that rabbit-hole--and yet--and yet--it's rather curious, you know, this sort of life! I do wonder what CAN have happened to me! When I used to read fairy-tales, I fancied that kind of thing never happened, and now here I am in the middle of one! There ought to be a book written about me, that there ought! And when I grow up, I'll write one--but I'm grown up now,' she added in a sorrowful tone; 'at least there's no room to grow up any more HERE.' 'But then,' thought Alice, 'shall I NEVER get any older than I am now? That'll be a comfort, one way--never to be an old woman--but then--always to have lessons to learn! Oh, I shouldn't like THAT!' 'Oh, you foolish Alice!' she answered herself. 'How can you learn lessons in here? Why, there's hardly room for YOU, and no room at all for any lesson-books!' And so she went on, taking first one side and then the other, and making quite a conversation of it altogether; but after a few minutes she heard a voice outside, and stopped to listen. 'Mary Ann! Mary Ann!' said the voice. 'Fetch me my gloves this moment!' Then came a little pattering of feet on the stairs. Alice knew it was the Rabbit coming to look for her, and she trembled till she shook the house, quite forgetting that she was now about a thousand times as large as the Rabbit, and had no reason to be afraid of it. Presently the Rabbit came up to the door, and tried to open it; but, as the door opened inwards, and Alice's elbow was pressed hard against it, that attempt proved a failure. Alice heard it say to itself 'Then I'll go round and get in at the window.' 'THAT you won't' thought Alice, and, after waiting till she fancied she heard the Rabbit just under the window, she suddenly spread out her hand, and made a snatch in the air. She did not get hold of anything, but she heard a little shriek and a fall, and a crash of broken glass, from which she concluded that it was just possible it had fallen into a cucumber-frame, or something of the sort. Next came an angry voice--the Rabbit's--'Pat! Pat! Where are you?' And then a voice she had never heard before, 'Sure then I'm here! Digging for apples, yer honour!' 'Digging for apples, indeed!' said the Rabbit angrily. 'Here! Come and help me out of THIS!' (Sounds of more broken glass.) 'Now tell me, Pat, what's that in the window?' 'Sure, it's an arm, yer honour!' (He pronounced it 'arrum.') 'An arm, you goose! Who ever saw one that size? Why, it fills the whole window!' 'Sure, it does, yer honour: but it's an arm for all that.' 'Well, it's got no business there, at any rate: go and take it away!' There was a long silence after this, and Alice could only hear whispers now and then; such as, 'Sure, I don't like it, yer honour, at all, at all!' 'Do as I tell you, you coward!' and at last she spread out her hand again, and made another snatch in the air. This time there were TWO little shrieks, and more sounds of broken glass. 'What a number of cucumber-frames there must be!' thought Alice. 'I wonder what they'll do next! As for pulling me out of the window, I only wish they COULD! I'm sure I don't want to stay in here any longer!' She waited for some time without hearing anything more: at last came a rumbling of little cartwheels, and the sound of a good many voices all talking together: she made out the words: 'Where's the other ladder?--Why, I hadn't to bring but one; Bill's got the other--Bill! fetch it here, lad!--Here, put 'em up at this corner--No, tie 'em together first--they don't reach half high enough yet--Oh! they'll do well enough; don't be particular--Here, Bill! catch hold of this rope--Will the roof bear?--Mind that loose slate--Oh, it's coming down! Heads below!' (a loud crash)--'Now, who did that?--It was Bill, I fancy--Who's to go down the chimney?--Nay, I shan't! YOU do it!--That I won't, then!--Bill's to go down--Here, Bill! the master says you're to go down the chimney!' 'Oh! So Bill's got to come down the chimney, has he?' said Alice to herself. 'Shy, they seem to put everything upon Bill! I wouldn't be in Bill's place for a good deal: this fireplace is narrow, to be sure; but I THINK I can kick a little!' She drew her foot as far down the chimney as she could, and waited till she heard a little animal (she couldn't guess of what sort it was) scratching and scrambling about in the chimney close above her: then, saying to herself 'This is Bill,' she gave one sharp kick, and waited to see what would happen next. The first thing she heard was a general chorus of 'There goes Bill!' then the Rabbit's voice along--'Catch him, you by the hedge!' then silence, and then another confusion of voices--'Hold up his head--Brandy now--Don't choke him--How was it, old fellow? What happened to you? Tell us all about it!' Last came a little feeble, squeaking voice, ('That's Bill,' thought Alice,) 'Well, I hardly know--No more, thank ye; I'm better now--but I'm a deal too flustered to tell you--all I know is, something comes at me like a Jack-in-the-box, and up I goes like a sky-rocket!' 'So you did, old fellow!' said the others. 'We must burn the house down!' said the Rabbit's voice; and Alice called out as loud as she could, 'If you do. I'll set Dinah at you!' There was a dead silence instantly, and Alice thought to herself, 'I wonder what they WILL do next! If they had any sense, they'd take the roof off.' After a minute or two, they began moving about again, and Alice heard the Rabbit say, 'A barrowful will do, to begin with.' 'A barrowful of WHAT?' thought Alice; but she had not long to doubt, for the next moment a shower of little pebbles came rattling in at the window, and some of them hit her in the face. 'I'll put a stop to this,' she said to herself, and shouted out, 'You'd better not do that again!' which produced another dead silence. Alice noticed with some surprise that the pebbles were all turning into little cakes as they lay on the floor, and a bright idea came into her head. 'If I eat one of these cakes,' she thought, 'it's sure to make SOME change in my size; and as it can't possibly make me larger, it must make me smaller, I suppose.' So she swallowed one of the cakes, and was delighted to find that she began shrinking directly. As soon as she was small enough to get through the door, she ran out of the house, and found quite a crowd of little animals and birds waiting outside. The poor little Lizard, Bill, was in the middle, being held up by two guinea-pigs, who were giving it something out of a bottle. They all made a rush at Alice the moment she appeared; but she ran off as hard as she could, and soon found herself safe in a thick wood. 'The first thing I've got to do,' said Alice to herself, as she wandered about in the wood, 'is to grow to my right size again; and the second thing is to find my way into that lovely garden. I think that will be the best plan.' It sounded an excellent plan, no doubt, and very neatly and simply arranged; the only difficulty was, that she had not the smallest idea how to set about it; and while she was peering about anxiously among the trees, a little sharp bark just over her head made her look up in a great hurry. An enormous puppy was looking down at her with large round eyes, and feebly stretching out one paw, trying to touch her. 'Poor little thing!' said Alice, in a coaxing tone, and she tried hard to whistle to it; but she was terribly frightened all the time at the thought that it might be hungry, in which case it would be very likely to eat her up in spite of all her coaxing. Hardly knowing what she did, she picked up a little bit of stick, and held it out to the puppy; whereupon the puppy jumped into the air off all its feet at once, with a yelp of delight, and rushed at the stick, and made believe to worry it; then Alice dodged behind a great thistle, to keep herself from being run over; and the moment she appeared on the other side, the puppy made another rush at the stick, and tumbled head over heels in its hurry to get hold of it; then Alice, thinking it was very like having a game of play with a cart-horse, and expecting every moment to be trampled under its feet, ran round the thistle again; then the puppy began a series of short charges at the stick, running a very little way forwards each time and a long way back, and barking hoarsely all the while, till at last it sat down a good way off, panting, with its tongue hanging out of its mouth, and its great eyes half shut. This seemed to Alice a good opportunity for making her escape; so she set off at once, and ran till she was quite tired and out of breath, and till the puppy's bark sounded quite faint in the distance. 'And yet what a dear little puppy it was!' said Alice, as she leant against a buttercup to rest herself, and fanned herself with one of the leaves: 'I should have liked teaching it tricks very much, if--if I'd only been the right size to do it! Oh dear! I'd nearly forgotten that I've got to grow up again! Let me see--how IS it to be managed? I suppose I ought to eat or drink something or other; but the great question is, what?' The great question certainly was, what? Alice looked all round her at the flowers and the blades of grass, but she did not see anything that looked like the right thing to eat or drink under the circumstances. There was a large mushroom growing near her, about the same height as herself; and when she had looked under it, and on both sides of it, and behind it, it occurred to her that she might as well look and see what was on the top of it. She stretched herself up on tiptoe, and peeped over the edge of the mushroom, and her eyes immediately met those of a large caterpillar, that was sitting on the top with its arms folded, quietly smoking a long hookah, and taking not the smallest notice of her or of anything else. CHAPTER V. Advice from a Caterpillar The Caterpillar and Alice looked at each other for some time in silence: at last the Caterpillar took the hookah out of its mouth, and addressed her in a languid, sleepy voice. 'Who are YOU?' said the Caterpillar. This was not an encouraging opening for a conversation. Alice replied, rather shyly, 'I--I hardly know, sir, just at present--at least I know who I WAS when I got up this morning, but I think I must have been changed several times since then.' 'What do you mean by that?' said the Caterpillar sternly. 'Explain yourself!' 'I can't explain MYSELF, I'm afraid, sir' said Alice, 'because I'm not myself, you see.' 'I don't see,' said the Caterpillar. 'I'm afraid I can't put it more clearly,' Alice replied very politely, 'for I can't understand it myself to begin with; and being so many different sizes in a day is very confusing.' 'It isn't,' said the Caterpillar. 'Well, perhaps you haven't found it so yet,' said Alice; 'but when you have to turn into a chrysalis--you will some day, you know--and then after that into a butterfly, I should think you'll feel it a little queer, won't you?' 'Not a bit,' said the Caterpillar. 'Well, perhaps your feelings may be different,' said Alice; 'all I know is, it would feel very queer to ME.' 'You!' said the Caterpillar contemptuously. 'Who are YOU?' Which brought them back again to the beginning of the conversation. Alice felt a little irritated at the Caterpillar's making such VERY short remarks, and she drew herself up and said, very gravely, 'I think, you ought to tell me who YOU are, first.' 'Why?' said the Caterpillar. Here was another puzzling question; and as Alice could not think of any good reason, and as the Caterpillar seemed to be in a VERY unpleasant state of mind, she turned away. 'Come back!' the Caterpillar called after her. 'I've something important to say!' This sounded promising, certainly: Alice turned and came back again. 'Keep your temper,' said the Caterpillar. 'Is that all?' said Alice, swallowing down her anger as well as she could. 'No,' said the Caterpillar. Alice thought she might as well wait, as she had nothing else to do, and perhaps after all it might tell her something worth hearing. For some minutes it puffed away without speaking, but at last it unfolded its arms, took the hookah out of its mouth again, and said, 'So you think you're changed, do you?' 'I'm afraid I am, sir,' said Alice; 'I can't remember things as I used--and I don't keep the same size for ten minutes together!' 'Can't remember WHAT things?' said the Caterpillar. 'Well, I've tried to say "HOW DOTH THE LITTLE BUSY BEE," but it all came different!' Alice replied in a very melancholy voice. 'Repeat, "YOU ARE OLD, FATHER WILLIAM,"' said the Caterpillar. Alice folded her hands, and began:-- 'You are old, Father William,' the young man said, 'And your hair has become very white; And yet you incessantly stand on your head-- Do you think, at your age, it is right?' 'In my youth,' Father William replied to his son, 'I feared it might injure the brain; But, now that I'm perfectly sure I have none, Why, I do it again and again.' 'You are old,' said the youth, 'as I mentioned before, And have grown most uncommonly fat; Yet you turned a back-somersault in at the door-- Pray, what is the reason of that?' 'In my youth,' said the sage, as he shook his grey locks, 'I kept all my limbs very supple By the use of this ointment--one shilling the box-- Allow me to sell you a couple?' 'You are old,' said the youth, 'and your jaws are too weak For anything tougher than suet; Yet you finished the goose, with the bones and the beak-- Pray how did you manage to do it?' 'In my youth,' said his father, 'I took to the law, And argued each case with my wife; And the muscular strength, which it gave to my jaw, Has lasted the rest of my life.' 'You are old,' said the youth, 'one would hardly suppose That your eye was as steady as ever; Yet you balanced an eel on the end of your nose-- What made you so awfully clever?' 'I have answered three questions, and that is enough,' Said his father; 'don't give yourself airs! Do you think I can listen all day to such stuff? Be off, or I'll kick you down stairs!' 'That is not said right,' said the Caterpillar. 'Not QUITE right, I'm afraid,' said Alice, timidly; 'some of the words have got altered.' 'It is wrong from beginning to end,' said the Caterpillar decidedly, and there was silence for some minutes. The Caterpillar was the first to speak. 'What size do you want to be?' it asked. 'Oh, I'm not particular as to size,' Alice hastily replied; 'only one doesn't like changing so often, you know.' 'I DON'T know,' said the Caterpillar. Alice said nothing: she had never been so much contradicted in her life before, and she felt that she was losing her temper. 'Are you content now?' said the Caterpillar. 'Well, I should like to be a LITTLE larger, sir, if you wouldn't mind,' said Alice: 'three inches is such a wretched height to be.' 'It is a very good height indeed!' said the Caterpillar angrily, rearing itself upright as it spoke (it was exactly three inches high). 'But I'm not used to it!' pleaded poor Alice in a piteous tone. And she thought of herself, 'I wish the creatures wouldn't be so easily offended!' 'You'll get used to it in time,' said the Caterpillar; and it put the hookah into its mouth and began smoking again. This time Alice waited patiently until it chose to speak again. In a minute or two the Caterpillar took the hookah out of its mouth and yawned once or twice, and shook itself. Then it got down off the mushroom, and crawled away in the grass, merely remarking as it went, 'One side will make you grow taller, and the other side will make you grow shorter.' 'One side of WHAT? The other side of WHAT?' thought Alice to herself. 'Of the mushroom,' said the Caterpillar, just as if she had asked it aloud; and in another moment it was out of sight. Alice remained looking thoughtfully at the mushroom for a minute, trying to make out which were the two sides of it; and as it was perfectly round, she found this a very difficult question. However, at last she stretched her arms round it as far as they would go, and broke off a bit of the edge with each hand. 'And now which is which?' she said to herself, and nibbled a little of the right-hand bit to try the effect: the next moment she felt a violent blow underneath her chin: it had struck her foot! She was a good deal frightened by this very sudden change, but she felt that there was no time to be lost, as she was shrinking rapidly; so she set to work at once to eat some of the other bit. Her chin was pressed so closely against her foot, that there was hardly room to open her mouth; but she did it at last, and managed to swallow a morsel of the lefthand bit. * * * * * * * * * * * * * * * * * * * * 'Come, my head's free at last!' said Alice in a tone of delight, which changed into alarm in another moment, when she found that her shoulders were nowhere to be found: all she could see, when she looked down, was an immense length of neck, which seemed to rise like a stalk out of a sea of green leaves that lay far below her. 'What CAN all that green stuff be?' said Alice. 'And where HAVE my shoulders got to? And oh, my poor hands, how is it I can't see you?' She was moving them about as she spoke, but no result seemed to follow, except a little shaking among the distant green leaves. As there seemed to be no chance of getting her hands up to her head, she tried to get her head down to them, and was delighted to find that her neck would bend about easily in any direction, like a serpent. She had just succeeded in curving it down into a graceful zigzag, and was going to dive in among the leaves, which she found to be nothing but the tops of the trees under which she had been wandering, when a sharp hiss made her draw back in a hurry: a large pigeon had flown into her face, and was beating her violently with its wings. 'Serpent!' screamed the Pigeon. 'I'm NOT a serpent!' said Alice indignantly. 'Let me alone!' 'Serpent, I say again!' repeated the Pigeon, but in a more subdued tone, and added with a kind of sob, 'I've tried every way, and nothing seems to suit them!' 'I haven't the least idea what you're talking about,' said Alice. 'I've tried the roots of trees, and I've tried banks, and I've tried hedges,' the Pigeon went on, without attending to her; 'but those serpents! There's no pleasing them!' Alice was more and more puzzled, but she thought there was no use in saying anything more till the Pigeon had finished. 'As if it wasn't trouble enough hatching the eggs,' said the Pigeon; 'but I must be on the look-out for serpents night and day! Why, I haven't had a wink of sleep these three weeks!' 'I'm very sorry you've been annoyed,' said Alice, who was beginning to see its meaning. 'And just as I'd taken the highest tree in the wood,' continued the Pigeon, raising its voice to a shriek, 'and just as I was thinking I should be free of them at last, they must needs come wriggling down from the sky! Ugh, Serpent!' 'But I'm NOT a serpent, I tell you!' said Alice. 'I'm a--I'm a--' 'Well! WHAT are you?' said the Pigeon. 'I can see you're trying to invent something!' 'I--I'm a little girl,' said Alice, rather doubtfully, as she remembered the number of changes she had gone through that day. 'A likely story indeed!' said the Pigeon in a tone of the deepest contempt. 'I've seen a good many little girls in my time, but never ONE with such a neck as that! No, no! You're a serpent; and there's no use denying it. I suppose you'll be telling me next that you never tasted an egg!' 'I HAVE tasted eggs, certainly,' said Alice, who was a very truthful child; 'but little girls eat eggs quite as much as serpents do, you know.' 'I don't believe it,' said the Pigeon; 'but if they do, why then they're a kind of serpent, that's all I can say.' This was such a new idea to Alice, that she was quite silent for a minute or two, which gave the Pigeon the opportunity of adding, 'You're looking for eggs, I know THAT well enough; and what does it matter to me whether you're a little girl or a serpent?' 'It matters a good deal to ME,' said Alice hastily; 'but I'm not looking for eggs, as it happens; and if I was, I shouldn't want YOURS: I don't like them raw.' 'Well, be off, then!' said the Pigeon in a sulky tone, as it settled down again into its nest. Alice crouched down among the trees as well as she could, for her neck kept getting entangled among the branches, and every now and then she had to stop and untwist it. After a while she remembered that she still held the pieces of mushroom in her hands, and she set to work very carefully, nibbling first at one and then at the other, and growing sometimes taller and sometimes shorter, until she had succeeded in bringing herself down to her usual height. It was so long since she had been anything near the right size, that it felt quite strange at first; but she got used to it in a few minutes, and began talking to herself, as usual. 'Come, there's half my plan done now! How puzzling all these changes are! I'm never sure what I'm going to be, from one minute to another! However, I've got back to my right size: the next thing is, to get into that beautiful garden--how IS that to be done, I wonder?' As she said this, she came suddenly upon an open place, with a little house in it about four feet high. 'Whoever lives there,' thought Alice, 'it'll never do to come upon them THIS size: why, I should frighten them out of their wits!' So she began nibbling at the righthand bit again, and did not venture to go near the house till she had brought herself down to nine inches high. CHAPTER VI. Pig and Pepper For a minute or two she stood looking at the house, and wondering what to do next, when suddenly a footman in livery came running out of the wood--(she considered him to be a footman because he was in livery: otherwise, judging by his face only, she would have called him a fish)--and rapped loudly at the door with his knuckles. It was opened by another footman in livery, with a round face, and large eyes like a frog; and both footmen, Alice noticed, had powdered hair that curled all over their heads. She felt very curious to know what it was all about, and crept a little way out of the wood to listen. The Fish-Footman began by producing from under his arm a great letter, nearly as large as himself, and this he handed over to the other, saying, in a solemn tone, 'For the Duchess. An invitation from the Queen to play croquet.' The Frog-Footman repeated, in the same solemn tone, only changing the order of the words a little, 'From the Queen. An invitation for the Duchess to play croquet.' Then they both bowed low, and their curls got entangled together. Alice laughed so much at this, that she had to run back into the wood for fear of their hearing her; and when she next peeped out the Fish-Footman was gone, and the other was sitting on the ground near the door, staring stupidly up into the sky. Alice went timidly up to the door, and knocked. 'There's no sort of use in knocking,' said the Footman, 'and that for two reasons. First, because I'm on the same side of the door as you are; secondly, because they're making such a noise inside, no one could possibly hear you.' And certainly there was a most extraordinary noise going on within--a constant howling and sneezing, and every now and then a great crash, as if a dish or kettle had been broken to pieces. 'Please, then,' said Alice, 'how am I to get in?' 'There might be some sense in your knocking,' the Footman went on without attending to her, 'if we had the door between us. For instance, if you were INSIDE, you might knock, and I could let you out, you know.' He was looking up into the sky all the time he was speaking, and this Alice thought decidedly uncivil. 'But perhaps he can't help it,' she said to herself; 'his eyes are so VERY nearly at the top of his head. But at any rate he might answer questions.--How am I to get in?' she repeated, aloud. 'I shall sit here,' the Footman remarked, 'till tomorrow--' At this moment the door of the house opened, and a large plate came skimming out, straight at the Footman's head: it just grazed his nose, and broke to pieces against one of the trees behind him. '--or next day, maybe,' the Footman continued in the same tone, exactly as if nothing had happened. 'How am I to get in?' asked Alice again, in a louder tone. 'ARE you to get in at all?' said the Footman. 'That's the first question, you know.' It was, no doubt: only Alice did not like to be told so. 'It's really dreadful,' she muttered to herself, 'the way all the creatures argue. It's enough to drive one crazy!' The Footman seemed to think this a good opportunity for repeating his remark, with variations. 'I shall sit here,' he said, 'on and off, for days and days.' 'But what am I to do?' said Alice. 'Anything you like,' said the Footman, and began whistling. 'Oh, there's no use in talking to him,' said Alice desperately: 'he's perfectly idiotic!' And she opened the door and went in. The door led right into a large kitchen, which was full of smoke from one end to the other: the Duchess was sitting on a three-legged stool in the middle, nursing a baby; the cook was leaning over the fire, stirring a large cauldron which seemed to be full of soup. 'There's certainly too much pepper in that soup!' Alice said to herself, as well as she could for sneezing. There was certainly too much of it in the air. Even the Duchess sneezed occasionally; and as for the baby, it was sneezing and howling alternately without a moment's pause. The only things in the kitchen that did not sneeze, were the cook, and a large cat which was sitting on the hearth and grinning from ear to ear. 'Please would you tell me,' said Alice, a little timidly, for she was not quite sure whether it was good manners for her to speak first, 'why your cat grins like that?' 'It's a Cheshire cat,' said the Duchess, 'and that's why. Pig!' She said the last word with such sudden violence that Alice quite jumped; but she saw in another moment that it was addressed to the baby, and not to her, so she took courage, and went on again:-- 'I didn't know that Cheshire cats always grinned; in fact, I didn't know that cats COULD grin.' 'They all can,' said the Duchess; 'and most of 'em do.' 'I don't know of any that do,' Alice said very politely, feeling quite pleased to have got into a conversation. 'You don't know much,' said the Duchess; 'and that's a fact.' Alice did not at all like the tone of this remark, and thought it would be as well to introduce some other subject of conversation. While she was trying to fix on one, the cook took the cauldron of soup off the fire, and at once set to work throwing everything within her reach at the Duchess and the baby--the fire-irons came first; then followed a shower of saucepans, plates, and dishes. The Duchess took no notice of them even when they hit her; and the baby was howling so much already, that it was quite impossible to say whether the blows hurt it or not. 'Oh, PLEASE mind what you're doing!' cried Alice, jumping up and down in an agony of terror. 'Oh, there goes his PRECIOUS nose'; as an unusually large saucepan flew close by it, and very nearly carried it off. 'If everybody minded their own business,' the Duchess said in a hoarse growl, 'the world would go round a deal faster than it does.' 'Which would NOT be an advantage,' said Alice, who felt very glad to get an opportunity of showing off a little of her knowledge. 'Just think of what work it would make with the day and night! You see the earth takes twenty-four hours to turn round on its axis--' 'Talking of axes,' said the Duchess, 'chop off her head!' Alice glanced rather anxiously at the cook, to see if she meant to take the hint; but the cook was busily stirring the soup, and seemed not to be listening, so she went on again: 'Twenty-four hours, I THINK; or is it twelve? I--' 'Oh, don't bother ME,' said the Duchess; 'I never could abide figures!' And with that she began nursing her child again, singing a sort of lullaby to it as she did so, and giving it a violent shake at the end of every line: 'Speak roughly to your little boy, And beat him when he sneezes: He only does it to annoy, Because he knows it teases.' CHORUS. (In which the cook and the baby joined):-- 'Wow! wow! wow!' While the Duchess sang the second verse of the song, she kept tossing the baby violently up and down, and the poor little thing howled so, that Alice could hardly hear the words:-- 'I speak severely to my boy, I beat him when he sneezes; For he can thoroughly enjoy The pepper when he pleases!' CHORUS. 'Wow! wow! wow!' 'Here! you may nurse it a bit, if you like!' the Duchess said to Alice, flinging the baby at her as she spoke. 'I must go and get ready to play croquet with the Queen,' and she hurried out of the room. The cook threw a frying-pan after her as she went out, but it just missed her. Alice caught the baby with some difficulty, as it was a queer-shaped little creature, and held out its arms and legs in all directions, 'just like a star-fish,' thought Alice. The poor little thing was snorting like a steam-engine when she caught it, and kept doubling itself up and straightening itself out again, so that altogether, for the first minute or two, it was as much as she could do to hold it. As soon as she had made out the proper way of nursing it, (which was to twist it up into a sort of knot, and then keep tight hold of its right ear and left foot, so as to prevent its undoing itself,) she carried it out into the open air. 'IF I don't take this child away with me,' thought Alice, 'they're sure to kill it in a day or two: wouldn't it be murder to leave it behind?' She said the last words out loud, and the little thing grunted in reply (it had left off sneezing by this time). 'Don't grunt,' said Alice; 'that's not at all a proper way of expressing yourself.' The baby grunted again, and Alice looked very anxiously into its face to see what was the matter with it. There could be no doubt that it had a VERY turn-up nose, much more like a snout than a real nose; also its eyes were getting extremely small for a baby: altogether Alice did not like the look of the thing at all. 'But perhaps it was only sobbing,' she thought, and looked into its eyes again, to see if there were any tears. No, there were no tears. 'If you're going to turn into a pig, my dear,' said Alice, seriously, 'I'll have nothing more to do with you. Mind now!' The poor little thing sobbed again (or grunted, it was impossible to say which), and they went on for some while in silence. Alice was just beginning to think to herself, 'Now, what am I to do with this creature when I get it home?' when it grunted again, so violently, that she looked down into its face in some alarm. This time there could be NO mistake about it: it was neither more nor less than a pig, and she felt that it would be quite absurd for her to carry it further. So she set the little creature down, and felt quite relieved to see it trot away quietly into the wood. 'If it had grown up,' she said to herself, 'it would have made a dreadfully ugly child: but it makes rather a handsome pig, I think.' And she began thinking over other children she knew, who might do very well as pigs, and was just saying to herself, 'if one only knew the right way to change them--' when she was a little startled by seeing the Cheshire Cat sitting on a bough of a tree a few yards off. The Cat only grinned when it saw Alice. It looked good-natured, she thought: still it had VERY long claws and a great many teeth, so she felt that it ought to be treated with respect. 'Cheshire Puss,' she began, rather timidly, as she did not at all know whether it would like the name: however, it only grinned a little wider. 'Come, it's pleased so far,' thought Alice, and she went on. 'Would you tell me, please, which way I ought to go from here?' 'That depends a good deal on where you want to get to,' said the Cat. 'I don't much care where--' said Alice. 'Then it doesn't matter which way you go,' said the Cat. '--so long as I get SOMEWHERE,' Alice added as an explanation. 'Oh, you're sure to do that,' said the Cat, 'if you only walk long enough.' Alice felt that this could not be denied, so she tried another question. 'What sort of people live about here?' 'In THAT direction,' the Cat said, waving its right paw round, 'lives a Hatter: and in THAT direction,' waving the other paw, 'lives a March Hare. Visit either you like: they're both mad.' 'But I don't want to go among mad people,' Alice remarked. 'Oh, you can't help that,' said the Cat: 'we're all mad here. I'm mad. You're mad.' 'How do you know I'm mad?' said Alice. 'You must be,' said the Cat, 'or you wouldn't have come here.' Alice didn't think that proved it at all; however, she went on 'And how do you know that you're mad?' 'To begin with,' said the Cat, 'a dog's not mad. You grant that?' 'I suppose so,' said Alice. 'Well, then,' the Cat went on, 'you see, a dog growls when it's angry, and wags its tail when it's pleased. Now I growl when I'm pleased, and wag my tail when I'm angry. Therefore I'm mad.' 'I call it purring, not growling,' said Alice. 'Call it what you like,' said the Cat. 'Do you play croquet with the Queen to-day?' 'I should like it very much,' said Alice, 'but I haven't been invited yet.' 'You'll see me there,' said the Cat, and vanished. Alice was not much surprised at this, she was getting so used to queer things happening. While she was looking at the place where it had been, it suddenly appeared again. 'By-the-bye, what became of the baby?' said the Cat. 'I'd nearly forgotten to ask.' 'It turned into a pig,' Alice quietly said, just as if it had come back in a natural way. 'I thought it would,' said the Cat, and vanished again. Alice waited a little, half expecting to see it again, but it did not appear, and after a minute or two she walked on in the direction in which the March Hare was said to live. 'I've seen hatters before,' she said to herself; 'the March Hare will be much the most interesting, and perhaps as this is May it won't be raving mad--at least not so mad as it was in March.' As she said this, she looked up, and there was the Cat again, sitting on a branch of a tree. 'Did you say pig, or fig?' said the Cat. 'I said pig,' replied Alice; 'and I wish you wouldn't keep appearing and vanishing so suddenly: you make one quite giddy.' 'All right,' said the Cat; and this time it vanished quite slowly, beginning with the end of the tail, and ending with the grin, which remained some time after the rest of it had gone. 'Well! I've often seen a cat without a grin,' thought Alice; 'but a grin without a cat! It's the most curious thing I ever saw in my life!' She had not gone much farther before she came in sight of the house of the March Hare: she thought it must be the right house, because the chimneys were shaped like ears and the roof was thatched with fur. It was so large a house, that she did not like to go nearer till she had nibbled some more of the lefthand bit of mushroom, and raised herself to about two feet high: even then she walked up towards it rather timidly, saying to herself 'Suppose it should be raving mad after all! I almost wish I'd gone to see the Hatter instead!' CHAPTER VII. A Mad Tea-Party There was a table set out under a tree in front of the house, and the March Hare and the Hatter were having tea at it: a Dormouse was sitting between them, fast asleep, and the other two were using it as a cushion, resting their elbows on it, and talking over its head. 'Very uncomfortable for the Dormouse,' thought Alice; 'only, as it's asleep, I suppose it doesn't mind.' The table was a large one, but the three were all crowded together at one corner of it: 'No room! No room!' they cried out when they saw Alice coming. 'There's PLENTY of room!' said Alice indignantly, and she sat down in a large arm-chair at one end of the table. 'Have some wine,' the March Hare said in an encouraging tone. Alice looked all round the table, but there was nothing on it but tea. 'I don't see any wine,' she remarked. 'There isn't any,' said the March Hare. 'Then it wasn't very civil of you to offer it,' said Alice angrily. 'It wasn't very civil of you to sit down without being invited,' said the March Hare. 'I didn't know it was YOUR table,' said Alice; 'it's laid for a great many more than three.' 'Your hair wants cutting,' said the Hatter. He had been looking at Alice for some time with great curiosity, and this was his first speech. 'You should learn not to make personal remarks,' Alice said with some severity; 'it's very rude.' The Hatter opened his eyes very wide on hearing this; but all he SAID was, 'Why is a raven like a writing-desk?' 'Come, we shall have some fun now!' thought Alice. 'I'm glad they've begun asking riddles.--I believe I can guess that,' she added aloud. 'Do you mean that you think you can find out the answer to it?' said the March Hare. 'Exactly so,' said Alice. 'Then you should say what you mean,' the March Hare went on. 'I do,' Alice hastily replied; 'at least--at least I mean what I say--that's the same thing, you know.' 'Not the same thing a bit!' said the Hatter. 'You might just as well say that "I see what I eat" is the same thing as "I eat what I see"!' 'You might just as well say,' added the March Hare, 'that "I like what I get" is the same thing as "I get what I like"!' 'You might just as well say,' added the Dormouse, who seemed to be talking in his sleep, 'that "I breathe when I sleep" is the same thing as "I sleep when I breathe"!' 'It IS the same thing with you,' said the Hatter, and here the conversation dropped, and the party sat silent for a minute, while Alice thought over all she could remember about ravens and writing-desks, which wasn't much. The Hatter was the first to break the silence. 'What day of the month is it?' he said, turning to Alice: he had taken his watch out of his pocket, and was looking at it uneasily, shaking it every now and then, and holding it to his ear. Alice considered a little, and then said 'The fourth.' 'Two days wrong!' sighed the Hatter. 'I told you butter wouldn't suit the works!' he added looking angrily at the March Hare. 'It was the BEST butter,' the March Hare meekly replied. 'Yes, but some crumbs must have got in as well,' the Hatter grumbled: 'you shouldn't have put it in with the bread-knife.' The March Hare took the watch and looked at it gloomily: then he dipped it into his cup of tea, and looked at it again: but he could think of nothing better to say than his first remark, 'It was the BEST butter, you know.' Alice had been looking over his shoulder with some curiosity. 'What a funny watch!' she remarked. 'It tells the day of the month, and doesn't tell what o'clock it is!' 'Why should it?' muttered the Hatter. 'Does YOUR watch tell you what year it is?' 'Of course not,' Alice replied very readily: 'but that's because it stays the same year for such a long time together.' 'Which is just the case with MINE,' said the Hatter. Alice felt dreadfully puzzled. The Hatter's remark seemed to have no sort of meaning in it, and yet it was certainly English. 'I don't quite understand you,' she said, as politely as she could. 'The Dormouse is asleep again,' said the Hatter, and he poured a little hot tea upon its nose. The Dormouse shook its head impatiently, and said, without opening its eyes, 'Of course, of course; just what I was going to remark myself.' 'Have you guessed the riddle yet?' the Hatter said, turning to Alice again. 'No, I give it up,' Alice replied: 'what's the answer?' 'I haven't the slightest idea,' said the Hatter. 'Nor I,' said the March Hare. Alice sighed wearily. 'I think you might do something better with the time,' she said, 'than waste it in asking riddles that have no answers.' 'If you knew Time as well as I do,' said the Hatter, 'you wouldn't talk about wasting IT. It's HIM.' 'I don't know what you mean,' said Alice. 'Of course you don't!' the Hatter said, tossing his head contemptuously. 'I dare say you never even spoke to Time!' 'Perhaps not,' Alice cautiously replied: 'but I know I have to beat time when I learn music.' 'Ah! that accounts for it,' said the Hatter. 'He won't stand beating. Now, if you only kept on good terms with him, he'd do almost anything you liked with the clock. For instance, suppose it were nine o'clock in the morning, just time to begin lessons: you'd only have to whisper a hint to Time, and round goes the clock in a twinkling! Half-past one, time for dinner!' ('I only wish it was,' the March Hare said to itself in a whisper.) 'That would be grand, certainly,' said Alice thoughtfully: 'but then--I shouldn't be hungry for it, you know.' 'Not at first, perhaps,' said the Hatter: 'but you could keep it to half-past one as long as you liked.' 'Is that the way YOU manage?' Alice asked. The Hatter shook his head mournfully. 'Not I!' he replied. 'We quarrelled last March--just before HE went mad, you know--' (pointing with his tea spoon at the March Hare,) '--it was at the great concert given by the Queen of Hearts, and I had to sing "Twinkle, twinkle, little bat! How I wonder what you're at!" You know the song, perhaps?' 'I've heard something like it,' said Alice. 'It goes on, you know,' the Hatter continued, 'in this way:-- "Up above the world you fly, Like a tea-tray in the sky. Twinkle, twinkle--"' Here the Dormouse shook itself, and began singing in its sleep 'Twinkle, twinkle, twinkle, twinkle--' and went on so long that they had to pinch it to make it stop. 'Well, I'd hardly finished the first verse,' said the Hatter, 'when the Queen jumped up and bawled out, "He's murdering the time! Off with his head!"' 'How dreadfully savage!' exclaimed Alice. 'And ever since that,' the Hatter went on in a mournful tone, 'he won't do a thing I ask! It's always six o'clock now.' A bright idea came into Alice's head. 'Is that the reason so many tea-things are put out here?' she asked. 'Yes, that's it,' said the Hatter with a sigh: 'it's always tea-time, and we've no time to wash the things between whiles.' 'Then you keep moving round, I suppose?' said Alice. 'Exactly so,' said the Hatter: 'as the things get used up.' 'But what happens when you come to the beginning again?' Alice ventured to ask. 'Suppose we change the subject,' the March Hare interrupted, yawning. 'I'm getting tired of this. I vote the young lady tells us a story.' 'I'm afraid I don't know one,' said Alice, rather alarmed at the proposal. 'Then the Dormouse shall!' they both cried. 'Wake up, Dormouse!' And they pinched it on both sides at once. The Dormouse slowly opened his eyes. 'I wasn't asleep,' he said in a hoarse, feeble voice: 'I heard every word you fellows were saying.' 'Tell us a story!' said the March Hare. 'Yes, please do!' pleaded Alice. 'And be quick about it,' added the Hatter, 'or you'll be asleep again before it's done.' 'Once upon a time there were three little sisters,' the Dormouse began in a great hurry; 'and their names were Elsie, Lacie, and Tillie; and they lived at the bottom of a well--' 'What did they live on?' said Alice, who always took a great interest in questions of eating and drinking. 'They lived on treacle,' said the Dormouse, after thinking a minute or two. 'They couldn't have done that, you know,' Alice gently remarked; 'they'd have been ill.' 'So they were,' said the Dormouse; 'VERY ill.' Alice tried to fancy to herself what such an extraordinary ways of living would be like, but it puzzled her too much, so she went on: 'But why did they live at the bottom of a well?' 'Take some more tea,' the March Hare said to Alice, very earnestly. 'I've had nothing yet,' Alice replied in an offended tone, 'so I can't take more.' 'You mean you can't take LESS,' said the Hatter: 'it's very easy to take MORE than nothing.' 'Nobody asked YOUR opinion,' said Alice. 'Who's making personal remarks now?' the Hatter asked triumphantly. Alice did not quite know what to say to this: so she helped herself to some tea and bread-and-butter, and then turned to the Dormouse, and repeated her question. 'Why did they live at the bottom of a well?' The Dormouse again took a minute or two to think about it, and then said, 'It was a treacle-well.' 'There's no such thing!' Alice was beginning very angrily, but the Hatter and the March Hare went 'Sh! sh!' and the Dormouse sulkily remarked, 'If you can't be civil, you'd better finish the story for yourself.' 'No, please go on!' Alice said very humbly; 'I won't interrupt again. I dare say there may be ONE.' 'One, indeed!' said the Dormouse indignantly. However, he consented to go on. 'And so these three little sisters--they were learning to draw, you know--' 'What did they draw?' said Alice, quite forgetting her promise. 'Treacle,' said the Dormouse, without considering at all this time. 'I want a clean cup,' interrupted the Hatter: 'let's all move one place on.' He moved on as he spoke, and the Dormouse followed him: the March Hare moved into the Dormouse's place, and Alice rather unwillingly took the place of the March Hare. The Hatter was the only one who got any advantage from the change: and Alice was a good deal worse off than before, as the March Hare had just upset the milk-jug into his plate. Alice did not wish to offend the Dormouse again, so she began very cautiously: 'But I don't understand. Where did they draw the treacle from?' 'You can draw water out of a water-well,' said the Hatter; 'so I should think you could draw treacle out of a treacle-well--eh, stupid?' 'But they were IN the well,' Alice said to the Dormouse, not choosing to notice this last remark. 'Of course they were', said the Dormouse; '--well in.' This answer so confused poor Alice, that she let the Dormouse go on for some time without interrupting it. 'They were learning to draw,' the Dormouse went on, yawning and rubbing its eyes, for it was getting very sleepy; 'and they drew all manner of things--everything that begins with an M--' 'Why with an M?' said Alice. 'Why not?' said the March Hare. Alice was silent. The Dormouse had closed its eyes by this time, and was going off into a doze; but, on being pinched by the Hatter, it woke up again with a little shriek, and went on: '--that begins with an M, such as mouse-traps, and the moon, and memory, and muchness--you know you say things are "much of a muchness"--did you ever see such a thing as a drawing of a muchness?' 'Really, now you ask me,' said Alice, very much confused, 'I don't think--' 'Then you shouldn't talk,' said the Hatter. This piece of rudeness was more than Alice could bear: she got up in great disgust, and walked off; the Dormouse fell asleep instantly, and neither of the others took the least notice of her going, though she looked back once or twice, half hoping that they would call after her: the last time she saw them, they were trying to put the Dormouse into the teapot. 'At any rate I'll never go THERE again!' said Alice as she picked her way through the wood. 'It's the stupidest tea-party I ever was at in all my life!' Just as she said this, she noticed that one of the trees had a door leading right into it. 'That's very curious!' she thought. 'But everything's curious today. I think I may as well go in at once.' And in she went. Once more she found herself in the long hall, and close to the little glass table. 'Now, I'll manage better this time,' she said to herself, and began by taking the little golden key, and unlocking the door that led into the garden. Then she went to work nibbling at the mushroom (she had kept a piece of it in her pocket) till she was about a foot high: then she walked down the little passage: and THEN--she found herself at last in the beautiful garden, among the bright flower-beds and the cool fountains. CHAPTER VIII. The Queen's Croquet-Ground A large rose-tree stood near the entrance of the garden: the roses growing on it were white, but there were three gardeners at it, busily painting them red. Alice thought this a very curious thing, and she went nearer to watch them, and just as she came up to them she heard one of them say, 'Look out now, Five! Don't go splashing paint over me like that!' 'I couldn't help it,' said Five, in a sulky tone; 'Seven jogged my elbow.' On which Seven looked up and said, 'That's right, Five! Always lay the blame on others!' 'YOU'D better not talk!' said Five. 'I heard the Queen say only yesterday you deserved to be beheaded!' 'What for?' said the one who had spoken first. 'That's none of YOUR business, Two!' said Seven. 'Yes, it IS his business!' said Five, 'and I'll tell him--it was for bringing the cook tulip-roots instead of onions.' Seven flung down his brush, and had just begun 'Well, of all the unjust things--' when his eye chanced to fall upon Alice, as she stood watching them, and he checked himself suddenly: the others looked round also, and all of them bowed low. 'Would you tell me,' said Alice, a little timidly, 'why you are painting those roses?' Five and Seven said nothing, but looked at Two. Two began in a low voice, 'Why the fact is, you see, Miss, this here ought to have been a RED rose-tree, and we put a white one in by mistake; and if the Queen was to find it out, we should all have our heads cut off, you know. So you see, Miss, we're doing our best, afore she comes, to--' At this moment Five, who had been anxiously looking across the garden, called out 'The Queen! The Queen!' and the three gardeners instantly threw themselves flat upon their faces. There was a sound of many footsteps, and Alice looked round, eager to see the Queen. First came ten soldiers carrying clubs; these were all shaped like the three gardeners, oblong and flat, with their hands and feet at the corners: next the ten courtiers; these were ornamented all over with diamonds, and walked two and two, as the soldiers did. After these came the royal children; there were ten of them, and the little dears came jumping merrily along hand in hand, in couples: they were all ornamented with hearts. Next came the guests, mostly Kings and Queens, and among them Alice recognised the White Rabbit: it was talking in a hurried nervous manner, smiling at everything that was said, and went by without noticing her. Then followed the Knave of Hearts, carrying the King's crown on a crimson velvet cushion; and, last of all this grand procession, came THE KING AND QUEEN OF HEARTS. Alice was rather doubtful whether she ought not to lie down on her face like the three gardeners, but she could not remember ever having heard of such a rule at processions; 'and besides, what would be the use of a procession,' thought she, 'if people had all to lie down upon their faces, so that they couldn't see it?' So she stood still where she was, and waited. When the procession came opposite to Alice, they all stopped and looked at her, and the Queen said severely 'Who is this?' She said it to the Knave of Hearts, who only bowed and smiled in reply. 'Idiot!' said the Queen, tossing her head impatiently; and, turning to Alice, she went on, 'What's your name, child?' 'My name is Alice, so please your Majesty,' said Alice very politely; but she added, to herself, 'Why, they're only a pack of cards, after all. I needn't be afraid of them!' 'And who are THESE?' said the Queen, pointing to the three gardeners who were lying round the rosetree; for, you see, as they were lying on their faces, and the pattern on their backs was the same as the rest of the pack, she could not tell whether they were gardeners, or soldiers, or courtiers, or three of her own children. 'How should I know?' said Alice, surprised at her own courage. 'It's no business of MINE.' The Queen turned crimson with fury, and, after glaring at her for a moment like a wild beast, screamed 'Off with her head! Off--' 'Nonsense!' said Alice, very loudly and decidedly, and the Queen was silent. The King laid his hand upon her arm, and timidly said 'Consider, my dear: she is only a child!' The Queen turned angrily away from him, and said to the Knave 'Turn them over!' The Knave did so, very carefully, with one foot. 'Get up!' said the Queen, in a shrill, loud voice, and the three gardeners instantly jumped up, and began bowing to the King, the Queen, the royal children, and everybody else. 'Leave off that!' screamed the Queen. 'You make me giddy.' And then, turning to the rose-tree, she went on, 'What HAVE you been doing here?' 'May it please your Majesty,' said Two, in a very humble tone, going down on one knee as he spoke, 'we were trying--' 'I see!' said the Queen, who had meanwhile been examining the roses. 'Off with their heads!' and the procession moved on, three of the soldiers remaining behind to execute the unfortunate gardeners, who ran to Alice for protection. 'You shan't be beheaded!' said Alice, and she put them into a large flower-pot that stood near. The three soldiers wandered about for a minute or two, looking for them, and then quietly marched off after the others. 'Are their heads off?' shouted the Queen. 'Their heads are gone, if it please your Majesty!' the soldiers shouted in reply. 'That's right!' shouted the Queen. 'Can you play croquet?' The soldiers were silent, and looked at Alice, as the question was evidently meant for her. 'Yes!' shouted Alice. 'Come on, then!' roared the Queen, and Alice joined the procession, wondering very much what would happen next. 'It's--it's a very fine day!' said a timid voice at her side. She was walking by the White Rabbit, who was peeping anxiously into her face. 'Very,' said Alice: '--where's the Duchess?' 'Hush! Hush!' said the Rabbit in a low, hurried tone. He looked anxiously over his shoulder as he spoke, and then raised himself upon tiptoe, put his mouth close to her ear, and whispered 'She's under sentence of execution.' 'What for?' said Alice. 'Did you say "What a pity!"?' the Rabbit asked. 'No, I didn't,' said Alice: 'I don't think it's at all a pity. I said "What for?"' 'She boxed the Queen's ears--' the Rabbit began. Alice gave a little scream of laughter. 'Oh, hush!' the Rabbit whispered in a frightened tone. 'The Queen will hear you! You see, she came rather late, and the Queen said--' 'Get to your places!' shouted the Queen in a voice of thunder, and people began running about in all directions, tumbling up against each other; however, they got settled down in a minute or two, and the game began. Alice thought she had never seen such a curious croquet-ground in her life; it was all ridges and furrows; the balls were live hedgehogs, the mallets live flamingoes, and the soldiers had to double themselves up and to stand on their hands and feet, to make the arches. The chief difficulty Alice found at first was in managing her flamingo: she succeeded in getting its body tucked away, comfortably enough, under her arm, with its legs hanging down, but generally, just as she had got its neck nicely straightened out, and was going to give the hedgehog a blow with its head, it WOULD twist itself round and look up in her face, with such a puzzled expression that she could not help bursting out laughing: and when she had got its head down, and was going to begin again, it was very provoking to find that the hedgehog had unrolled itself, and was in the act of crawling away: besides all this, there was generally a ridge or furrow in the way wherever she wanted to send the hedgehog to, and, as the doubled-up soldiers were always getting up and walking off to other parts of the ground, Alice soon came to the conclusion that it was a very difficult game indeed. The players all played at once without waiting for turns, quarrelling all the while, and fighting for the hedgehogs; and in a very short time the Queen was in a furious passion, and went stamping about, and shouting 'Off with his head!' or 'Off with her head!' about once in a minute. Alice began to feel very uneasy: to be sure, she had not as yet had any dispute with the Queen, but she knew that it might happen any minute, 'and then,' thought she, 'what would become of me? They're dreadfully fond of beheading people here; the great wonder is, that there's any one left alive!' She was looking about for some way of escape, and wondering whether she could get away without being seen, when she noticed a curious appearance in the air: it puzzled her very much at first, but, after watching it a minute or two, she made it out to be a grin, and she said to herself 'It's the Cheshire Cat: now I shall have somebody to talk to.' 'How are you getting on?' said the Cat, as soon as there was mouth enough for it to speak with. Alice waited till the eyes appeared, and then nodded. 'It's no use speaking to it,' she thought, 'till its ears have come, or at least one of them.' In another minute the whole head appeared, and then Alice put down her flamingo, and began an account of the game, feeling very glad she had someone to listen to her. The Cat seemed to think that there was enough of it now in sight, and no more of it appeared. 'I don't think they play at all fairly,' Alice began, in rather a complaining tone, 'and they all quarrel so dreadfully one can't hear oneself speak--and they don't seem to have any rules in particular; at least, if there are, nobody attends to them--and you've no idea how confusing it is all the things being alive; for instance, there's the arch I've got to go through next walking about at the other end of the ground--and I should have croqueted the Queen's hedgehog just now, only it ran away when it saw mine coming!' 'How do you like the Queen?' said the Cat in a low voice. 'Not at all,' said Alice: 'she's so extremely--' Just then she noticed that the Queen was close behind her, listening: so she went on, '--likely to win, that it's hardly worth while finishing the game.' The Queen smiled and passed on. 'Who ARE you talking to?' said the King, going up to Alice, and looking at the Cat's head with great curiosity. 'It's a friend of mine--a Cheshire Cat,' said Alice: 'allow me to introduce it.' 'I don't like the look of it at all,' said the King: 'however, it may kiss my hand if it likes.' 'I'd rather not,' the Cat remarked. 'Don't be impertinent,' said the King, 'and don't look at me like that!' He got behind Alice as he spoke. 'A cat may look at a king,' said Alice. 'I've read that in some book, but I don't remember where.' 'Well, it must be removed,' said the King very decidedly, and he called the Queen, who was passing at the moment, 'My dear! I wish you would have this cat removed!' The Queen had only one way of settling all difficulties, great or small. 'Off with his head!' she said, without even looking round. 'I'll fetch the executioner myself,' said the King eagerly, and he hurried off. Alice thought she might as well go back, and see how the game was going on, as she heard the Queen's voice in the distance, screaming with passion. She had already heard her sentence three of the players to be executed for having missed their turns, and she did not like the look of things at all, as the game was in such confusion that she never knew whether it was her turn or not. So she went in search of her hedgehog. The hedgehog was engaged in a fight with another hedgehog, which seemed to Alice an excellent opportunity for croqueting one of them with the other: the only difficulty was, that her flamingo was gone across to the other side of the garden, where Alice could see it trying in a helpless sort of way to fly up into a tree. By the time she had caught the flamingo and brought it back, the fight was over, and both the hedgehogs were out of sight: 'but it doesn't matter much,' thought Alice, 'as all the arches are gone from this side of the ground.' So she tucked it away under her arm, that it might not escape again, and went back for a little more conversation with her friend. When she got back to the Cheshire Cat, she was surprised to find quite a large crowd collected round it: there was a dispute going on between the executioner, the King, and the Queen, who were all talking at once, while all the rest were quite silent, and looked very uncomfortable. The moment Alice appeared, she was appealed to by all three to settle the question, and they repeated their arguments to her, though, as they all spoke at once, she found it very hard indeed to make out exactly what they said. The executioner's argument was, that you couldn't cut off a head unless there was a body to cut it off from: that he had never had to do such a thing before, and he wasn't going to begin at HIS time of life. The King's argument was, that anything that had a head could be beheaded, and that you weren't to talk nonsense. The Queen's argument was, that if something wasn't done about it in less than no time she'd have everybody executed, all round. (It was this last remark that had made the whole party look so grave and anxious.) Alice could think of nothing else to say but 'It belongs to the Duchess: you'd better ask HER about it.' 'She's in prison,' the Queen said to the executioner: 'fetch her here.' And the executioner went off like an arrow. The Cat's head began fading away the moment he was gone, and, by the time he had come back with the Duchess, it had entirely disappeared; so the King and the executioner ran wildly up and down looking for it, while the rest of the party went back to the game. CHAPTER IX. The Mock Turtle's Story 'You can't think how glad I am to see you again, you dear old thing!' said the Duchess, as she tucked her arm affectionately into Alice's, and they walked off together. Alice was very glad to find her in such a pleasant temper, and thought to herself that perhaps it was only the pepper that had made her so savage when they met in the kitchen. 'When I'M a Duchess,' she said to herself, (not in a very hopeful tone though), 'I won't have any pepper in my kitchen AT ALL. Soup does very well without--Maybe it's always pepper that makes people hot-tempered,' she went on, very much pleased at having found out a new kind of rule, 'and vinegar that makes them sour--and camomile that makes them bitter--and--and barley-sugar and such things that make children sweet-tempered. I only wish people knew that: then they wouldn't be so stingy about it, you know--' She had quite forgotten the Duchess by this time, and was a little startled when she heard her voice close to her ear. 'You're thinking about something, my dear, and that makes you forget to talk. I can't tell you just now what the moral of that is, but I shall remember it in a bit.' 'Perhaps it hasn't one,' Alice ventured to remark. 'Tut, tut, child!' said the Duchess. 'Everything's got a moral, if only you can find it.' And she squeezed herself up closer to Alice's side as she spoke. Alice did not much like keeping so close to her: first, because the Duchess was VERY ugly; and secondly, because she was exactly the right height to rest her chin upon Alice's shoulder, and it was an uncomfortably sharp chin. However, she did not like to be rude, so she bore it as well as she could. 'The game's going on rather better now,' she said, by way of keeping up the conversation a little. ''Tis so,' said the Duchess: 'and the moral of that is--"Oh, 'tis love, 'tis love, that makes the world go round!"' 'Somebody said,' Alice whispered, 'that it's done by everybody minding their own business!' 'Ah, well! It means much the same thing,' said the Duchess, digging her sharp little chin into Alice's shoulder as she added, 'and the moral of THAT is--"Take care of the sense, and the sounds will take care of themselves."' 'How fond she is of finding morals in things!' Alice thought to herself. 'I dare say you're wondering why I don't put my arm round your waist,' the Duchess said after a pause: 'the reason is, that I'm doubtful about the temper of your flamingo. Shall I try the experiment?' 'HE might bite,' Alice cautiously replied, not feeling at all anxious to have the experiment tried. 'Very true,' said the Duchess: 'flamingoes and mustard both bite. And the moral of that is--"Birds of a feather flock together."' 'Only mustard isn't a bird,' Alice remarked. 'Right, as usual,' said the Duchess: 'what a clear way you have of putting things!' 'It's a mineral, I THINK,' said Alice. 'Of course it is,' said the Duchess, who seemed ready to agree to everything that Alice said; 'there's a large mustard-mine near here. And the moral of that is--"The more there is of mine, the less there is of yours."' 'Oh, I know!' exclaimed Alice, who had not attended to this last remark, 'it's a vegetable. It doesn't look like one, but it is.' 'I quite agree with you,' said the Duchess; 'and the moral of that is--"Be what you would seem to be"--or if you'd like it put more simply--"Never imagine yourself not to be otherwise than what it might appear to others that what you were or might have been was not otherwise than what you had been would have appeared to them to be otherwise."' 'I think I should understand that better,' Alice said very politely, 'if I had it written down: but I can't quite follow it as you say it.' 'That's nothing to what I could say if I chose,' the Duchess replied, in a pleased tone. 'Pray don't trouble yourself to say it any longer than that,' said Alice. 'Oh, don't talk about trouble!' said the Duchess. 'I make you a present of everything I've said as yet.' 'A cheap sort of present!' thought Alice. 'I'm glad they don't give birthday presents like that!' But she did not venture to say it out loud. 'Thinking again?' the Duchess asked, with another dig of her sharp little chin. 'I've a right to think,' said Alice sharply, for she was beginning to feel a little worried. 'Just about as much right,' said the Duchess, 'as pigs have to fly; and the m--' But here, to Alice's great surprise, the Duchess's voice died away, even in the middle of her favourite word 'moral,' and the arm that was linked into hers began to tremble. Alice looked up, and there stood the Queen in front of them, with her arms folded, frowning like a thunderstorm. 'A fine day, your Majesty!' the Duchess began in a low, weak voice. 'Now, I give you fair warning,' shouted the Queen, stamping on the ground as she spoke; 'either you or your head must be off, and that in about half no time! Take your choice!' The Duchess took her choice, and was gone in a moment. 'Let's go on with the game,' the Queen said to Alice; and Alice was too much frightened to say a word, but slowly followed her back to the croquet-ground. The other guests had taken advantage of the Queen's absence, and were resting in the shade: however, the moment they saw her, they hurried back to the game, the Queen merely remarking that a moment's delay would cost them their lives. All the time they were playing the Queen never left off quarrelling with the other players, and shouting 'Off with his head!' or 'Off with her head!' Those whom she sentenced were taken into custody by the soldiers, who of course had to leave off being arches to do this, so that by the end of half an hour or so there were no arches left, and all the players, except the King, the Queen, and Alice, were in custody and under sentence of execution. Then the Queen left off, quite out of breath, and said to Alice, 'Have you seen the Mock Turtle yet?' 'No,' said Alice. 'I don't even know what a Mock Turtle is.' 'It's the thing Mock Turtle Soup is made from,' said the Queen. 'I never saw one, or heard of one,' said Alice. 'Come on, then,' said the Queen, 'and he shall tell you his history,' As they walked off together, Alice heard the King say in a low voice, to the company generally, 'You are all pardoned.' 'Come, THAT'S a good thing!' she said to herself, for she had felt quite unhappy at the number of executions the Queen had ordered. They very soon came upon a Gryphon, lying fast asleep in the sun. (IF you don't know what a Gryphon is, look at the picture.) 'Up, lazy thing!' said the Queen, 'and take this young lady to see the Mock Turtle, and to hear his history. I must go back and see after some executions I have ordered'; and she walked off, leaving Alice alone with the Gryphon. Alice did not quite like the look of the creature, but on the whole she thought it would be quite as safe to stay with it as to go after that savage Queen: so she waited. The Gryphon sat up and rubbed its eyes: then it watched the Queen till she was out of sight: then it chuckled. 'What fun!' said the Gryphon, half to itself, half to Alice. 'What IS the fun?' said Alice. 'Why, SHE,' said the Gryphon. 'It's all her fancy, that: they never executes nobody, you know. Come on!' 'Everybody says "come on!" here,' thought Alice, as she went slowly after it: 'I never was so ordered about in all my life, never!' They had not gone far before they saw the Mock Turtle in the distance, sitting sad and lonely on a little ledge of rock, and, as they came nearer, Alice could hear him sighing as if his heart would break. She pitied him deeply. 'What is his sorrow?' she asked the Gryphon, and the Gryphon answered, very nearly in the same words as before, 'It's all his fancy, that: he hasn't got no sorrow, you know. Come on!' So they went up to the Mock Turtle, who looked at them with large eyes full of tears, but said nothing. 'This here young lady,' said the Gryphon, 'she wants for to know your history, she do.' 'I'll tell it her,' said the Mock Turtle in a deep, hollow tone: 'sit down, both of you, and don't speak a word till I've finished.' So they sat down, and nobody spoke for some minutes. Alice thought to herself, 'I don't see how he can EVEN finish, if he doesn't begin.' But she waited patiently. 'Once,' said the Mock Turtle at last, with a deep sigh, 'I was a real Turtle.' These words were followed by a very long silence, broken only by an occasional exclamation of 'Hjckrrh!' from the Gryphon, and the constant heavy sobbing of the Mock Turtle. Alice was very nearly getting up and saying, 'Thank you, sir, for your interesting story,' but she could not help thinking there MUST be more to come, so she sat still and said nothing. 'When we were little,' the Mock Turtle went on at last, more calmly, though still sobbing a little now and then, 'we went to school in the sea. The master was an old Turtle--we used to call him Tortoise--' 'Why did you call him Tortoise, if he wasn't one?' Alice asked. 'We called him Tortoise because he taught us,' said the Mock Turtle angrily: 'really you are very dull!' 'You ought to be ashamed of yourself for asking such a simple question,' added the Gryphon; and then they both sat silent and looked at poor Alice, who felt ready to sink into the earth. At last the Gryphon said to the Mock Turtle, 'Drive on, old fellow! Don't be all day about it!' and he went on in these words: 'Yes, we went to school in the sea, though you mayn't believe it--' 'I never said I didn't!' interrupted Alice. 'You did,' said the Mock Turtle. 'Hold your tongue!' added the Gryphon, before Alice could speak again. The Mock Turtle went on. 'We had the best of educations--in fact, we went to school every day--' 'I'VE been to a day-school, too,' said Alice; 'you needn't be so proud as all that.' 'With extras?' asked the Mock Turtle a little anxiously. 'Yes,' said Alice, 'we learned French and music.' 'And washing?' said the Mock Turtle. 'Certainly not!' said Alice indignantly. 'Ah! then yours wasn't a really good school,' said the Mock Turtle in a tone of great relief. 'Now at OURS they had at the end of the bill, "French, music, AND WASHING--extra."' 'You couldn't have wanted it much,' said Alice; 'living at the bottom of the sea.' 'I couldn't afford to learn it.' said the Mock Turtle with a sigh. 'I only took the regular course.' 'What was that?' inquired Alice. 'Reeling and Writhing, of course, to begin with,' the Mock Turtle replied; 'and then the different branches of Arithmetic--Ambition, Distraction, Uglification, and Derision.' 'I never heard of "Uglification,"' Alice ventured to say. 'What is it?' The Gryphon lifted up both its paws in surprise. 'What! Never heard of uglifying!' it exclaimed. 'You know what to beautify is, I suppose?' 'Yes,' said Alice doubtfully: 'it means--to--make--anything--prettier.' 'Well, then,' the Gryphon went on, 'if you don't know what to uglify is, you ARE a simpleton.' Alice did not feel encouraged to ask any more questions about it, so she turned to the Mock Turtle, and said 'What else had you to learn?' 'Well, there was Mystery,' the Mock Turtle replied, counting off the subjects on his flappers, '--Mystery, ancient and modern, with Seaography: then Drawling--the Drawling-master was an old conger-eel, that used to come once a week: HE taught us Drawling, Stretching, and Fainting in Coils.' 'What was THAT like?' said Alice. 'Well, I can't show it you myself,' the Mock Turtle said: 'I'm too stiff. And the Gryphon never learnt it.' 'Hadn't time,' said the Gryphon: 'I went to the Classics master, though. He was an old crab, HE was.' 'I never went to him,' the Mock Turtle said with a sigh: 'he taught Laughing and Grief, they used to say.' 'So he did, so he did,' said the Gryphon, sighing in his turn; and both creatures hid their faces in their paws. 'And how many hours a day did you do lessons?' said Alice, in a hurry to change the subject. 'Ten hours the first day,' said the Mock Turtle: 'nine the next, and so on.' 'What a curious plan!' exclaimed Alice. 'That's the reason they're called lessons,' the Gryphon remarked: 'because they lessen from day to day.' This was quite a new idea to Alice, and she thought it over a little before she made her next remark. 'Then the eleventh day must have been a holiday?' 'Of course it was,' said the Mock Turtle. 'And how did you manage on the twelfth?' Alice went on eagerly. 'That's enough about lessons,' the Gryphon interrupted in a very decided tone: 'tell her something about the games now.' CHAPTER X. The Lobster Quadrille The Mock Turtle sighed deeply, and drew the back of one flapper across his eyes. He looked at Alice, and tried to speak, but for a minute or two sobs choked his voice. 'Same as if he had a bone in his throat,' said the Gryphon: and it set to work shaking him and punching him in the back. At last the Mock Turtle recovered his voice, and, with tears running down his cheeks, he went on again:-- 'You may not have lived much under the sea--' ('I haven't,' said Alice)--'and perhaps you were never even introduced to a lobster--' (Alice began to say 'I once tasted--' but checked herself hastily, and said 'No, never') '--so you can have no idea what a delightful thing a Lobster Quadrille is!' 'No, indeed,' said Alice. 'What sort of a dance is it?' 'Why,' said the Gryphon, 'you first form into a line along the sea-shore--' 'Two lines!' cried the Mock Turtle. 'Seals, turtles, salmon, and so on; then, when you've cleared all the jelly-fish out of the way--' 'THAT generally takes some time,' interrupted the Gryphon. '--you advance twice--' 'Each with a lobster as a partner!' cried the Gryphon. 'Of course,' the Mock Turtle said: 'advance twice, set to partners--' '--change lobsters, and retire in same order,' continued the Gryphon. 'Then, you know,' the Mock Turtle went on, 'you throw the--' 'The lobsters!' shouted the Gryphon, with a bound into the air. '--as far out to sea as you can--' 'Swim after them!' screamed the Gryphon. 'Turn a somersault in the sea!' cried the Mock Turtle, capering wildly about. 'Change lobsters again!' yelled the Gryphon at the top of its voice. 'Back to land again, and that's all the first figure,' said the Mock Turtle, suddenly dropping his voice; and the two creatures, who had been jumping about like mad things all this time, sat down again very sadly and quietly, and looked at Alice. 'It must be a very pretty dance,' said Alice timidly. 'Would you like to see a little of it?' said the Mock Turtle. 'Very much indeed,' said Alice. 'Come, let's try the first figure!' said the Mock Turtle to the Gryphon. 'We can do without lobsters, you know. Which shall sing?' 'Oh, YOU sing,' said the Gryphon. 'I've forgotten the words.' So they began solemnly dancing round and round Alice, every now and then treading on her toes when they passed too close, and waving their forepaws to mark the time, while the Mock Turtle sang this, very slowly and sadly:-- '"Will you walk a little faster?" said a whiting to a snail. "There's a porpoise close behind us, and he's treading on my tail. See how eagerly the lobsters and the turtles all advance! They are waiting on the shingle--will you come and join the dance? Will you, won't you, will you, won't you, will you join the dance? Will you, won't you, will you, won't you, won't you join the dance? "You can really have no notion how delightful it will be When they take us up and throw us, with the lobsters, out to sea!" But the snail replied "Too far, too far!" and gave a look askance-- Said he thanked the whiting kindly, but he would not join the dance. Would not, could not, would not, could not, would not join the dance. Would not, could not, would not, could not, could not join the dance. '"What matters it how far we go?" his scaly friend replied. "There is another shore, you know, upon the other side. The further off from England the nearer is to France-- Then turn not pale, beloved snail, but come and join the dance. Will you, won't you, will you, won't you, will you join the dance? Will you, won't you, will you, won't you, won't you join the dance?"' 'Thank you, it's a very interesting dance to watch,' said Alice, feeling very glad that it was over at last: 'and I do so like that curious song about the whiting!' 'Oh, as to the whiting,' said the Mock Turtle, 'they--you've seen them, of course?' 'Yes,' said Alice, 'I've often seen them at dinn--' she checked herself hastily. 'I don't know where Dinn may be,' said the Mock Turtle, 'but if you've seen them so often, of course you know what they're like.' 'I believe so,' Alice replied thoughtfully. 'They have their tails in their mouths--and they're all over crumbs.' 'You're wrong about the crumbs,' said the Mock Turtle: 'crumbs would all wash off in the sea. But they HAVE their tails in their mouths; and the reason is--' here the Mock Turtle yawned and shut his eyes.--'Tell her about the reason and all that,' he said to the Gryphon. 'The reason is,' said the Gryphon, 'that they WOULD go with the lobsters to the dance. So they got thrown out to sea. So they had to fall a long way. So they got their tails fast in their mouths. So they couldn't get them out again. That's all.' 'Thank you,' said Alice, 'it's very interesting. I never knew so much about a whiting before.' 'I can tell you more than that, if you like,' said the Gryphon. 'Do you know why it's called a whiting?' 'I never thought about it,' said Alice. 'Why?' 'IT DOES THE BOOTS AND SHOES.' the Gryphon replied very solemnly. Alice was thoroughly puzzled. 'Does the boots and shoes!' she repeated in a wondering tone. 'Why, what are YOUR shoes done with?' said the Gryphon. 'I mean, what makes them so shiny?' Alice looked down at them, and considered a little before she gave her answer. 'They're done with blacking, I believe.' 'Boots and shoes under the sea,' the Gryphon went on in a deep voice, 'are done with a whiting. Now you know.' 'And what are they made of?' Alice asked in a tone of great curiosity. 'Soles and eels, of course,' the Gryphon replied rather impatiently: 'any shrimp could have told you that.' 'If I'd been the whiting,' said Alice, whose thoughts were still running on the song, 'I'd have said to the porpoise, "Keep back, please: we don't want YOU with us!"' 'They were obliged to have him with them,' the Mock Turtle said: 'no wise fish would go anywhere without a porpoise.' 'Wouldn't it really?' said Alice in a tone of great surprise. 'Of course not,' said the Mock Turtle: 'why, if a fish came to ME, and told me he was going a journey, I should say "With what porpoise?"' 'Don't you mean "purpose"?' said Alice. 'I mean what I say,' the Mock Turtle replied in an offended tone. And the Gryphon added 'Come, let's hear some of YOUR adventures.' 'I could tell you my adventures--beginning from this morning,' said Alice a little timidly: 'but it's no use going back to yesterday, because I was a different person then.' 'Explain all that,' said the Mock Turtle. 'No, no! The adventures first,' said the Gryphon in an impatient tone: 'explanations take such a dreadful time.' So Alice began telling them her adventures from the time when she first saw the White Rabbit. She was a little nervous about it just at first, the two creatures got so close to her, one on each side, and opened their eyes and mouths so VERY wide, but she gained courage as she went on. Her listeners were perfectly quiet till she got to the part about her repeating 'YOU ARE OLD, FATHER WILLIAM,' to the Caterpillar, and the words all coming different, and then the Mock Turtle drew a long breath, and said 'That's very curious.' 'It's all about as curious as it can be,' said the Gryphon. 'It all came different!' the Mock Turtle repeated thoughtfully. 'I should like to hear her try and repeat something now. Tell her to begin.' He looked at the Gryphon as if he thought it had some kind of authority over Alice. 'Stand up and repeat "'TIS THE VOICE OF THE SLUGGARD,"' said the Gryphon. 'How the creatures order one about, and make one repeat lessons!' thought Alice; 'I might as well be at school at once.' However, she got up, and began to repeat it, but her head was so full of the Lobster Quadrille, that she hardly knew what she was saying, and the words came very queer indeed:-- ''Tis the voice of the Lobster; I heard him declare, "You have baked me too brown, I must sugar my hair." As a duck with its eyelids, so he with his nose Trims his belt and his buttons, and turns out his toes.' [later editions continued as follows When the sands are all dry, he is gay as a lark, And will talk in contemptuous tones of the Shark, But, when the tide rises and sharks are around, His voice has a timid and tremulous sound.] 'That's different from what I used to say when I was a child,' said the Gryphon. 'Well, I never heard it before,' said the Mock Turtle; 'but it sounds uncommon nonsense.' Alice said nothing; she had sat down with her face in her hands, wondering if anything would EVER happen in a natural way again. 'I should like to have it explained,' said the Mock Turtle. 'She can't explain it,' said the Gryphon hastily. 'Go on with the next verse.' 'But about his toes?' the Mock Turtle persisted. 'How COULD he turn them out with his nose, you know?' 'It's the first position in dancing.' Alice said; but was dreadfully puzzled by the whole thing, and longed to change the subject. 'Go on with the next verse,' the Gryphon repeated impatiently: 'it begins "I passed by his garden."' Alice did not dare to disobey, though she felt sure it would all come wrong, and she went on in a trembling voice:-- 'I passed by his garden, and marked, with one eye, How the Owl and the Panther were sharing a pie--' [later editions continued as follows The Panther took pie-crust, and gravy, and meat, While the Owl had the dish as its share of the treat. When the pie was all finished, the Owl, as a boon, Was kindly permitted to pocket the spoon: While the Panther received knife and fork with a growl, And concluded the banquet--] 'What IS the use of repeating all that stuff,' the Mock Turtle interrupted, 'if you don't explain it as you go on? It's by far the most confusing thing I ever heard!' 'Yes, I think you'd better leave off,' said the Gryphon: and Alice was only too glad to do so. 'Shall we try another figure of the Lobster Quadrille?' the Gryphon went on. 'Or would you like the Mock Turtle to sing you a song?' 'Oh, a song, please, if the Mock Turtle would be so kind,' Alice replied, so eagerly that the Gryphon said, in a rather offended tone, 'Hm! No accounting for tastes! Sing her "Turtle Soup," will you, old fellow?' The Mock Turtle sighed deeply, and began, in a voice sometimes choked with sobs, to sing this:-- 'Beautiful Soup, so rich and green, Waiting in a hot tureen! Who for such dainties would not stoop? Soup of the evening, beautiful Soup! Soup of the evening, beautiful Soup! Beau--ootiful Soo--oop! Beau--ootiful Soo--oop! Soo--oop of the e--e--evening, Beautiful, beautiful Soup! 'Beautiful Soup! Who cares for fish, Game, or any other dish? Who would not give all else for two Pennyworth only of beautiful Soup? Pennyworth only of beautiful Soup? Beau--ootiful Soo--oop! Beau--ootiful Soo--oop! Soo--oop of the e--e--evening, Beautiful, beauti--FUL SOUP!' 'Chorus again!' cried the Gryphon, and the Mock Turtle had just begun to repeat it, when a cry of 'The trial's beginning!' was heard in the distance. 'Come on!' cried the Gryphon, and, taking Alice by the hand, it hurried off, without waiting for the end of the song. 'What trial is it?' Alice panted as she ran; but the Gryphon only answered 'Come on!' and ran the faster, while more and more faintly came, carried on the breeze that followed them, the melancholy words:-- 'Soo--oop of the e--e--evening, Beautiful, beautiful Soup!' CHAPTER XI. Who Stole the Tarts? The King and Queen of Hearts were seated on their throne when they arrived, with a great crowd assembled about them--all sorts of little birds and beasts, as well as the whole pack of cards: the Knave was standing before them, in chains, with a soldier on each side to guard him; and near the King was the White Rabbit, with a trumpet in one hand, and a scroll of parchment in the other. In the very middle of the court was a table, with a large dish of tarts upon it: they looked so good, that it made Alice quite hungry to look at them--'I wish they'd get the trial done,' she thought, 'and hand round the refreshments!' But there seemed to be no chance of this, so she began looking at everything about her, to pass away the time. Alice had never been in a court of justice before, but she had read about them in books, and she was quite pleased to find that she knew the name of nearly everything there. 'That's the judge,' she said to herself, 'because of his great wig.' The judge, by the way, was the King; and as he wore his crown over the wig, (look at the frontispiece if you want to see how he did it,) he did not look at all comfortable, and it was certainly not becoming. 'And that's the jury-box,' thought Alice, 'and those twelve creatures,' (she was obliged to say 'creatures,' you see, because some of them were animals, and some were birds,) 'I suppose they are the jurors.' She said this last word two or three times over to herself, being rather proud of it: for she thought, and rightly too, that very few little girls of her age knew the meaning of it at all. However, 'jury-men' would have done just as well. The twelve jurors were all writing very busily on slates. 'What are they doing?' Alice whispered to the Gryphon. 'They can't have anything to put down yet, before the trial's begun.' 'They're putting down their names,' the Gryphon whispered in reply, 'for fear they should forget them before the end of the trial.' 'Stupid things!' Alice began in a loud, indignant voice, but she stopped hastily, for the White Rabbit cried out, 'Silence in the court!' and the King put on his spectacles and looked anxiously round, to make out who was talking. Alice could see, as well as if she were looking over their shoulders, that all the jurors were writing down 'stupid things!' on their slates, and she could even make out that one of them didn't know how to spell 'stupid,' and that he had to ask his neighbour to tell him. 'A nice muddle their slates'll be in before the trial's over!' thought Alice. One of the jurors had a pencil that squeaked. This of course, Alice could not stand, and she went round the court and got behind him, and very soon found an opportunity of taking it away. She did it so quickly that the poor little juror (it was Bill, the Lizard) could not make out at all what had become of it; so, after hunting all about for it, he was obliged to write with one finger for the rest of the day; and this was of very little use, as it left no mark on the slate. 'Herald, read the accusation!' said the King. On this the White Rabbit blew three blasts on the trumpet, and then unrolled the parchment scroll, and read as follows:-- 'The Queen of Hearts, she made some tarts, All on a summer day: The Knave of Hearts, he stole those tarts, And took them quite away!' 'Consider your verdict,' the King said to the jury. 'Not yet, not yet!' the Rabbit hastily interrupted. 'There's a great deal to come before that!' 'Call the first witness,' said the King; and the White Rabbit blew three blasts on the trumpet, and called out, 'First witness!' The first witness was the Hatter. He came in with a teacup in one hand and a piece of bread-and-butter in the other. 'I beg pardon, your Majesty,' he began, 'for bringing these in: but I hadn't quite finished my tea when I was sent for.' 'You ought to have finished,' said the King. 'When did you begin?' The Hatter looked at the March Hare, who had followed him into the court, arm-in-arm with the Dormouse. 'Fourteenth of March, I think it was,' he said. 'Fifteenth,' said the March Hare. 'Sixteenth,' added the Dormouse. 'Write that down,' the King said to the jury, and the jury eagerly wrote down all three dates on their slates, and then added them up, and reduced the answer to shillings and pence. 'Take off your hat,' the King said to the Hatter. 'It isn't mine,' said the Hatter. 'Stolen!' the King exclaimed, turning to the jury, who instantly made a memorandum of the fact. 'I keep them to sell,' the Hatter added as an explanation; 'I've none of my own. I'm a hatter.' Here the Queen put on her spectacles, and began staring at the Hatter, who turned pale and fidgeted. 'Give your evidence,' said the King; 'and don't be nervous, or I'll have you executed on the spot.' This did not seem to encourage the witness at all: he kept shifting from one foot to the other, looking uneasily at the Queen, and in his confusion he bit a large piece out of his teacup instead of the bread-and-butter. Just at this moment Alice felt a very curious sensation, which puzzled her a good deal until she made out what it was: she was beginning to grow larger again, and she thought at first she would get up and leave the court; but on second thoughts she decided to remain where she was as long as there was room for her. 'I wish you wouldn't squeeze so.' said the Dormouse, who was sitting next to her. 'I can hardly breathe.' 'I can't help it,' said Alice very meekly: 'I'm growing.' 'You've no right to grow here,' said the Dormouse. 'Don't talk nonsense,' said Alice more boldly: 'you know you're growing too.' 'Yes, but I grow at a reasonable pace,' said the Dormouse: 'not in that ridiculous fashion.' And he got up very sulkily and crossed over to the other side of the court. All this time the Queen had never left off staring at the Hatter, and, just as the Dormouse crossed the court, she said to one of the officers of the court, 'Bring me the list of the singers in the last concert!' on which the wretched Hatter trembled so, that he shook both his shoes off. 'Give your evidence,' the King repeated angrily, 'or I'll have you executed, whether you're nervous or not.' 'I'm a poor man, your Majesty,' the Hatter began, in a trembling voice, '--and I hadn't begun my tea--not above a week or so--and what with the bread-and-butter getting so thin--and the twinkling of the tea--' 'The twinkling of the what?' said the King. 'It began with the tea,' the Hatter replied. 'Of course twinkling begins with a T!' said the King sharply. 'Do you take me for a dunce? Go on!' 'I'm a poor man,' the Hatter went on, 'and most things twinkled after that--only the March Hare said--' 'I didn't!' the March Hare interrupted in a great hurry. 'You did!' said the Hatter. 'I deny it!' said the March Hare. 'He denies it,' said the King: 'leave out that part.' 'Well, at any rate, the Dormouse said--' the Hatter went on, looking anxiously round to see if he would deny it too: but the Dormouse denied nothing, being fast asleep. 'After that,' continued the Hatter, 'I cut some more bread-and-butter--' 'But what did the Dormouse say?' one of the jury asked. 'That I can't remember,' said the Hatter. 'You MUST remember,' remarked the King, 'or I'll have you executed.' The miserable Hatter dropped his teacup and bread-and-butter, and went down on one knee. 'I'm a poor man, your Majesty,' he began. 'You're a very poor speaker,' said the King. Here one of the guinea-pigs cheered, and was immediately suppressed by the officers of the court. (As that is rather a hard word, I will just explain to you how it was done. They had a large canvas bag, which tied up at the mouth with strings: into this they slipped the guinea-pig, head first, and then sat upon it.) 'I'm glad I've seen that done,' thought Alice. 'I've so often read in the newspapers, at the end of trials, "There was some attempts at applause, which was immediately suppressed by the officers of the court," and I never understood what it meant till now.' 'If that's all you know about it, you may stand down,' continued the King. 'I can't go no lower,' said the Hatter: 'I'm on the floor, as it is.' 'Then you may SIT down,' the King replied. Here the other guinea-pig cheered, and was suppressed. 'Come, that finished the guinea-pigs!' thought Alice. 'Now we shall get on better.' 'I'd rather finish my tea,' said the Hatter, with an anxious look at the Queen, who was reading the list of singers. 'You may go,' said the King, and the Hatter hurriedly left the court, without even waiting to put his shoes on. '--and just take his head off outside,' the Queen added to one of the officers: but the Hatter was out of sight before the officer could get to the door. 'Call the next witness!' said the King. The next witness was the Duchess's cook. She carried the pepper-box in her hand, and Alice guessed who it was, even before she got into the court, by the way the people near the door began sneezing all at once. 'Give your evidence,' said the King. 'Shan't,' said the cook. The King looked anxiously at the White Rabbit, who said in a low voice, 'Your Majesty must cross-examine THIS witness.' 'Well, if I must, I must,' the King said, with a melancholy air, and, after folding his arms and frowning at the cook till his eyes were nearly out of sight, he said in a deep voice, 'What are tarts made of?' 'Pepper, mostly,' said the cook. 'Treacle,' said a sleepy voice behind her. 'Collar that Dormouse,' the Queen shrieked out. 'Behead that Dormouse! Turn that Dormouse out of court! Suppress him! Pinch him! Off with his whiskers!' For some minutes the whole court was in confusion, getting the Dormouse turned out, and, by the time they had settled down again, the cook had disappeared. 'Never mind!' said the King, with an air of great relief. 'Call the next witness.' And he added in an undertone to the Queen, 'Really, my dear, YOU must cross-examine the next witness. It quite makes my forehead ache!' Alice watched the White Rabbit as he fumbled over the list, feeling very curious to see what the next witness would be like, '--for they haven't got much evidence YET,' she said to herself. Imagine her surprise, when the White Rabbit read out, at the top of his shrill little voice, the name 'Alice!' CHAPTER XII. Alice's Evidence 'Here!' cried Alice, quite forgetting in the flurry of the moment how large she had grown in the last few minutes, and she jumped up in such a hurry that she tipped over the jury-box with the edge of her skirt, upsetting all the jurymen on to the heads of the crowd below, and there they lay sprawling about, reminding her very much of a globe of goldfish she had accidentally upset the week before. 'Oh, I BEG your pardon!' she exclaimed in a tone of great dismay, and began picking them up again as quickly as she could, for the accident of the goldfish kept running in her head, and she had a vague sort of idea that they must be collected at once and put back into the jury-box, or they would die. 'The trial cannot proceed,' said the King in a very grave voice, 'until all the jurymen are back in their proper places--ALL,' he repeated with great emphasis, looking hard at Alice as he said do. Alice looked at the jury-box, and saw that, in her haste, she had put the Lizard in head downwards, and the poor little thing was waving its tail about in a melancholy way, being quite unable to move. She soon got it out again, and put it right; 'not that it signifies much,' she said to herself; 'I should think it would be QUITE as much use in the trial one way up as the other.' As soon as the jury had a little recovered from the shock of being upset, and their slates and pencils had been found and handed back to them, they set to work very diligently to write out a history of the accident, all except the Lizard, who seemed too much overcome to do anything but sit with its mouth open, gazing up into the roof of the court. 'What do you know about this business?' the King said to Alice. 'Nothing,' said Alice. 'Nothing WHATEVER?' persisted the King. 'Nothing whatever,' said Alice. 'That's very important,' the King said, turning to the jury. They were just beginning to write this down on their slates, when the White Rabbit interrupted: 'UNimportant, your Majesty means, of course,' he said in a very respectful tone, but frowning and making faces at him as he spoke. 'UNimportant, of course, I meant,' the King hastily said, and went on to himself in an undertone, 'important--unimportant--unimportant--important--' as if he were trying which word sounded best. Some of the jury wrote it down 'important,' and some 'unimportant.' Alice could see this, as she was near enough to look over their slates; 'but it doesn't matter a bit,' she thought to herself. At this moment the King, who had been for some time busily writing in his note-book, cackled out 'Silence!' and read out from his book, 'Rule Forty-two. ALL PERSONS MORE THAN A MILE HIGH TO LEAVE THE COURT.' Everybody looked at Alice. 'I'M not a mile high,' said Alice. 'You are,' said the King. 'Nearly two miles high,' added the Queen. 'Well, I shan't go, at any rate,' said Alice: 'besides, that's not a regular rule: you invented it just now.' 'It's the oldest rule in the book,' said the King. 'Then it ought to be Number One,' said Alice. The King turned pale, and shut his note-book hastily. 'Consider your verdict,' he said to the jury, in a low, trembling voice. 'There's more evidence to come yet, please your Majesty,' said the White Rabbit, jumping up in a great hurry; 'this paper has just been picked up.' 'What's in it?' said the Queen. 'I haven't opened it yet,' said the White Rabbit, 'but it seems to be a letter, written by the prisoner to--to somebody.' 'It must have been that,' said the King, 'unless it was written to nobody, which isn't usual, you know.' 'Who is it directed to?' said one of the jurymen. 'It isn't directed at all,' said the White Rabbit; 'in fact, there's nothing written on the OUTSIDE.' He unfolded the paper as he spoke, and added 'It isn't a letter, after all: it's a set of verses.' 'Are they in the prisoner's handwriting?' asked another of the jurymen. 'No, they're not,' said the White Rabbit, 'and that's the queerest thing about it.' (The jury all looked puzzled.) 'He must have imitated somebody else's hand,' said the King. (The jury all brightened up again.) 'Please your Majesty,' said the Knave, 'I didn't write it, and they can't prove I did: there's no name signed at the end.' 'If you didn't sign it,' said the King, 'that only makes the matter worse. You MUST have meant some mischief, or else you'd have signed your name like an honest man.' There was a general clapping of hands at this: it was the first really clever thing the King had said that day. 'That PROVES his guilt,' said the Queen. 'It proves nothing of the sort!' said Alice. 'Why, you don't even know what they're about!' 'Read them,' said the King. The White Rabbit put on his spectacles. 'Where shall I begin, please your Majesty?' he asked. 'Begin at the beginning,' the King said gravely, 'and go on till you come to the end: then stop.' These were the verses the White Rabbit read:-- 'They told me you had been to her, And mentioned me to him: She gave me a good character, But said I could not swim. He sent them word I had not gone (We know it to be true): If she should push the matter on, What would become of you? I gave her one, they gave him two, You gave us three or more; They all returned from him to you, Though they were mine before. If I or she should chance to be Involved in this affair, He trusts to you to set them free, Exactly as we were. My notion was that you had been (Before she had this fit) An obstacle that came between Him, and ourselves, and it. Don't let him know she liked them best, For this must ever be A secret, kept from all the rest, Between yourself and me.' 'That's the most important piece of evidence we've heard yet,' said the King, rubbing his hands; 'so now let the jury--' 'If any one of them can explain it,' said Alice, (she had grown so large in the last few minutes that she wasn't a bit afraid of interrupting him,) 'I'll give him sixpence. _I_ don't believe there's an atom of meaning in it.' The jury all wrote down on their slates, 'SHE doesn't believe there's an atom of meaning in it,' but none of them attempted to explain the paper. 'If there's no meaning in it,' said the King, 'that saves a world of trouble, you know, as we needn't try to find any. And yet I don't know,' he went on, spreading out the verses on his knee, and looking at them with one eye; 'I seem to see some meaning in them, after all. "--SAID I COULD NOT SWIM--" you can't swim, can you?' he added, turning to the Knave. The Knave shook his head sadly. 'Do I look like it?' he said. (Which he certainly did NOT, being made entirely of cardboard.) 'All right, so far,' said the King, and he went on muttering over the verses to himself: '"WE KNOW IT TO BE TRUE--" that's the jury, of course--"I GAVE HER ONE, THEY GAVE HIM TWO--" why, that must be what he did with the tarts, you know--' 'But, it goes on "THEY ALL RETURNED FROM HIM TO YOU,"' said Alice. 'Why, there they are!' said the King triumphantly, pointing to the tarts on the table. 'Nothing can be clearer than THAT. Then again--"BEFORE SHE HAD THIS FIT--" you never had fits, my dear, I think?' he said to the Queen. 'Never!' said the Queen furiously, throwing an inkstand at the Lizard as she spoke. (The unfortunate little Bill had left off writing on his slate with one finger, as he found it made no mark; but he now hastily began again, using the ink, that was trickling down his face, as long as it lasted.) 'Then the words don't FIT you,' said the King, looking round the court with a smile. There was a dead silence. 'It's a pun!' the King added in an offended tone, and everybody laughed, 'Let the jury consider their verdict,' the King said, for about the twentieth time that day. 'No, no!' said the Queen. 'Sentence first--verdict afterwards.' 'Stuff and nonsense!' said Alice loudly. 'The idea of having the sentence first!' 'Hold your tongue!' said the Queen, turning purple. 'I won't!' said Alice. 'Off with her head!' the Queen shouted at the top of her voice. Nobody moved. 'Who cares for you?' said Alice, (she had grown to her full size by this time.) 'You're nothing but a pack of cards!' At this the whole pack rose up into the air, and came flying down upon her: she gave a little scream, half of fright and half of anger, and tried to beat them off, and found herself lying on the bank, with her head in the lap of her sister, who was gently brushing away some dead leaves that had fluttered down from the trees upon her face. 'Wake up, Alice dear!' said her sister; 'Why, what a long sleep you've had!' 'Oh, I've had such a curious dream!' said Alice, and she told her sister, as well as she could remember them, all these strange Adventures of hers that you have just been reading about; and when she had finished, her sister kissed her, and said, 'It WAS a curious dream, dear, certainly: but now run in to your tea; it's getting late.' So Alice got up and ran off, thinking while she ran, as well she might, what a wonderful dream it had been. But her sister sat still just as she left her, leaning her head on her hand, watching the setting sun, and thinking of little Alice and all her wonderful Adventures, till she too began dreaming after a fashion, and this was her dream:-- First, she dreamed of little Alice herself, and once again the tiny hands were clasped upon her knee, and the bright eager eyes were looking up into hers--she could hear the very tones of her voice, and see that queer little toss of her head to keep back the wandering hair that WOULD always get into her eyes--and still as she listened, or seemed to listen, the whole place around her became alive with the strange creatures of her little sister's dream. The long grass rustled at her feet as the White Rabbit hurried by--the frightened Mouse splashed his way through the neighbouring pool--she could hear the rattle of the teacups as the March Hare and his friends shared their never-ending meal, and the shrill voice of the Queen ordering off her unfortunate guests to execution--once more the pig-baby was sneezing on the Duchess's knee, while plates and dishes crashed around it--once more the shriek of the Gryphon, the squeaking of the Lizard's slate-pencil, and the choking of the suppressed guinea-pigs, filled the air, mixed up with the distant sobs of the miserable Mock Turtle. So she sat on, with closed eyes, and half believed herself in Wonderland, though she knew she had but to open them again, and all would change to dull reality--the grass would be only rustling in the wind, and the pool rippling to the waving of the reeds--the rattling teacups would change to tinkling sheep-bells, and the Queen's shrill cries to the voice of the shepherd boy--and the sneeze of the baby, the shriek of the Gryphon, and all the other queer noises, would change (she knew) to the confused clamour of the busy farm-yard--while the lowing of the cattle in the distance would take the place of the Mock Turtle's heavy sobs. Lastly, she pictured to herself how this same little sister of hers would, in the after-time, be herself a grown woman; and how she would keep, through all her riper years, the simple and loving heart of her childhood: and how she would gather about her other little children, and make THEIR eyes bright and eager with many a strange tale, perhaps even with the dream of Wonderland of long ago: and how she would feel with all their simple sorrows, and find a pleasure in all their simple joys, remembering her own child-life, and the happy summer days. THE END End of Project Gutenberg's Alice's Adventures in Wonderland, by Lewis Carroll *** END OF THIS PROJECT GUTENBERG EBOOK ALICE'S ADVENTURES IN WONDERLAND ***

Foo BarWednesday, 19 September 2012 at 14:15 EDT

STAR WARS Episode IV A NEW HOPE From the JOURNAL OF THE WHILLS by George Lucas Revised Fourth Draft January 15, 1976 LUCASFILM LTD. A long time ago, in a galaxy far, far, away... A vast sea of stars serves as the backdrop for the main title. War drums echo through the heavens as a rollup slowly crawls into infinity. It is a period of civil war. Rebel spaceships, striking from a hidden base, have won their first victory against the evil Galactic Empire. During the battle, Rebel spies managed to steal secret plans to the Empire's ultimate weapon, the Death Star, an armored space station with enough power to destroy an entire planet. Pursued by the Empire's sinister agents, Princess Leia races home aboard her starship, custodian of the stolen plans that can save her people and restore freedom to the galaxy... The awesome yellow planet of Tatooine emerges from a total eclipse, her two moons glowing against the darkness. A tiny silver spacecraft, a Rebel Blockade Runner firing lasers from the back of the ship, races through space. It is pursed by a giant Imperial Stardestroyer. Hundreds of deadly laserbolts streak from the Imperial Stardestroyer, causing the main solar fin of the Rebel craft to disintegrate. INT. REBEL BLOCKADE RUNNER - MAIN PASSAGEWAY An explosion rocks the ship as two robots, Artoo-Detoo (R2- D2) and See-Threepio (C-3PO) struggle to make their way through the shaking, bouncing passageway. Both robots are old and battered. Artoo is a short, claw-armed tripod. His face is a mass of computer lights surrounding a radar eye. Threepio, on the other Hand, is a tall, slender robot of human proportions. He has a gleaming bronze-like metallic surface of an Art Deco design. Another blast shakes them as they struggle along their way. THREEPIO Did you hear that? They've shut down the main reactor. We'll be destroyed for sure. This is madness! Rebel troopers rush past the robots and take up positions in the main passageway. They aim their weapons toward the door. THREEPIO We're doomed! The little R2 unit makes a series of electronic sounds that only another robot could understand. THREEPIO There'll be no escape for the Princess this time. Artoo continues making beeping sounds. Tension mounts as loud metallic latches clank and the scream of heavy equipment are heard moving around the outside hull of the ship. THREEPIO What's that? EXT. SPACECRAFT IN SPACE The Imperial craft has easily overtaken the Rebel Blockade Runner. The smaller Rebel ship is being drawn into the underside dock of the giant Imperial starship. INT. REBEL BLOCKADE RUNNER The nervous Rebel troopers aim their weapons. Suddenly a tremendous blast opens up a hole in the main passageway and a score of fearsome armored spacesuited stormtroopers make their way into the smoke-filled corridor. In a few minutes the entire passageway is ablaze with laserfire. The deadly bolts ricochet in wild random patterns creating huge explosions. Stormtroopers scatter and duck behind storage lockers. Laserbolts hit several Rebel soldiers who scream and stagger through the smoke, holding shattered arms and faces. An explosion hits near the robots. THREEPIO I should have known better tHan to trust the logic of a half-sized thermocapsulary dehousing assister... Artoo counters with an angry rebuttal as the battle rages around the two hapless robots. EXT. TATOOINE - DESERT WASTELAND - DAY A death-white wasteland stretches from horizon to horizon. The tremendous heat of two huge twin suns settle on a lone figure, Luke Skywalker, a farm boy with heroic aspirations who looks much younger tHan his eighteen years. His shaggy hair and baggy tunic give him the air of a simple but lovable lad with a prize-winning smile. A light wind whips at him as he adjusts several valves on a large battered moisture vaporator which sticks out of the desert floor much like an oil pipe with valves. He is aided by a beatup tread-robot with six claw arms. The little robot appears to be barely functioning and moves with jerky motions. A bright sparkle in the morning sky catches Luke eye and he instinctively grabs a pair of electrobinoculars from his utility belt. He stands transfixed for a few moments studying the heavens, then dashed toward his dented, crudely repaired Landspeeder (an auto-like transport that travels a few feet above the ground on a magnetic-field). He motions for the tiny robot to follow him. LUKE Hurry up! Come with me! What are you waiting for?! Get in gear! The robot scoots around in a tight circle, stops short, and smoke begins to pour out of every joint. Luke throws his arms up in disgust. Exasperated, the young farm boy jumps into his Landspeeder leaving the smoldering robot to hum madly. INT. REBEL BLOCKADE RUNNER - MAIN HALLWAY The awesome, seven-foot-tall Dark Lord of the Sith makes his way into the blinding light of the main passageway. This is Darth Vader, right Hand of the Emperor. His face is obscured by his flowing black robes and grotesque breath mask, which stands out next to the fascist white armored suits of the Imperial stormtroopers. Everyone instinctively backs away from the imposing warrior and a deathly quiet sweeps through the Rebel troops. Several of the Rebel troops break and run in a frenzied panic. INT. REBEL BLOCKADE RUNNER A woman's Hand puts a card into an opening in Artoo's dome. Artoo makes beeping sounds. INT. REBEL BLOCKADE RUNNER Threepio stands in a hallway, somewhat bewildered. Artoo is nowhere in sight. The pitiful screams of the doomed Rebel soldiers can be heard in the distance. THREEPIO Artoo! Artoo-Detoo, where are you? A familiar clanking sound attacks Threepio's attention and he spots little Artoo at the end of the hallway in a smoke- filled alcove. A beautiful young girl (about sixteen years old) stands in front of Artoo. Surreal and out of place, dreamlike and half hidden in the smoke, she finishes adjusting something on Artoo's computer face, then watches as the little robot joins his companion. THREEPIO At last! Where have you been? Stormtroopers can be heard battling in the distance. THREEPIO They're heading in this direction. What are we going to do? We'll be sent to the spice mine of Kessel or smashed into who knows what! Artoo scoots past his bronze friend and races down the subhallway. Threepio chases after him. THREEPIO Wait a minute, where are you going? Artoo responds with electronic beeps. INT. REBEL BLOCKADE RUNNER - CORRIDOR The evil Darth Vader stands amid the broken and twisted bodies of his foes. He grabs a wounded Rebel Officer by the neck as an Imperial Officer rushes up to the Dark Lord. IMPERIAL OFFICER The Death Star plans are not in the main computer. Vader squeezes the neck of the Rebel Officer, who struggles in vain. VADER Where are those transmissions you intercepted? Vader lifts the Rebel off his feet by his throat. VADER What have you done with those plans? REBEL OFFICER We intercepted no transmissions. Aaah... This is a consular ship. Were on a diplomatic mission. VADER If this is a consular ship... were is the Ambassador? The Rebel refuses to speak but eventually cries out as the Dark Lord begins to squeeze the officer's throat, creating a gruesome snapping and choking, until the soldier goes limp. Vader tosses the dead soldier against the wall and turns to his troops. VADER Commander, tear this ship apart until you've found those plans and bring me the Ambassador. I want her alive! The stormtroopers scurry into the subhallways. INT. REBEL BLOCKADE RUNNER - SUBHALLWAY The lovely young girl huddles in a small alcove as the stormtroopers search through the ship. She is Princess Leia Organa, a member of the Alderaan Senate. The fear in her eyes slowly gives way to anger as the muted crushing sounds of the approaching stormtroopers grow louder. One of the troopers spots her. TROOPER There she is! Set for stun! Leia steps from her hiding place and blasts a trooper with her laser pistol. She starts to run but is felled by a paralyzing ray. The troopers inspect her inert body. TROOPER She'll be all right. Inform Lord Vader we have a prisoner. INT. REBEL BLOCKADE RUNNER - SUBHALLWAY Artoo stops before the small hatch of an emergency lifepod. He snaps the seal on the main latch and a red warning light begins to flash. The stubby astro-robot works his way into the cramped four-man pod. THREEPIO Hey, you're not permitted in there. It's restricted. You'll be deactivated for sure.. Artoo beeps something to him. THREEPIO Don't call me a mindless philosopher, you overweight glob of grease! Now come out before somebody sees you. Artoo whistles something at his reluctant friend regarding the mission he is about to perform. THREEPIO Secret mission? What plans? What are you talking about? I'm not getting in there! Artoo isn't happy with Threepio's stubbornness, and he beeps and twangs angrily. A new explosion, this time very close, sends dust and debris through the narrow subhallway. Flames lick at Threepio and, after a flurry of electronic swearing from Artoo, the lanky robot jumps into the lifepod. THREEPIO I'm going to regret this. INT. IMPERIAL STARDESTROYER On the main viewscreen, the lifepod carrying the two terrified robots speeds away from the stricken Rebel spacecraft. CHIEF PILOT There goes another one. CAPTAIN Hold your fire. There are no life forms. It must have been short- circuited. INT. LIFEPOD Artoo and Threepio look out at the receding Imperial starship. Stars circle as the pod rotates through the galaxy. THREEPIO That's funny, the damage doesn't look as bad from out here. Artoo beeps an assuring response. THREEPIO Are you sure this things safe? EXT. TATOOINE - ANCHORHEAD SETTLEMENT - POWER STATION - DAY Heat waves radiate from the dozen or so bleached white buildings. Luke pilots his Landspeeder through the dusty empty street of the tiny settlement. An old woman runs to get out of the way of the speeding vehicle, shaking her fist at Luke as he flies past. WOMAN I've told you kids to slow down! INT. POWER STATION - DAY Luke bursts into the power station, waking The Fixer, a rugged mecHanic and Camie, a sexy, disheveled girl who has been asleep in his lap. They grumbled as he races through the office, yelling wildly. FIXER Did I hear a young noise blast through here? CAMIE It was just wormie on another rampage. Luke bounces into a small room behind the office where Deak and Windy, two tough boys about the same age as Luke, are playing a computer pool-like game with Biggs, a burly, Handsome boy a few years older tHan the rest. His flashy city attire is a sharp contrast to the loose-fitting tunics of the farm boys. A robot repairs some equipment in the background. LUKE Shape it up you guys!... Biggs? Luke surprise at the appearance of Biggs gives way to great joy and emotion. They give each other a great bear hug. LUKE I didn't know you were back! When did you get in? BIGGS Just now. I wanted to surprise you, hot shot. I thought you'd be here... certainly didn't expect you to be out working. (he laughs) LUKE The Academy didn't cHange you much...but you're back so soon? Hey, what happened, didn't you get your commission? Biggs has an air of cool that seems slightly phony. BIGGS Of course I got it. Signed aboard The Rand Ecliptic last week. First mate Biggs Darklighter at your service... (he salutes) ...I just came to say good-bye to all you unfortunate landlocked simpletons. Everyone laughs. The dazzling spectacle of his dashing friend is almost too much for Luke, but suddenly he snaps out of it. LUKE I almost forgot. There's a battle going on! Right here in our system. Come and look! DEAK Not again! Forget it. EXT. TATOOINE - ANCHORHEAD - SETTLEMENT - POWER STATION - DAY The group stumbles out into the stifling desert sun. Camie and The Fixer complain and are forced to shade their eyes. Luke has his binoculars out scanning the heavens. LUKE There they are! Biggs takes the binoculars from Luke as the others strain to see something with the naked eye. Through the binoculars Biggs sees two small silver specks. BIGGS That's no battle, hot shot... they're just sitting there! Probably a freighter-tanker refueling. LUKE But there was a lot of firing earlier... Camie grabs the binoculars away banging them against the building in the process. Luke grabs them. LUKE Hey, easy with those... CAMIE Don't worry about it, Wormie. The Fixer gives Luke a hard look and the young farm boy shrugs his shoulders in resignation. FIXER I keep telling you, the Rebellion is a long way from here. I doubt if the Empire would even fight to keep this system. Believe me Luke, this planet is a big hunk of nothing... Luke agrees, although it's obvious he isn't sure why. The group stumbles back into the power station, grumbling about Luke ineptitude. INT. REBEL BLOCKADE RUNNER - HALLWAY Princess Leia is led down a low-ceilinged hallway by a squad of armored stormtroopers. Her Hands are bound and she is brutally shoved when she is unable to keep up with the briskly marching troops. They stop in a smoky hallway as Darth Vader emerges from the shadows. The sinister Dark Lord stares hard at the frail young senator, but she doesn't move. LEIA Lord Vader, I should have known. Only you could be so bold. The Imperial Senate will not sit for this, when they hear you've attacked a diplomatic... VADER Don't play games with me, Your Highness. You weren't on any mercy mission this time. You passed directly through a restricted system. Several transmissions were beamed to this ship by Rebel spies. I want to know what happened to the plans they sent you. LEIA I don't know what you're talking about. I'm a member of the Imperial Senate on a diplomatic mission to Alderaan... VADER You're a part of the Rebel Alliance... and a traitor. Take her away! Leia is marched away down the hallway and into the smoldering hole blasted in the side of the ship. An Imperial Commander turns to Vader. COMMANDER Holding her is dangerous. If word of this gets out, it could generate sympathy for the Rebellion in the senate. VADER I have traced the Rebel spies to her. Now she is my only link to find their secret base! COMMANDER She'll die before she tells you anything. VADER Leave that to me. Send a distress signal and then inform the senate that all aboard were killed! Another Imperial Officer approaches Vader and the Commander. They stop and snap to attention. SECOND OFFICER Lord Vader, the battle station plans are not aboard this ship! And no transmissions were made. An escape pod was jettisoned during the fighting, but no life forms were aboard. Vader turns to the Commander. VADER She must have hidden the plans in the escape pod. Send a detachment down to retrieve them. See to it personally, Commander. There'll be no one to stop us this time. COMMANDER Yes, sir. EXT. SPACE The Imperial Stardestroyer comes over the surface of the planet Tatooine. EXT. TATOOINE - DESERT Jundland, or "No Man's Land", where the rugged desert mesas meet the foreboding dune sea. The two helpless astro-droids kick up clouds of sand as they leave the lifepod and clumsily work their way across the desert wasteland. The lifepod in the distance rests half buried in the sand. THREEPIO How did I get into this mess? I really don't know how. We seem to be made to suffer. It's our lot in life. Artoo answers with beeping sounds. THREEPIO I've got to rest before I fall apart. My joints are almost frozen. Artoo continues to respond with beeping sounds. THREEPIO What a desolate place this is. Suddenly Artoo whistles, makes a sharp right turn and starts off in the direction of the rocky desert mesas. Threepio stops and yells at him. THREEPIO Where are you going? A stream of electronic noises pours forth from the small robot. THREEPIO Well, I'm not going that way. It's much too rocky. This way is much easier. Artoo counters with a long whistle. THREEPIO What makes you think there are settlements over there? Artoo continues to make beeping sounds. THREEPIO Don't get technical with me. Artoo continues to make beeping sounds. THREEPIO What mission? What are you talking about? I've had just about enough of you! Go that way! You'll be malfunctioning within a day, you nearsighted scrap pile! Threepio gives the little robot a kick and starts off in the direction of the vast dune sea. THREEPIO And don't let me catch you following me begging for help, because you won't get it. Artoo's reply is a rather rude sound. He turns and trudges off in the direction of the towering mesas. THREEPIO No more adventures. I'm not going that way. Artoo beeps to himself as he makes his way toward the distant mountains. EXT. TATOOINE - DUNE SEA Threepio, hot and tired, struggles up over the ridge of a dune; only to find more dunes, which seem to go on for endless miles. He looks back in the direction of the now distant rock mesas. THREEPIO That malfunctioning little twerp. This is all his fault! He tricked me into going this way, but he'll do no better. In a huff of anger and frustration, Threepio knocks the sand from his joints. His plight seems hopeless, when a glint of reflected light in the distance reveals an object moving towards him. THREEPIO Wait, what's that? A transport! I'm saved! The bronze android waves frantically and yells at the approaching transport. THREEPIO Over here! Help! Please, help! EXT. TATOOINE - ANCHORHEAD SETTLEMENT - POWER STATION - DAY Luke and Biggs are walking and drinking a malt brew. Fixer and the others can be heard working inside. LUKE (Very animated) ...so I cut off my power, shut down the afterburners and came in low on Deak's trail. I was so close I thought I was going to fry my instruments. As it was I busted up the Skyhopper pretty bad. Uncle Owen was pretty upset. He grounded me for the rest of the season. You should have been there... it was fantastic. BIGGS You ought to take it easy Luke. You may be the hottest bushpilot this side of Mos Eisley, but those little Skyhoppers are dangerous. Keep it up, and one day, whammo, you're going to be nothing more tHan a dark spot on the down side of a canyon wall. LUKE Look who's talking. Now that you've been around those giant starships you're beginning to sound like my uncle. You've gotten soft in the city... BIGGS I've missed you kid. LUKE Well, things haven't been the same since you left, Biggs. It's been so... quiet. Biggs looks around then leans close to Luke. BIGGS Luke, I didn't come back just to say good-bye... I shouldn't tell you this, but you're the only one I can trust... and if I don't come back, I want somebody to know. Luke eyes are wide with Biggs' seriousness and loyalty. LUKE What are you talking about? BIGGS I made some friends at the Academy. (he whispers) ...when our frigate goes to one of the central systems, we're going to jump ship and join the Alliance... Luke, amazed and stunned, is almost speechless. LUKE Join the Rebellion?! Are you kidding! How? BIGGS Quiet down will ya! You got a mouth bigger tHan a meteor crater! LUKE I'm sorry. I'm quiet. (he whispers) Listen how quiet I am. You can barely hear me... Biggs shakes his head angrily and then continues. BIGGS My friend has a friend on Bestine who might help us make contact. LUKE You're crazy! You could wander around forever trying to find them. BIGGS I know it's a long shot, but if I don't find them I'll do what I can on my own... It's what we always talked about. Luke, I'm not going to wait for the Empire to draft me into service. The Rebellion is spreading and I want to be on the right side -- the side I believe in. LUKE And I'm stuck here... BIGGS I thought you were going to the Academy next term. You'll get your cHance to get off this rock. LUKE Not likely! I had to cancel my application. There has been a lot of unrest among the Sandpeople since you left... they've even raided the outskirts of Anchorhead. BIGGS Your uncle could hold off a whole colony of Sandpeople with one blaster. LUKE I know, but he's got enough vaporators going to make the place pay off. He needs me for just one more season. I can't leave him now. BIGGS I feel for you, Luke, you're going to have to learn what seems to be important or what really is important. What good is all your uncle's work if it's taken over by the Empire?... You know they're starting to nationalize commerce in the central systems... it won't be long before your uncle is merely a tenant, slaving for the greater glory of the Empire. LUKE It couldn't happen here. You said it yourself. The Empire won't bother with this rock. BIGGS Things always cHange. LUKE I wish I was going... Are you going to be around long? BIGGS No, I'm leaving in the morning... LUKE Then I guess I won't see you. BIGGS Maybe someday... I'll keep a lookout. LUKE Well, I'll be at the Academy next season... after that who knows. I won't be drafted into the Imperial Starfleet that's for sure... Take care of yourself, you'll always be the best friend I've got. BIGGS So long, Luke. Biggs turns away from his old friend and heads towards the power station. EXT. TATOOINE - ROCK CANYON - SUNSET The gargantuan rock formations are shrouded in a strange foreboding mist and the onimous sounds of unearthly creatures fill the air. Artoo moves cautiously through the creepy rock canyon, inadvertently making a loud clicking noise as he goes. He hears a distant, hard, metallic sound and stops for a moment. Convinced he is alone, he continues on his way. In the distance, a pebble tumbles down the steep canyon wall and a small dark figure darts into the shadows. A little further up the canyon a slight flicker of light reveals a pair of eyes in the dark recesses only a few feet from the narrow path. The unsuspecting robot waddles along the rugged trail until suddenly, out of nowhere, a powerful magnetic ray shoots out of the rocks and engulfs him in an eerie glow. He manages one short electronic squeak before he topples over onto his back. His bright computer lights flicker off, then on, then off again. Out of the rocks scurry three Jawas, no taller tHan Artoo. They holster strange and complex weapons as they cautiously approach the robot. They wear grubby cloaks and their faces are shrouded so only their glowing eyes can be seen. They hiss and make odd guttural sounds as they heave the heavy robot onto their shoulders and carry him off down the trail. EXT. TATOOINE - ROCK CANYON - SANDCRAWLER - SUNSET The eight Jawas carry Artoo out of the canyon to a huge tank- like vehicle the size of a four-story house. They weld a small disk on the side of Artoo and then put him under a large tube on the side of the vehicle and the little robot is sucked into the giant machine. The filthy little Jawas scurry like rats up small ladders and enter the main cabin of the behemoth transport. INT. SANDCRAWLER - HOLD AREA It is dim inside the hold area of the Sandcrawler. Artoo switches on a small floodlight on his forehead and stumbles around the scrap heap. The narrow beam swings across rusty metal rocket parts and an array of grotesquely twisted and maimed astro-robots. He lets out a pathetic electronic whimper and stumbles off toward what appears to be a door at the end of the chamber. INT. SANDCRAWLER - PRISON AREA Artoo enters a wide room with a four-foot ceiling. In the middle of the scrap heap sit a dozen or so robots of various shapes and sizes. Some are engaged in electronic conversation, while others simply mill about. A voice of recognition calls out from the gloom. THREEPIO Artoo-Detoo! It's you! It's you! A battered Threepio scrambles up to Artoo and embraces him. EXT. TATOOINE - ROCK CANYON - SANDCRAWLER - SUNSET The enormous Sandcrawler lumbers off toward the magnificent twin suns, which are slowly setting over a distant mountain ridge. EXT. TATOOINE - DESERT - DAY Four Imperial stormtroopers mill about in front of the half- buried lifepod that brought Artoo and Threepio to Tatooine. A trooper yells to an officer some distance away. FIRST TROOPER Someone was in the pod. The tracks go off in this direction. A second trooper picks a small bit of metal out of the sand and gives it to the first trooper. SECOND TROOPER Look, sir -- droids. EXT. TATOOINE - DUNES The Sandcrawler moves slowly down a great sand dune. INT. SANDCRAWLER Threepio and Artoo noisily bounce along inside the cramped prison chamber. Artoo appears to be shut off. THREEPIO Wake up! Wake up! Suddenly the shaking and bouncing of the Sandcrawler stops, creating quite a commotion among the mecHanical men. Threepio's fist bangs the head of Artoo whose computer lights pop on as he begins beeping. At the far end of the long chamber a hatch opens, filling the chamber with blinding white light. a dozen or so Jawas make their way through the odd assortment of robots. THREEPIO We're doomed. A Jawa starts moving toward them. THREEPIO Do you think they'll melt us down? Artoo responds, making beeping sounds. THREEPIO Don't shoot! Don't shoot! Will this never end? EXT. TATOOINE - DESERT - LARS HOMESTEAD - AFTERNOON The Jawas mutter gibberish as they busily line up their battered captives, including Artoo and Threepio, in front of the enormous Sandcrawler, which is parked beside a small homestead consisting of three large holes in the ground surrounded by several tall moisture vaporators and one small adobe block house. The Jawas scurry around fussing over the robots, straightening them up or brushing some dust from a dented metallic elbow. The shrouded little creatures smell horribly, attracting small insects to the dark areas when their mouths and nostrils should be. Out of the shadows of a dingy side-building limps Owen Lars, a large burly man in his mid-fifties. His reddish eyes are sunken in a dust-covered face. As the farmer carefully inspects each robot, he is closely followed by his slump- shouldered nephew, Luke Skywalker. One of the vile little Jawas walks ahead of the farmer spouting an animated sales pitch in a queer, unintelligible language. A voice calls out from one of the huge holes that form the homestead. Luke goes over to the edge and sees his Aunt Beru standing in the main courtyard. BERU Luke, tell Owen that if he gets a translator to be sure it speaks Bocce. LUKE It looks like we don't have much of a choice but I'll remind him. Luke returns to his uncle as they look over the equipment for sale with the Jawa leader. OWEN I have no need for a protocol droid. THREEPIO (quickly) Sir -- not in an environment such as this -- that's why I've also been programmed for over thirty secondary functions that... OWEN What I really need is a droid that understands the binary language of moisture vaporators. THREEPIO Vaporators! Sir -- My first job was programming binary load lifter... very similar to your vaporators. You could say... OWEN Do you speak Bocce? THREEPIO Of course I can, sir. It's like a second language for me... I'm as fluent in Bocce... OWEN All right shut up! (turning to Jawa) I'll take this one. THREEPIO Shutting up, sir. OWEN Luke, take these two over to the garage, will you? I want you to have both of them cleaned up before dinner. LUKE But I was going into Toshi Station to pick up some power converters... OWEN You can waste time with your friends when your chores are done. Now come on, get to it! LUKE All right, come on! And the red one, come on. Well, come on, Red, let's go. As the Jawas start to lead the three remaining robots back into the Sandcrawler, Artoo lets out a pathetic little beep and starts after his old friend Threepio. He is restrained by a slimy Jawa, who zaps him with a control box. Owen is negotiating with the head Jawa. Luke and the two robots start off for the garage when a plate pops off the head of the red astro-droid's head plate and it sparks wildly. LUKE Uncle Owen... OWEN Yeah? LUKE This R2 unit has a bad motivator. Look! OWEN (to the head Jawa) Hey, what're you trying to push on us? The Jawa goes into a loud spiel. Meanwhile, Artoo has sneaked out of line and is moving up and down trying to attract attention. He lets out with a low whistle. Threepio taps Luke on the shoulder. THREEPIO (pointing to Artoo) Excuse me, sir, but that R2 unit is in prime condition. A real bargain. LUKE Uncle Owen... OWEN Yeah? LUKE What about that one? OWEN (to Jawa) What about that blue one? We'll take that one. With a little reluctance the scruffy dwarf trades the damaged astro-droid for Artoo. LUKE Yeah, take it away. THREEPIO Uh, I'm quite sure you'll be very pleased with that one, sir. He really is in first-class condition. I've worked with him before. Here he comes. Owen pays off the whining Jawa as Luke and the two robots trudge off toward a grimy homestead entry. LUKE Okay, let's go. THREEPIO (to Artoo) Now, don't you forget this! Why I should stick my neck out for you is quite beyond my capacity! INT. LARS HOMESTEAD - GARAGE AREA - LATE AFTERNOON The garage is cluttered and worn, but a friendly peaceful atmosphere permeates the low grey chamber. Threepio lowers himself into a large tub filled with warm oil. Near the battered Landspeeder little Artoo rests on a large battery with a cord to his face. THREEPIO THank the maker! This oil bath is going to feel so good. I've got such a bad case of dust contamination, I can barely move! Artoo beeps a muffled reply. Luke seems to be lost in thought as he runs his Hand over the damaged fin of a small two-man Skyhopper spaceship resting in a low Hangar off the garage. Finally Luke frustrations get the better of him and he slams a wrench across the workbench. LUKE It just isn't fair. Oh, Biggs is right. I'm never gonna get out of here! THREEPIO Is there anything I might do to help? Luke glances at the battered robot. A bit of his anger drains and a tiny smile creeps across his face. LUKE Well, not unless you can alter time, speed up the harvest, or teleport me off this rock! THREEPIO I don't think so, sir. I'm only a droid and not very knowledgeable about such things. Not on this planet, anyways. As a matter of fact, I'm not even sure which planet I'm on. LUKE Well, if there's a bright center to the universe, you're on the planet that it's farthest from. THREEPIO I see, sir. LUKE Uh, you can call me Luke. THREEPIO I see, sir Luke. LUKE (laughing) Just Luke. THREEPIO And I am See-Threepio, human-cyborg relations, and this is my counterpart, Artoo-Detoo. LUKE Hello. Artoo beeps in response. Luke unplugs Artoo and begins to scrape several connectors on the robot's head with a chrome pick. Threepio climbs out of the oil tub and begins wiping oil from his bronze body. LUKE You got a lot of carbon scoring here. It looks like you boys have seen a lot of action. THREEPIO With all we've been through, sometimes I'm amazed we're in as good condition as we are, what with the Rebellion and all. LUKE You know of the Rebellion against the Empire? THREEPIO That's how we came to be in your service, if you take my meaning, sir. LUKE Have you been in many battles? THREEPIO Several, I think. Actually, there's not much to tell. I'm not much more tHan an interpreter, and not very good at telling stories. Well, not at making them interesting, anyways. Luke struggles to remove a small metal fragment from Artoo's neck joint. He uses a larger pick. LUKE Well, my little friend, you've got something jammed in here real good. Were you on a cruiser or... The fragment breaks loose with a snap, sending Luke tumbling head over heels. He sits up and sees a twelve-inch three- dimensional hologram of Leia Organa, the Rebel senator, being projected from the face of little Artoo. The image is a rainbow of colors as it flickers and jiggles in the dimly lit garage. Luke mouth Hangs open in awe. LEIA Help me, Obi-Wan Kenobi. You're my only hope. LUKE What's this? Artoo looks around and sheepishly beeps an answer for Threepio to translate. Leia continues to repeat the sentence fragment over and over. THREEPIO What is what?!? He asked you a question... (pointing to Leia) What is that? Artoo whistles his surprise as he pretends to just notice the hologram. He looks around and sheepishly beeps an answer for Threepio to translate. Leia continues to repeat the sentence fragment over and over. LEIA Help me, Obi-Wan Kenobi. You're my only hope. Help me, Obi-Wan Kenobi. You're my only hope. THREEPIO Oh, he says it's nothing, sir. Merely a malfunction. Old data. Pay it no mind. Luke becomes intrigued by the beautiful girl. LUKE Who is she? She's beautiful. THREEPIO I'm afraid I'm not quite sure, sir. LEIA Help me, Obi-Wan Kenobi... THREEPIO I think she was a passenger on our last voyage. A person of some importance, sir -- I believe. Our captain was attached to... LUKE Is there more to this recording? Luke reaches out for Artoo but he lets out several frantic squeaks and a whistle. THREEPIO Behave yourself, Artoo. You're going to get us in trouble. It's all right, you can trust him. He's our new master. Artoo whistles and beeps a long message to Threepio. THREEPIO He says he's the property of Obi-Wan Kenobi, a resident of these parts. And it's a private message for him. Quite frankly, sir I don't know what he's talking about. Our last master was Captain Antilles, but with what we've been through, this little R2 unit has become a bit eccentric. LUKE Obi-Wan Kenobi? I wonder if he means old Ben Kenobi? THREEPIO I beg your pardon, sir, but do you know what he's talking about? LUKE Well, I don't know anyone named Obi- Wan, but old Ben lives out beyond the dune sea. He's kind of a strange old hermit. Luke gazes at the beautiful young princess for a few moments. LUKE I wonder who she is. It sounds like she's in trouble. I'd better play back the whole thing. Artoo beeps something to Threepio. THREEPIO He says the restraining bolt has short circuited his recording system. He suggests that if you remove the bolt, he might be able to play back the entire recording. Luke looks longingly at the lovely, little princess and hasn't really heard what Threepio has been saying. LUKE H'm? Oh, yeah, well, I guess you're too small to run away on me if I take this off! Okay. Luke takes a wedged bar and pops the restraining bolt off Artoo's side. LUKE There you go. The princess immediately disappears... LUKE Well, wait a minute. Where'd she go? Bring her back! Play back the entire message. Artoo beeps an innocent reply as Threepio sits up in embarrassment. THREEPIO What message? The one you're carrying inside your rusty innards! A women's voice calls out from another room. AUNT BERU Luke? Luke! Come to dinner! Luke stands up and shakes his head at the malfunctioning robot. LUKE All right, I'll be right there, Aunt Beru. THREEPIO I'm sorry, sir, but he appears to have picked up a slight flutter. Luke tosses Artoo's restraining bolt on the workbench and hurries out of the room. LUKE Well, see what you can do with him. I'll be right back. THREEPIO (to Artoo) Just you reconsider playing that message for him. Artoo beeps in response. THREEPIO No, I don't think he likes you at all. Artoo beeps. THREEPIO No, I don't like you either. INT. LARS HOMESTEAD - DINING AREA Luke Aunt Beru, a warm, motherly woman, fills a pitcher with blue fluid from a refrigerated container in the well- used kitchen. She puts the pitcher on a tray with some bowls of food and starts for the dining area. Luke sits with his Uncle Owen before a table covered with steaming bowls of food as Aunt Beru carries in a bowl of red grain. LUKE You know, I think that R2 unit we bought might have been stolen. OWEN What makes you think that? LUKE Well, I stumbled across a recording while I was cleaning him. He says he belongs to someone called Obi-Wan Kenobi. Owen is greatly alarmed at the mention of his name, but manages to control himself. LUKE I thought he might have meant old Ben. Do you know what he's talking about? Well, I wonder if he's related to Ben. Owen breaks loose with a fit of uncontrolled anger. OWEN That old man's just a crazy old wizard. Tomorrow I want you to take that R2 unit into Anchorhead and have its memory flushed. That'll be the end of it. It belongs to us now. LUKE But what if this Obi-Wan comes looking for him? OWEN He won't, I don't think he exists any more. He died about the same time as your father. LUKE He knew my father? OWEN I told you to forget it. Your only concern is to prepare the new droids for tomorrow. In the morning I want them on the south ridge working out those condensers. LUKE Yes, sir. I think those new droids are going to work out fine. In fact, I, uh, was also thinking about our agreement about my staying on another season. And if these new droids do work out, I want to transmit my application to the Academy this year. Owen's face becomes a scowl, although he tries to suppress it. OWEN You mean the next semester before harvest? LUKE Sure, there're more tHan enough droids. OWEN Harvest is when I need you the most. Only one more season. This year we'll make enough on the harvest so I'll be able to hire some more Hands. And then you can go to the Academy next year. Luke continues to toy with his food, not looking at his uncle. OWEN You must understand I need you here, Luke. LUKE But it's a whole 'nother year. OWEN Look, it's only one more season. Luke pushes his half-eaten plate of food aside and stands. LUKE Yeah, that's what you said last year when Biggs and Tank left. AUNT BERU Where are you going? LUKE It looks like I'm going nowhere. I have to finish cleaning those droids. Resigned to his fate, Luke paddles out of the room. Owen mecHanically finishes his dinner. AUNT BERU Owen, he can't stay here forever. Most of his friends have gone. It means so much to him. OWEN I'll make it up to him next year. I promise. AUNT BERU Luke just not a farmer, Owen. He has too much of his father in him. OWEN That's what I'm afraid of. EXT. TATOOINE - LARS HOMESTEAD The giant twin suns of Tatooine slowly disappear behind a distant dune range. Luke stands watching them for a few moments, then reluctantly enters the doomed entrance to the homestead. INT. LARS HOMESTEAD - GARAGE Luke enters the garage to discover the robots nowhere in sight. He takes a small control box from his utility belt similar to the one the Jawas were carrying. He activates the box, which creates a low hum, and Threepio, letting out a short yell, pops up from behind the Skyhopper spaceship. LUKE What are you doing hiding there? Threepio stumbles forward, but Artoo is still nowhere in sight. THREEPIO It wasn't my fault, sir. Please don't deactivate me. I told him not to go, but he's faulty, malfunctioning; kept babbling on about his mission. LUKE Oh, no! Luke races out of the garage followed by Threepio. EXT. TATOOINE - LARS HOMESTEAD Luke rushes out of the small doomed entry to the homestead and searches the darkening horizon for the small triped astro- robot. Threepio struggles out of the homestead and on the salt flat as Luke scans the landscape with his electrobinoculars. THREEPIO That R2 unit has always been a problem. These astro-droids are getting quite out of Hand. Even I can't understand their logic at times. LUKE How could I be so stupid? He's nowhere in sight. Blast it! THREEPIO Pardon me, sir, but couldn't we go after him? LUKE It's too dangerous with all the Sandpeople around. We'll have to wait until morning. Owen yells up from the homestead plaza. OWEN Luke, I'm shutting the power down for the night. LUKE All right, I'll be there in a few minutes. Boy, am I gonna get it. He takes one final look across the dim horizon. LUKE You know that little droid is going to cause me a lot of trouble. THREEPIO Oh, he excels at that, sir. INT. LARS HOMESTEAD - PLAZA Morning slowly creeps into the sparse but sparkling oasis of the open courtyard. The idyll is broken be the yelling of Uncle Owen, his voice echoing throughout the homestead. OWEN Luke? Luke? Luke? Where could he be loafing now! INT. LARS HOMESTEAD - KITCHEN The interior of the kitchen is a worm glow as Aunt Beru prepares the morning breakfast. Owen enters in a huff. OWEN Have you seen Luke this morning? AUNT BERU He said he had some things to do before he started today, so he left early. OWEN Uh? Did he take those two new droids with him? AUNT BERU I think so. OWEN Well, he'd better have those units in the south range repaired be midday or there'll be hell to pay! EXT. TATOOINE - DESERT WASTELAND - Luke SPEEDER - DAY The rock and sand of the desert floor are a blur as Threepio pilots the sleek Landspeeder gracefully across the vast wasteland. INT./EXT. Luke SPEEDER - DESERT WASTELAND - TRAVELING - DAY Luke leans over the back of the speeder and adjusts something in the motor compartment. LUKE (yelling) How's that. Threepio signals that is fine and Luke turns back into the wind-whipped cockpit and pops the canopy shut. LUKE Old Ben Kenobi lives out in this direction somewhere, but I don't see how that R2 unit could have come this far. We must have missed him. Uncle Owen isn't going to take this very well. THREEPIO Sir, would it help if you told him it was my fault. LUKE (brightening) Sure. He needs you. He'd probably only deactivate you for a day or so... THREEPIO Deactivate! Well, on the other Hand if you hadn't removed his restraining bolt... LUKE Wait, there's something dead ahead on the scanner. It looks like our droid... hit the accelerator. EXT. TATOOINE - ROCK MESA - DUNE SEA - COASTLINE - DAY From high on a rock mesa, the tiny Landspeeder can be seen gliding across the desert floor. Suddenly in the foreground two weather-beaten Sandpeople shrouded in their grimy desert cloaks peer over the edge of the rock mesa. One of the marginally human creatures raises a long ominous laser rifle and points it at the speeder but the second creature grabs the gun before it can be fired. The Sandpeople, or Tusken Raiders as they're sometimes called, speak in a coarse barbaric language as they get into an animated argument. The second Tusken Raider seems to get in the final word and the nomads scurry over the rocky terrain. EXT. TATOOINE - ROCK MESA - CANYON The Tusken Raider approaches two large Banthas standing tied to a rock. The monstrous, bear-like creatures are as large as elepHants, with huge red eyes, tremendous looped horns, and long, furry, dinosaur-like tails. The Tusken Raiders mount saddles strapped to the huge creatures' shaggy backs and ride off down the rugged bluff. EXT. TATOOINE - ROCK CANYON - FLOOR The speeder is parked on the floor of a massive canyon. Luke, with his long laser rifle slung over his shoulder, stands before little Artoo. LUKE Hey, whoa, just where do you think you're going? The little droid whistles a feeble reply, as Threepio poses menacingly behind the little runaway. THREEPIO Master Luke here is your rightful owner. We'll have no more of this Obi-Wan Kenobi jibberish... and don't talk to me about your mission, either. You're fortunate he doesn't blast you into a million pieces right here. LUKE Well, come on. It's getting late. I only hope we can get back before Uncle Owen really blows up. THREEPIO If you don't mind my saying so, sir, I think you should deactivate the little fugitive until you've gotten him back to your workshop. LUKE No, he's not going to try anything. Suddenly the little robot jumps to life with a mass of frantic whistles and screams. LUKE What's wrong with him now? THREEPIO Oh my... sir, he says there are several creatures approaching from the southeast. Luke swings his rifle into position and looks to the south. LUKE Sandpeople! Or worst! Come on, let's have a look. Come on. EXT. TATOOINE - ROCK CANYON - RIDGE - DAY Luke carefully makes his way to the top of a rock ridge and scans the canyon with his electrobinoculars. He spots the two riderless Banthas. Threepio struggles up behind the young adventurer. LUKE There are two Banthas down there but I don't see any... wait a second, they're Sandpeople all right. I can see one of them now. Luke watches the distant Tusken Raider through his electrobinoculars. Suddenly something huge moves in front of his field of view. Before Luke or Threepio can react, a large, gruesome Tusken Raider looms over them. Threepio is startled and backs away, right off the side if the cliff. He can be heard for several moments as he clangs, bangs and rattles down the side of the mountain. The towering creature brings down his curved, double-pointed gaderffii -- the dreaded axe blade that has struck terror in the heart of the local settlers. But Luke manages to block the blow with his laser rifle, which is smashed to pieces. The terrified farm boy scrambles backward until he is forced to the edge of a deep crevice. The sinister Raider stands over him with his weapon raised and lets out a horrible shrieking laugh. EXT. TATOOINE - ROCK CANYON - FLOOR - DAY Artoo forces himself into the shadows of a small alcove in the rocks as the vicious Sandpeople walk past carrying the inert Luke Skywalker, who is dropped in a heap before the speeder. The Sandpeople ransack the speeder, throwing parts and supplies in all directions. Suddenly they stop. Then everything is quiet for a few moments. A great howling moan is heard echoing throughout the canyon which sends the Sandpeople fleeing in terror. Artoo moves even tighter into the shadows as the slight swishing sound that frightened off the Sandpeople grows even closer, until a shabby old desert-rat-of-a-man appears and leans over Luke. His ancient leathery face, cracked and weathered by exotic climates is set off by dark, penetrating eyes and a scraggly white beard. Ben Kenobi squints his eyes as he scrutinizes the unconscious farm boy. Artoo makes a slight sound and Ben turns and looks right at him. BEN Hello there! Come here my little friend. Don't be afraid. Artoo waddles over to were Luke lies crumpled in a heap and begins to whistle and beep his concern. Ben puts his Hand on Luke forehead and he begins to come around. BEN Don't worry, he'll be all right. LUKE What happened? BEN Rest easy, son, you've had a busy day. You're fortunate you're still in one piece. LUKE Ben? Ben Kenobi! Boy, am I glad to see you! BEN The Jundland wastes are not to be traveled lightly. Tell me young Luke, what brings you out this far? LUKE Oh, this little droid! I think he's searching for his former master... I've never seen such devotion in a droid before... there seems to be no stopping him. He claims to be the property of an Obi-Wan Kenobi. Is he a relative of yours? Do you know who he's talking about? Ben ponders this for a moment, scratching his scruffy beard. BEN Obi-Wan Kenobi... Obi-Wan? Now thats a name I haven't heard in a long time... a long time. LUKE I think my uncle knew him. He said he was dead. BEN Oh, he's not dead, not... not yet. LUKE You know him! BEN Well of course, of course I know him. He's me! I haven't gone by the name Obi-Wan since oh, before you were born. LUKE Then the droid does belong to you. BEN Don't seem to remember ever owning a droid. Very interesting... He suddenly looks up at the overHanging cliffs. BEN I think we better get indoors. The Sandpeople are easily startled but they will soon be back and in greater numbers. Luke sits up and rubs his head. Artoo lets out a pathetic beep causing Luke to remember something. He looks around. LUKE Threepio! EXT. TATOOINE - SAND PIT - ROCK MESA - DAY Little Artoo stands at the edge of a large sand pit and begins to chatter away in electronic whistles and beeps. Luke and Ben stand over a very dented and tangled Threepio lying half buried in the sand. One of his arms has broken off. Luke tries to revive the inert robot by shaking him and then flips a hidden switch on his back several times until finally the mecHanical man's systems turn on. THREEPIO Where am I? I must have taken a bad step... LUKE Can you stand? We've got to get out of here before the Sandpeople return. THREEPIO I don't think I can make it. You go on, Master Luke. There's no sense in you risking yourself on my account. I'm done for. Artoo makes a beeping sound. LUKE No, you're not. What kind of talk is that? Luke and Ben help the battered robot to his feet. Little Artoo watches from the top of the pit. Ben glances around suspiciously. Sensing something, he stands up and sniffs the air. BEN Quickly, son... they're on the move. INT. KENOBI'S DWELLING The small, spartan hovel is cluttered with desert junk but still manages to radiate an air of time-worn comfort and security. Luke is in one corner repairing Threepio's arm, as old Ben sits thinking. LUKE No, my father didn't fight in the wars. He was a navigator on a spice freighter. BEN That's what your uncle told you. He didn't hold with your father's ideals. Thought he should have stayed here and not gotten involved. LUKE You fought in the Clone Wars? BEN Yes, I was once a Jedi Knight the same as your father. LUKE I wish I'd known him. BEN He was the best star-pilot in the galaxy, and a cunning warrior. I understand you've become quite a good pilot yourself. And he was a good friend. Which reminds me... Ben gets up and goes to a chest where he rummages around. As Luke finishes repairing Threepio and starts to fit the restraining bolt back on, Threepio looks at him nervously. Luke thinks about the bolt for a moment then puts it on the table. Ben shuffles up and presents Luke with a short Handle with several electronic gadgets attached to it. BEN I have something here for you. Your father wanted you to have this when you were old enough, but your uncle wouldn't allow it. He feared you might follow old Obi-Wan on some damned-fool idealistic crusade like your father did. THREEPIO Sir, if you'll not be needing me, I'll close down for awhile. LUKE Sure, go ahead. Ben Hands Luke the saber. LUKE What is it? BEN Your fathers lightsaber. This is the weapon of a Jedi Knight. Not as clumsy or as random as a blaster. Luke pushes a button on the Handle. A long beam shoots out about four feet and flickers there. The light plays across the ceiling. BEN An elegant weapon for a more civilized time. For over a thousand generations the Jedi Knights were the guardians of peace and justice in the Old Republic. Before the dark times, before the Empire. Luke hasn't really been listening. LUKE How did my father die? BEN A young Jedi named Darth Vader, who was a pupil of mine until he turned to evil, helped the Empire hunt down and destroy the Jedi Knights. He betrayed and murdered your father. Now the Jedi are all but extinct. Vader was seduced by the dark side of the Force. LUKE The Force? BEN Well, the Force is what gives a Jedi his power. It's an energy field created by all living things. It surrounds us and penetrates us. It binds the galaxy together. Artoo makes beeping sounds. BEN Now, let's see if we can't figure out what you are, my little friend. And where you come from. LUKE I saw part of the message he was... Luke is cut short as the recorded image of the beautiful young Rebel princess is projected from Artoo's face. BEN I seem to have found it. Luke stops his work as the lovely girl's image flickers before his eyes. LEIA General Kenobi, years ago you served my father in the Clone Wars. Now he begs you to help him in his struggle against the Empire. I regret that I am unable to present my father's request to you in person, but my ship has fallen under attack and I'm afraid my mission to bring you to Alderaan has failed. I have placed information vital to the survival of the Rebellion into the memory systems of this R2 unit. My father will know how to retrieve it. You must see this droid safely delivered to him on Alderaan. This is our most desperate hour. Help me, Obi-Wan Kenobi, you're my only hope. There is a little static and the transmission is cut short. Old Ben leans back and scratches his head. He silently puffs on a tarnished chrome water pipe. Luke has stars in his eyes. BEN You must learn the ways of the Force if you're to come with me to Alderaan. LUKE (laughing) Alderaan? I'm not going to Alderaan. I've got to go home. It's late, I'm in for it as it is. BEN I need your help, Luke. She needs your help. I'm getting too old for this sort of thing. LUKE I can't get involved! I've got work to do! It's not that I like the Empire. I hate it! But there's nothing I can do about it right now. It's such a long way from here. BEN That's your uncle talking. LUKE (sighing) Oh, God, my uncle. How am I ever going to explain this? BEN Learn about the Force, Luke. LUKE Look, I can take you as far as Anchorhead. You can get a transport there to Mos Eisley or wherever you're going. BEN You must do what you feel is right, of course. EXT. SPACE. An Imperial Stardestroyer heads toward the evil planet-like battle station: the Death Star! INT. DEATH STAR - CONFERENCE ROOM Eight Imperial senators and generals sit around a black conference table. Imperial stormtroopers stand guard around the room. Commander Tagge, a young, slimy-looking general, is speaking. TAGGE Until this battle station is fully operational we are vulnerable. The Rebel Alliance is too well equipped. They're more dangerous tHan you realize. The bitter Admiral Motti twists nervously in his chair. MOTTI Dangerous to your starfleet, Commander, not to this battle station! TAGGE The Rebellion will continue to gain a support in the Imperial Senate as long as.... Suddenly all heads turn as Commander Tagge's speech is cut short and the Grand Moff Tarkin, governor of the Imperial outland regions, enters. He is followed by his powerful ally, The Sith Lord, Darth Vader. All of the generals stand and bow before the thin, evil-looking governor as he takes his place at the head of the table. The Dark Lord stands behind him. TARKIN The Imperial Senate will no longer be of any concern to us. I've just received word that the Emperor has dissolved the council permanently. The last remnants of the Old Republic have been swept away. TAGGE That's impossible! How will the Emperor maintain control without the bureaucracy? TARKIN The regional governors now have direct control over territories. Fear will keep the local systems in line. Fear of this battle station. TAGGE And what of the Rebellion? If the Rebels have obtained a complete technical readout of this station, it is possible, however unlikely, that they might find a weakness and exploit it. VADER The plans you refer to will soon be back in our Hands. MOTTI Any attack made by the Rebels against this station would be a useless gesture, no matter what technical data they've obtained. This station is now the ultimate power in the universe. I suggest we use it! VADER Don't be too proud of this technological terror you've constructed. The ability to destroy a planet is insignificant next to the power of the Force. MOTTI Don't try to frighten us with your sorcerer's ways, Lord Vader. Your sad devotion to that ancient religion has not helped you conjure up the stolen data tapes, or given you clairvoyance enough to find the Rebel's hidden fort... Suddenly Motti chokes and starts to turn blue under Vader's spell. VADER I find your lack of faith disturbing. TARKIN Enough of this! Vader, release him! VADER As you wish. TARKIN This bickering is pointless. Lord Vader will provide us with the location of the Rebel fortress by the time this station is operational. We will then crush the Rebellion with one swift stroke. EXT. TATOOINE - WASTELAND The speeder stops before what remains of the huge Jawas Sandcrawler. Luke and Ben walk among the smoldering rubble and scattered bodies. LUKE It looks like Sandpeople did this, all right. Look, here are Gaffi sticks, Bantha tracks. It's just... I never heard of them hitting anything this big before. Ben is crouching in the sand studying the tracks. BEN They didn't. But we are meant to think they did. These tracks are side by side. Sandpeople always ride single file to hide there numbers. LUKE These are the same Jawas that sold us Artoo and Threepio. BEN And these blast points, too accurate for Sandpeople. Only Imperial stormtroopers are so precise. LUKE Why would Imperial troops want to slaughter Jawas? Luke looks back at the speeder where Artoo and Threepio are inspecting the dead Jawas, and put two and two together. LUKE If they traced the robots here, they may have learned who they sold them to. And that would lead them home! Luke reaches a sudden horrible realization, then races for the speeder and jumps it. BEN Wait, Luke! It's too dangerous. Luke races off leaving Ben and the two robots alone with the burning Sandcrawler. EXT. TATOOINE - WASTELAND Luke races across the wasteland in his battered Landspeeder. EXT. TATOOINE - LARS HOMESTEAD The speeder roars up to the burning homestead. Luke jumps out and runs to the smoking holes that were once his home. Debris is scattered everywhere and it looks as if a great battle has taken place. LUKE Uncle Owen! Aunt Beru! Uncle Owen! Luke stumbles around in a daze looking for his aunt and uncle. Suddenly he comes upon their smoldering remains. He is stunned, and cannot speak. Hate replaces fear and a new resolve comes over him. EXT. SPACE Imperial TIE fighter races toward the Death Star. INT. DEATH STAR - DETENTION CORRIDOR Two stormtroopers open an electronic cell door and allow several Imperial guards to enter. Princess Leia's face is filled with defiance, which slowly gives way to fear as a giant black torture robot enters, followed by Darth Vader. VADER And, now Your Highness, we will discuss the location of your hidden Rebel base. The torture robot gives off a steady beeping sound as it approaches Princess Leia and extends one of its mecHanical arms bearing a large hypodermic needle. The door slides shut and the long cell block hallway appears peaceful. The muffled screams of the Rebel princess are barely heard. EXT. TATOOINE - WASTELAND There is a large bonfire of Jawa bodies blazing in front of the Sandcrawler as Ben and the robots finish burning the dead. Luke drives up in the speeder and Ben walks over to him. BEN There's nothing you could have done, Luke, had you been there. You'd have been killed, too, and the droids would be in the Hands of the Empire. LUKE I want to come with you to Alderaan. There's nothing here for me now. I want to learn the ways of the Force and become a Jedi like my father. EXT. TATOOINE - WASTELAND The Landspeeder with Luke, Artoo, Threepio, and Ben in it zooms across the desert. The speeder stops on a bluff overlooking the spaceport at Mos Eisley. It is a haphazard array of low, grey, concrete structures and semi-domes. A harsh gale blows across the stark canyon floor. Luke adjusts his goggles and walks to the edge of the craggy bluff where Ben is standing. BEN Mos Eisley Spaceport. You will never find a more wretched hive of scum and villainy. We must be cautious. Ben looks over at Luke, who gives the old Jedi a determined smile. EXT. TATOOINE - MOS EISLEY - STREET The speeder is stopped on a crowded street by several combat- hardend stormtroopers who look over the two robots. A Trooper questions Luke. TROOPER How long have you had these droids? LUKE About three or four seasons. BEN They're for sale if you want them. TROOPER Let me see your identification. Luke becomes very nervous as he fumbles to find his ID while Ben speaks to the Trooper in a very controlled voice. BEN You don't need to see his identification. TROOPER We don't need to see his identification. BEN These are not the droids your looking for. TROOPER These are not the droids we're looking for. BEN He can go about his business. TROOPER You can go about your business. BEN (to Luke) Move along. TROOPER Move along. Move along. EXT. TATOOINE - MOS EISLEY - STREET The speeder pulls up in front of a rundown blockhouse cantina on the outskirts of the spaceport. Various strange forms of transport, including several unusual beasts of burden, are parked outside the bar. A Jawa runs up and begins to fondle the speeder. THREEPIO I can't abide these Jawas. Disgusting creatures. As Luke gets out of the speeder he tries to shoo the Jawa away. LUKE Go on, go on. I can't understand how we got by those troopers. I thought we were dead. BEN The Force can have a strong influence on the weak-minded. You will find it a powerful ally. LUKE Do you really think we're going to find a pilot here that'll take us to Alderaan? BEN Well, most of the best freighter pilots can be found here. Only watch your step. This place can be a little rough. LUKE I'm ready for anything. THREEPIO Come along, Artoo. INT. TATOOINE - MOS EISLEY - CANTINA The young adventurer and his two mecHanical servants follow Ben Kenobi into the smoke-filled cantina. The murky, moldy den is filled with a startling array of weird and exotic alien creatures and monsters at the long metallic bar. At first the sight is horrifying. One-eyed, thousand-eyed, slimy, furry, scaly, tentacled, and clawed creatures huddle over drinks. Ben moves to an empty spot at the bar near a group of repulsive but human scum. A huge, rough-looking Bartender stops Luke and the robots. BARTENDER We don't serve their kind here! Luke still recovering from the shock of seeing so many outlandish creatures, doesn't quite catch the bartender's drift. LUKE What? BARTENDER Your droids. They'll have to wait outside. We don't want them here. Luke looks at old Ben, who is busy talking to one of the Galactic pirates. He notices several of the gruesome creatures along the bar are giving him a very unfriendly glare. Luke pats Threepio on the shoulder. LUKE Listen, why don't you wait out by the speeder. We don't want any trouble. THREEPIO I heartily agree with you sir. Threepio and his stubby partner go outside and most of the creatures at the bar go back to their drinks. Ben is standing next to Chewbacca, an eight-foot-tall savage- looking creature resembling a huge grey bushbaby monkey with fierce baboon-like fangs. His large blue eyes dominate a fur- covered face and soften his otherwise awesome appearance. Over his matted, furry body he wears two chrome bandoliers, and little else. He is a two-hundred-year-old Wookiee and a sight to behold. Ben speaks to the Wookiee, pointing to Luke several times during his conversation and the huge creature suddenly lets out a horrifying laugh. Luke is more tHan a little bit disconcerted and pretends not to hear the conversation between Ben and the giant Wookiee. Luke is terrified but tries not to show it. He quietly sips his drink, looking over the crowd for a more sympathetic ear or whatever. A large, multiple-eyed Creature gives Luke a rough shove. CREATURE Negola dewaghi wooldugger?!? The hideous freak is obviously drunk. Luke tries to ignore the creature and turns back on his drink. A short, grubby Human and an even smaller rodent-like beast join the belligerent monstrosity. HUMAN He doesn't like you. LUKE I'm sorry. HUMAN I don't like you either. The big creature is getting agitated and yells out some unintelligible gibberish at the now rather nervous, young adventurer. HUMAN Don't insult us. You just watch yourself. We're wanted men. I have the death sentence in twelve systems. LUKE I'll be careful tHan. HUMAN You'll be dead. The rodent lets out a loud grunt and everything at the bar moves away. Luke tries to remain cool but it isn't easy. His three adversaries ready their weapons. Old Ben moves in behind Luke. BEN This little one isn't worth the effort. Come let me buy you something... A powerful blow from the unpleasant creature sends the young would-be Jedi sailing across the room, crashing through tables and breaking a large jug filled with a foul-looking liquid. With a blood curdling shriek, the monster draws a wicked chrome laser pistol from his belt and levels it at old Ben. The bartender panics. BARTENDER No blasters! No blaster! With astounding agility old Ben's laser sword sparks to life and in a flash an arm lies on the floor. The rodent is cut in two and the giant multiple-eyed creature lies doubled, cut from chin to groin. Ben carefully and precisely turns off his laser sword and replaces it on his utility belt. Luke, shaking and totally amazed at the old man's abilities, attempts to stand. The entire fight has lasted only a matter of seconds. The cantina goes back to normal, although Ben is given a respectable amount of room at the bar. Luke, rubbing his bruised head, approaches the old man with new awe. Ben points the the Wookiee. BEN This is Chewbacca. He's first-mate on a ship that might suit our needs. EXT. TATOOINE - MOS EISLEY - STREET Threepio paces in front of the cantina as Artoo carries on an electronic conversation with another little red astro- droid. A creature comes out of the cantina and approaches two stormtroopers in the street. THREEPIO I don't like the look of this. INT. TATOOINE - MOS EISLEY - CANTINA Strange creatures play exotic big band music on odd-looking instruments as Luke, still giddy, downs a fresh drink and follows Ben and Chewbacca to a booth where Han Solo is sitting. Han is a tough, roguish starpilot about thirty years old. A mercenary on a starship, he is simple, sentimental, and cocksure. Han Han Solo. I'm captain of the Millennium Falcon. Chewie here tells me you're looking for passage to the Alderaan system. BEN Yes, indeed. If it's a fast ship. Han Fast ship? You've never heard of the Millennium Falcon? BEN Should I have? Han It's the ship that made the Kessel run in less tHan twelve parsecs! Ben reacts to Solo's stupid attempt to impress them with obvious misinformation. Han I've outrun Imperial starships, not the local bulk-cruisers, mind you. I'm talking about the big Corellian ships now. She's fast enough for you, old man. What's the cargo? BEN Only passengers. Myself, the boy, two droids, and no questions asked. Han What is it? Some kind of local trouble? BEN Let's just say we'd like to avoid any Imperial entanglements. Han Well, that's the trick, isn't it? And it's going to cost you something extra. Ten thousand in advance. LUKE Ten thousand? We could almost buy our own ship for that! Han But who's going to fly it, kid! You? LUKE You bet I could. I'm not such a bad pilot myself! We don't have to sit here and listen... BEN We haven't that much with us. But we could pay you two thousand now, plus fifteen when we reach Alderaan. Han Seventeen, huh! Han ponders this for a few moments. Han Okay. You guys got yourself a ship. We'll leave as soon as you're ready. Docking bay Ninety-four. BEN Ninety-four. Han Looks like somebody's beginning to take an interest in your Handiwork. Ben and Luke turn around to see four Imperial stormtroopers looking at the dead bodies and asking the bartenders some questions. The bartender points to the booth. TROOPER All right, we'll check it out. The stormtroopers look over at the booth but Luke and Ben are gone. The bartender shrugs his shoulders in puzzlement. Han Seventeen thousand! Those guys must really be desperate. This could really save my neck. Get back to the ship and get her ready. EXT. TATOOINE - MOS EISLEY - STREET BEN You'll have to sell your speeder. LUKE That's okay. I'm never coming back to this planet again. INT. MOS EISLEY - CANTINA As Han is about to leave, Greedo, a slimy green-faced alien with a short trunk-nose, pokes a gun in his side. The creature speaks in a foreign tongue translated into English subtitles. GREEDO Going somewhere, Solo? Han Yes, Greedo. As a matter of fact, I was just going to see your boss. Tell Jabba that I've got his money. Han sits down and the alien sits across from him holding the gun on him. GREEDO It's too late. You should have paid him when you had the cHance. Jabba's put a price on your head, so large that every bounty hunter in the galaxy will be looking for you. I'm lucky I found you first. Han Yeah, but this time I got the money. GREEDO If you give it to me, I might forget I found you. Han I don't have it with me. Tell Jabba... GREEDO Jabba's through with you. He has no time for smugglers who drop their shipments at the first sign of an Imperial cruiser. Han Even I get boarded sometimes. Do you think I had a choice? Han Solo slowly reaches for his gun under the table. GREEDO You can tell that to Jabba. He may only take your ship. Han Over my dead body. GREEDO That's the idea. I've been looking forward to killing you for a long time. Han Yes, I'll bet you have. Suddenly the slimy alien disappears in a blinding flash of light. Han pulls his smoking gun from beneath the table as the other patron look on in bemused amazement. Han gets up and starts out of the cantina, flipping the bartender some coins as he leaves. Han Sorry about the mess. EXT. SPACE Several TIE fighters approach the Death Star. INT. DEATH STAR - CONTROL ROOM VADER Her resistance to the mind probe is considerable. It will be some time before we can extract any information from her. An Imperial Officer interrupts the meeting. IMPERIAL OFFICER The final check-out is complete. All systems are operational. What course shall we set? TARKIN Perhaps she would respond to an alternative form of persuasion. VADER What do you mean? TARKIN I think it is time we demonstrate the full power of this station. (to soldier) Set your course for Princess Leia's home planet of Alderaan. TROOPER With pleasure. EXT. TATOOINE - MOS EISLEY - STREET Four heavily-armed stormtroopers move menacingly along a narrow slum alleyway crowed with darkly clad creatures hawking exotic goods in the dingy little stalls. Men, monsters, and robots crouch in the waste-filled doorways, whispering and hiding from the hot winds. THREEPIO Lock the door, Artoo. One of the troopers checks a tightly locked door and moves on down the alleyway. The door slides open a crack and Threepio peeks out. Artoo is barely visible in the background. TROOPER All right, check that side of the street. It's secure. Move on to the next door. The door opens, Threepio moves into the doorway. THREEPIO I would much rather have gone with Master Luke tHan stay here with you. I don't know what all the trouble is about, but I'm sure it must be your fault. Artoo makes beeping sounds. THREEPIO You watch your language! EXT. TATOOINE - MOS EISLEY - STREET - ALLEYWAY - USED SPEEDER LOT Ben and Luke are standing in a sleazy used speeder lot, talking with a tall, grotesque, insect-like used speeder dealer. Strange exotic bodies and spindly-legged beasts pass by as the insect concludes the sale by giving Luke some coins. LUKE He says it's the best he can do. Since the XP-38 came out, they're just not in demand. BEN It will be enough. Ben and Luke leave the speeder lot and walk down the dusty alleyway past a small robot herding a bunch of anteater-like creatures. Luke turns and gives one last forlorn look at his faithful speeder as he rounds a corner. A darkly clad creature moves out of the shadows as they pass and watches them as they disappear down another alley. BEN If the ship's as fast as he's boasting, we ought to do well. INT. DOCKING BAY 94 - DAY Jabba the Hut and a half-dozen grisly alien pirates and purple creatures stand in the middle of the docking bay. Jabba is the grossest of the slavering hulks and his scarred face is a grim testimonial to his prowess as a vicious killer. He is a fat, slug-like creature with eyes on extended feelers and a huge ugly mouth. JABBA Come on out, Solo! A voice from directly behind the pirates startles them and they turn around to see Han Solo and the giant Wookiee, Chewbacca, standing behind them with no weapons in sight. Han I've been waiting for you, Jabba. JABBA I expected you would be. Han I'm not the type to run. JABBA (fatherly-smooth) Han, my boy, there are times when you disappoint me... why haven't you paid me? And why did you have to fry poor Greedo like that... after all we've been through together. Han You sent Greedo to blast me. JABBA (mock surprise) Han, why you're the best smuggler in the business. You're too valuable to fry. He was only relaying my concern at your delays. He wasn't going to blast you. Han I think he thought he was. Next time don't send one of those twerps. If you've got something to say to me, come see me yourself. JABBA Han, Han! If only you hadn't had to dump that shipment of spice... you understand I just can't make an exception. Where would I be if every pilot who smuggled for me dumped their shipment at the first sign of an Imperial starship? It's not good business. Han You know, even I get boarded sometimes, Jabba. I had no choice, but I've got a charter now and I can pay you back, plus a little extra. I just need some more time. JABBA (to his men) Put your blasters away. Han, my boy, I'm only doing this because you're the best and I need you. So, for an extra, say twenty percent I'll give you a little more time... but this is it. If you disappoint me again, I'll put a price on your head so large you won't be able to go near a civilized system for the rest of your short life. Han Jabba, I'll pay you because it's my pleasure. EXT. DOCKING PORT ENTRY - ALLEYWAY Chewbacca waits restlessly at the entrance to Docking Bay 94. Ben, Luke, and the robots make their way up the street. Chewbacca jabbers excitedly and signals for them to hurry. The darkly clad creature has followed them from the speeder lot. He stops in a nearby doorway and speaks into a small transmitter. INT. MOS EISLEY SPACEPORT - DOCKING BAY 94 Chewbacca leads the group into a giant dirt pit that is Docking Bay 94. Resting in the middle of the huge hole is a large, round, beat-up, pieced-together hunk of junk that could only loosely be called a starship. LUKE What a piece of junk. The tall figure of Han Solo comes down the boarding ramp. Han She'll make point five beyond the speed of light. She may not look like much, but she's got it where it counts, kid. I've added some special modifications myself. Luke scratches his head. It's obvious he isn't sure about all this. Chewbacca rushes up the ramp and urges the others to follow. Han We're a little rushed, so if you'll hurry aboard we'll get out of here. The group rushes up the gang plank, passing a grinning Han Solo. INT. MILLENNIUM FALCON Chewbacca settles into the pilot's chair and starts the mighty engines of the starship. INT. MOS EISLEY SPACEPORT - DOCKING BAY 94 Luke, Ben, Threepio, and Artoo move toward the Millennium Falcon passing Solo. THREEPIO Hello, sir. EXT. TATOOINE - MOS EISLEY - STREET Eight Imperial stormtroopers rush up to the darkly clad creature. TROOPER Which way? The darkly clad creature points to the door of the docking bay. TROOPER All right, men. Load your weapons! INT. MOS EISLEY SPACEPORT - DOCKING BAY 94] The troops hold their guns at the ready and charge down the docking bay entrance. TROOPER Stop that ship! Han Solo looks up and sees the Imperial stormtroopers rushing into the docking bay. Several of the troopers fire at Han as he ducks into the spaceship. TROOPER Blast 'em! Han draws his laser pistol and pops off a couple of shots which force the stormtroopers to dive for safety. The pirateship engines whine as Han hits the release button that slams the overhead entry shut. INT. MILLENNIUM FALCON Han Chewie, get us out of here! The group straps in for take off. THREEPIO Oh, my. I'd forgotten how much I hate space travel. EXT. TATOOINE - MOS EISLEY - STREETS The half-dozen stormtroopers at a check point hear the general alarm and look to the sky as the huge starship rises above the dingy slum dwellings and quickly disappears into the morning sky. INT. MILLENNIUM FALCON - COCKPIT Han climbs into the pilot's chair next to Chewbacca, who chatters away as he points to something on the radar scope. EXT. SPACE - PLANET TATOOINE The Corellian pirateship zooms from Tatooine into space. INT. MILLENNIUM FALCON - COCKPIT Han frantically types information into the ship's computer. Little Artoo appears momentarily at the cockpit doorway, makes a few beeping remarks, then scurries away. Han It looks like an Imperial cruiser. Our passengers must be hotter tHan I thought. Try and hold them off. Angle the deflector shield while I make the calculations for the jump to light speed. EXT. SPACE - PLANET TATOOINE The Millennium Falcon pirateship races away from the yellow planet, Tatooine. It is followed by two huge Imperial stardestroyers. INT. MILLENNIUM FALCON - COCKPIT Over the shoulders of Chewbacca and Han, we can see the galaxy spread before them. Luke and Ben make their way into the cramped cockpit where Han continues his calculation. Han Stay sharp! There are two more coming in; they're going to try to cut us off. LUKE Why don't you outrun them? I thought you said this thing was fast. Han Watch your mouth, kid, or you're going to find yourself floating home. We'll be safe enough once we make the jump to hyperspace. Besides, I know a few maneuvers. We'll lose them! EXT. SPACE - PLANET TATOOINE Imperial cruisers fire at the pirateship. INT. MILLENNIUM FALCON - COCKPIT The ship shudders as an explosion flashes outside the window. Han Here's where the fun begins! BEN How long before you can make the jump to light speed? Han It'll take a few moments to get the coordinates from the navi-computer. The ship begins to rock violently as lasers hit it. LUKE Are you kidding? At the rate they're gaining... Han Traveling through hyperspace isn't like dusting crops, boy! Without precise calculations we could fly right through a star or bounce too close to a supernova and that'd end your trip real quick, wouldn't it? The ship is now constantly battered with laserfire as a red warning light begins to flash. LUKE What's that flashing? Han We're losing our deflector shield. Go strap yourself in, I'm going to make the jump to light speed. The galaxy brightens and they move faster, almost as if crashing a barrier. Stars become streaks as the pirateship makes the jump to hyperspace. EXT. SPACE The Millennium Falcon zooms into infinity in less tHan a second. EXT. DEATH STAR Alderaan looms behind the Death Star battlestation. INT. DEATH STAR - CONTROL ROOM Admiral Motti enters the quiet control room and bows before Governor Tarkin, who stands before the huge wall screen displaying a small green planet. MOTTI We've entered the Alderaan system. Vader and two stormtroopers enter with Princess Leia. Her Hands are bound. LEIA Governor Tarkin, I should have expected to find you holding Vader's leash. I recognized your foul stench when I was brought on board. TARKIN Charming to the last. You don't know how hard I found it signing the order to terminate your life! LEIA I surprised you had the courage to take the responsibility yourself! TARKIN Princess Leia, before your execution I would like you to be my guest at a ceremony that will make this battle station operational. No star system will dare oppose the Emperor now. LEIA The more you tighten your grip, Tarkin, the more star systems will slip through your fingers. TARKIN Not after we demonstrate the power of this station. In a way, you have determined the choice of the planet that'll be destroyed first. Since you are reluctant to provide us with the location of the Rebel base, I have chosen to test this station's destructive power... on your home planet of Alderaan. LEIA No! Alderaan is peaceful. We have no weapons. You can't possibly... TARKIN You would prefer another target? A military target? Then name the system! Tarkin waves menacingly toward Leia. TARKIN I grow tired of asking this. So it'll be the last time. Where is the Rebel base? Leia overhears an intercom voice announcing the approach to Alderaan. LEIA (softly) Dantooine. Leia lowers her head. LEIA They're on Dantooine. TARKIN There. You see Lord Vader, she can be reasonable. (addressing Motti) Continue with the operation. You may fire when ready. LEIA What? TARKIN You're far too trusting. Dantooine is too remote to make an effective demonstration. But don't worry. We will deal with your Rebel friends soon enough. LEIA No! INT. DEATH STAR - BLAST CHAMBER VADER Commence primary ignition. A button is pressed which switches on a panel of lights. A hooded Imperial soldier reaches overhead and pulls a lever. Another lever is pulled. Vader reaches for still another lever and a bank of lights on a panel and wall light up. A huge beam of light emanates from within a cone-shaped area and converges into a single laser beam out toward Alderaan. The small green planet of Alderaan is blown into space dust. INT. MILLENNIUM FALCON - CENTRAL HOLD AREA Ben watches Luke practice the lightsaber with a small "seeker" robot. Ben suddenly turns away and sits down. He falters, seems almost faint. LUKE Are you all right? What's wrong? BEN I felt a great disturbance in the Force... as if millions of voices suddenly cried out in terror and were suddenly silenced. I fear something terrible has happened. Ben rubs his forehead. He seems to drift into a trance. Then he fixes his gaze on Luke. BEN You'd better get on with your exercises. Han Solo enters the room. Han Well, you can forget your troubles with those Imperial slugs. I told you I'd outrun 'em. Luke is once again practicing with the lightsaber. Han Don't everyone tHank me at once. Threepio watches Chewbacca and Artoo who are engrossed in a game in which three-dimensional holographic figures move along a chess-type board. Han Anyway, we should be at Alderaan about oh-two-hundred hours. Chewbacca and the two robots sit around the lighted table covered with small holographic monsters. Each side of the table has a small computer monitor embedded in it. Chewbacca seems very pleased with himself as he rests his lanky fur- covered arms over his head. THREEPIO Now be careful, Artoo. Artoo immediately reaches up and taps the computer with his stubby claw Hand, causing one of the holographic creatures to walk to the new square. A sudden frown crosses Chewbacca's face and he begins yelling gibberish at the tiny robot. Threepio intercedes on behalf of his small companion and begins to argue with the huge Wookiee. THREEPIO He made a fair move. Screaming about it won't help you. Han (interrupting) Let him have it. It's not wise to upset a Wookiee. THREEPIO But sir, nobody worries about upsetting a droid. Han That's 'cause droids don't pull people's arms out of their socket when they lose. Wookiees are known to do that. THREEPIO I see your point, sir. I suggest a new strategy, Artoo. Let the Wookiee win. Luke stands in the middle of the small hold area; he seems frozen in place. A humming lightsaber is held high over his head. Ben watches him from the corner, studying his movements. Han watches with a bit of smugness. BEN Remember, a Jedi can feel the Force flowing through him. LUKE You mean it controls your actions? BEN Partially. But it also obeys your commands. Suspended at eye level, about ten feet in front of Luke, a "seeker", a chrome baseball-like robot covered with antennae, hovers slowly in a wide arc. The ball floats to one side of the youth then the other. Suddenly it makes a lightning-swift lunge and stops within a few feet of Luke face. Luke doesn't move and the ball backs off. It slowly moves behind the boy, then makes another quick lunge, this time emitting a blood red laser beam as it attacks. It hits Luke in the leg causing him to tumble over. Han lets loose with a burst of laughter. Han Hokey religions and ancient weapons are no match for a good blaster at your side, kid. LUKE You don't believe in the Force, do you? Han Kid, I've flown from one side of this galaxy to the other. I've seen a lot of strange stuff, but I've never seen anything to make me believe there's one all-powerful force controlling everything. There's no mystical energy field that controls my destiny. Ben smiles quietly. Han It's all a lot of simple tricks and nonsense. BEN I suggest you try it again, Luke. Ben places a large helmet on Luke head which covers his eyes. BEN This time, let go your conscious self and act on instinct. LUKE (laughing) With the blast shield down, I can't even see. How am I supposed to fight? BEN Your eyes can deceive you. Don't trust them. Han skeptically shakes his head as Ben throws the seeker into the air. The ball shoots straight up in the air, then drops like a rock. Luke swings the lightsaber around blindly missing the seeker, which fires off a laserbolt which hits Luke square on the seat of the pants. He lets out a painful yell and attempts to hit the seeker. BEN Stretch out with your feelings. Luke stands in one place, seemingly frozen. The seeker makes a dive at Luke and, incredibly, he managed to deflect the bolt. The ball ceases fire and moves back to its original position. BEN You see, you can do it. Han I call it luck. BEN In my experience, there's no such thing as luck. Han Look, going good against remotes is one thing. Going good against the living? That's something else. Solo notices a small light flashing on the far side of the control panel. Han Looks like we're coming up on Alderaan. Han and Chewbacca head back to the cockpit. LUKE You know, I did feel something. I could almost see the remote. BEN That's good. You have taken your first step into a larger world. INT. DEATH STAR - CONFERENCE ROOM Imperial Officer Cass stands before Governor Tarkin and the evil Dark Lord Darth Vader. TARKIN Yes. OFFICER CASS Our scout ships have reached Dantooine. They found the remains of a Rebel base, but they estimate that it has been deserted for some time. They are now conducting an extensive search of the surrounding systems. TARKIN She lied! She lied to us! VADER I told you she would never consciously betray the Rebellion. TARKIN Terminate her... immediately! EXT. HYPERSPACE The pirateship is just coming out of hyperspace; a strange surreal light show surrounds the ship. INT. MILLENNIUM FALCON - COCKPIT Han Stand by, Chewie, here we go. Cut in the sublight engines. Han pulls back on a control lever. Outside the cockpit window stars begin streaking past, seem to decrease in speed, then stop. Suddenly the starship begins to shudder and violently shake about. Asteroids begin to race toward them, battering the sides of the ship. Han What the...? Aw, we've come out of hyperspace into a meteor shower. Some kind of asteroid collision. It's not on any of the charts. The Wookiee flips off several controls and seems very cool in the emergency. Luke makes his way into the bouncing cockpit. LUKE What's going on? Han Our position is correct, except... no, Alderaan! LUKE What do you mean? Where is it? Han Thats what I'm trying to tell you, kid. It ain't there. It's been totally blown away. LUKE What? How? Ben moves into the cockpit behind Luke as the ship begins to settle down. BEN Destroyed... by the Empire! Han The entire starfleet couldn't destroy the whole planet. It'd take a thousand ships with more fire power tHan I've... A signal starts flashing on the control panel and a muffled alarm starts humming. Han There's another ship coming in. LUKE Maybe they know what happened. BEN It's an Imperial fighter. Chewbacca barks his concern. A huge explosion bursts outside the cockpit window, shaking the ship violently. A tiny, finned Imperial TIE fighter races past the cockpit window. LUKE It followed us! BEN No. It's a short range fighter. Han There aren't any bases around here. Where did it come from? EXT. SPACE The fighter races past the Corellian pirateship. INT. MILLENNIUM FALCON - COCKPIT LUKE It sure is leaving in a big hurry. If they identify us, we're in big trouble. Han Not if I can help it. Chewie...jam it's transmissions. BEN It'd be as well to let it go. It's too far out of range. Han Not for long... EXT. SPACE The pirateship zooms over the camera and away into the vastness of space after the Imperial TIE fighter. INT. MILLENNIUM FALCON - COCKPIT The tension mounts as the pirateship gains on the tiny fighter. In the distance, one of the stars becomes brighter until it is obvious that the TIE ship is heading for it. Ben stands behind Chewbacca. BEN A fighter that size couldn't get this deep into space on its own. LUKE It must have gotten lost, been part of a convoy or something. Han Well, he ain't going to be around long enough to tell anyone about us. EXT. SPACE The TIE fighter is losing ground to the larger pirateship as they race toward camera and disappear over head. INT. MILLENNIUM FALCON - COCKPIT The distant star can be distinguished as a small moon or planet. LUKE Look at him. He's headed for that small moon. Han I think I can get him before he gets there... he's almost in range. The small moon begins to take on the appearance of a monstrous spherical battle station. BEN That's no moon! It's a space station. Han It's too big to be a space station. LUKE I have a very bad feeling about this. Han Yeah, I think your right. Full reverse! Chewie, lock in the auxiliary power. The pirateship shudders and the TIE fighter accelerates away toward the gargantuan battle station. LUKE Why are we still moving towards it? Han We're caught in a tractor beam! It's pulling us in! LUKE But there's gotta be something you can do! Han There's nothin' I can do about it, kid. I'm in full power. I'm going to have to shut down. But they're not going to get me without a fight! Ben Kenobi puts a Hand on his shoulder. BEN You can't win. But there are alternatives to fighting. INT. MILLENNIUM FALCON - DEATH STAR As the battered pirate starship is towed closer to the awesome metal moon, the immense size of the massive battle station becomes staggering. Running along the equator of the gigantic sphere is a mile-high band of huge docking ports into which the helpless pirateship is dragged. EXT. DEATH STAR - HUGE PORT DOORS The helpless Millennium Falcon is pulled past a docking port control room and huge laser turret cannons. VOICE OVER DEATH STAR INTERCOM Clear Bay twenty-three-seven. We are opening the magnetic field. INT. DEATH STAR - DOCKING BAY 2037 The pirateship is pulled in through port doors of the Death Star, coming to rest in a huge Hangar. Thirty stormtroopers stand at attention in a central assembly area. OFFICER To you stations! (to another officer) Come with me. INT. DEATH STAR - HALLWAY Stormtroopers run to their posts. INT. DEATH STAR - HanGAR 2037 A line of stormtroopers march toward the pirateship in readiness to board it, while other troopers stand with weapons ready to fire. OFFICER Close all outboard shields! Close all outboard shields! INT. DEATH STAR - CONFERENCE ROOM Tarkin pushes a button and responds to the intercom buzz. TARKIN Yes. VOICE (over intercom) We've captured a freighter entering the remains of the Alderaan system. It's markings match those of a ship that blasted its way out of Mos Eisley. VADER They must be trying to return the stolen plans to the princess. She may yet be of some use to us. INT. DEATH STAR - DOCKING BAY 2037 Vader and a commander approach the troops as an Officer and several heavily armed troops exit the spacecraft. VOICE (over intercom) Unlock one-five-seven and nine. Release charges. OFFICER (to Vader) There's no one on board, sir. According to the log, the crew abandoned ship right after takeoff. It must be a decoy, sir. Several of the escape pods have been jettisoned. VADER Did you find any droids? OFFICER No, sir. If there were any on board, they must also have jettisoned. VADER Send a scanning crew on board. I want every part of this ship checked. OFFICER Yes, sir. VADER I sense something... a presence I haven't felt since... Vader turns quickly and exits the Hangar. OFFICER Get me a scanning crew in here on the double. I want every part of this ship checked! INT. MILLENNIUM FALCON - HALLWAY A trooper runs through the hallway heading for the exit. In a few moments all is quiet. The muffled sounds of a distant officer giving orders finally fade. Two floor panels suddenly pop up revealing Han Solo and Luke. Ben Kenobi sticks his head out of a third locker. LUKE Boy, it's lucky you had these compartments. Han I use them for smuggling. I never thought I'd be smuggling myself in them. This is ridiculous. Even if I could take off, I'd never get past the tractor beam. BEN Leave that to me! Han Damn fool. I knew that you were going to say that! BEN Who's the more foolish... the fool or the fool who follows him? Han shakes his head, muttering to himself. Chewbacca agrees. INT. DEATH STAR - MAIN FORWARD BAY The crewmen carry a heavy box on board the ship, past the two stormtroopers guarding either side of the ramp. TROOPER The ship's all yours. If the scanners pick up anything, report it immediately. All right, let's go. The crewmen enter the pirateship and a loud crashing sound is followed by a voice calling to the guard below. Han'S VOICE Hey down there, could you give us a Hand with this? The stormtroopers enter the ship and a quick round of gunfire is heard. INT. DEATH STAR - FORWARD BAY - COMMAND OFFICE In a very small command office near the entrance to the pirateship, a Gantry Officer looks out his window and notices the guards are missing. He speaks into the comlink. GANTRY OFFICER TX-four-one-two. Why aren't you at your post? TX-four-one-two, do you copy? A stormtrooper comes down the ramp of the pirateship and waves to the gantry officer, pointing to his ear indicating his comlink is not working. The gantry officer shakes his head in disgust and heads for the door, giving his aide an annoyed look. GANTRY OFFICER Take over. We've got a bad transmitter. I'll see what I can do. As the officer approaches the door, it slides open revealing the towering Chewbacca. The gantry officer, in a momentary state of shock, stumbles backward. With a bone- chilling howl, the giant Wookiee flattens the officer with one blow. The aide immediately reaches for his pistol, but is blasted by Han, dressed as an Imperial stormtrooper. Ben and the robots enter the room quickly followed by Luke, also dressed as a stormtrooper. Luke quickly removes his helmet. LUKE You know, between his howling and your blasting everything in sight, it's a wonder the whole station doesn't know we're here. Han Bring them on! I prefer a straight fight to all this sneaking around. THREEPIO We found the computer outlet, sir. Ben feeds some information into the computer and a map of the city appears on the monitor. He begins to inspect it carefully. Threepio and Artoo look over the control panel. Artoo finds something that makes him whistle wildly. BEN Plug in. He should be able to interpret the entire Imperial computer network. Artoo punches his claw arm into the computer socket and the vast Imperial brain network comes to life, feeding information to the little robot. After a few moments, he beeps something. THREEPIO He says he's found the main computer to power the tractor beam that's holding the ship here. He'll try to make the precise location appear on the monitor. The computer monitor flashes readouts. THREEPIO The tractor beam is coupled to the main reactor in seven locations. A power loss at one of the terminals will allow the ship to leave. Ben studies the data on the monitor readout. BEN I don't think you boys can help. I must go alone. Han Whatever you say. I've done more that I bargained for on this trip already. LUKE I want to go with you. BEN Be patient, Luke. Stay and watch over the droids. LUKE But he can... BEN They must be delivered safely or other star systems will suffer the same fate as Alderaan. Your destiny lies along a different path tHan mine. The Force will be with you... always! Ben adjusts the lightsaber on his belt and silently steps out of the command office, then disappears down a long grey hallway. Chewbacca barks a comment and Han shakes his head in agreement. Han Boy you said it, Chewie. Han looks at Luke. Han Where did you dig up that old fossil? LUKE Ben is a great man. Han Yeah, great at getting us into trouble. LUKE I didn't hear you give any ideas... Han Well, anything would be better tHan just Hanging around waiting for him to pick us up... LUKE Who do you think... Suddenly Artoo begins to whistle and beep a blue streak. Luke goes over to him. LUKE What is it? THREEPIO I'm afraid I'm not quite sure, sir. He says "I found her", and keeps repeating, "She's here." LUKE Well, who... who has he found? Artoo whistles a frantic reply. THREEPIO Princess Leia. LUKE The princess? She's here? Han Princess? What's going on? THREEPIO Level five. Detention block A A-twenty- three. I'm afraid she's scheduled to be terminated. LUKE Oh, no! We've got to do something. Han What are you talking about? LUKE The droid belongs to her. She's the one in the message... We've got to help her. Han Now, look, don't get any funny ideas. The old man wants us to wait right here. LUKE But he didn't know she was here. Look, will you just find a way back into the detention block? Han I'm not going anywhere. LUKE They're going to execute her. Look, a few minutes ago you said you didn't want to just wait here to be captured. Now all you want to do is stay. Han Marching into the detention area is not what I had in mind. LUKE But they're going to kill her! Han Better her tHan me... LUKE She's rich. Chewbacca growls. Han Rich? LUKE Yes. Rich, powerful! Listen, if you were to rescue her, the reward would be... Han What? LUKE Well more wealth that you can imagine. Han I don't know, I can imagine quite a bit! LUKE You'll get it! Han I better! LUKE You will... Han All right, kid. But you'd better be right about this. Han looks at Chewie, who grunts a short grunt. LUKE All right. Han What's your plan? LUKE Uh... Threepio, Hand me those binders there will you? Luke moves toward Chewbacca with electronic cuffs. LUKE Okay. Now, I'm going to put these on you. Chewie lets out a hideous growl. LUKE Okay. Han, you put these on. Luke sheepishly Hands the binders to Han. Han Don't worry, Chewie. I think I know what he has in mind. The Wookiee has a worried and frightened look on his face as Han binds him with the electronic cuffs. THREEPIO Master Luke, sir! Pardon me for asking... but, ah... what should Artoo and I do if we're discovered here? LUKE Lock the door! Han And hope they don't have blasters. THREEPIO That isn't very reassuring. Luke and Han put on their armored stormtrooper helmets and start off into the giant Imperial Death Star. INT. DEATH STAR - DETENTION AREA - ELEVATOR TUBE Han and Luke try to look inconspicuous in their armored suits as they wait for a vacuum elevator to arrive. Troops, bureaucrats, and robots bustle about, ignoring the trio completely. Only a few give the giant Wookiee a curious glance. Finally a small elevator arrives and the trio enters. LUKE I can't see a thing in this helmet. A bureaucrat races to get aboard also, but is signaled away by Han. The door to the pod-like vehicle slides closed and the elevator car takes off through a vacuum tube. INT. DEATH STAR - MAIN HALLWAY Several Imperial officers walk through the wide main passageway. They pass several stormtroopers and a robot similar to Threepio but with an insect face. At the far end of the hallway, a passing flash of Ben Kenobi appears, then disappears down a small hallway. His appearance is so fleeting that it is hard to tell if he is real or just an illusion. No one in the hallway seems to notice him. INT. DEATH STAR - INTERIOR ELEVATOR - DETENTION SECURITY AREA Luke and Han step forward to exit the elevator, but the door slides open behind them. The giant Wookiee and his two guards enter the old grey security station. Guards and laser gates are everywhere. Han whispers to Luke under his breath. Han This is not going to work. LUKE Why didn't you say so before? Han I did say so before! INT. DETENTION AREA Elevator doors open. A tall, grim looking Officer approaches the trio. OFFICER Where are you taking this... thing? Chewie growls a bit at the remark but Han nudges him to shut up. LUKE Prisoner transfer from Block one-one- three-eight. OFFICER I wasn't notified. I'll have to clear it. The officer goes back to his console and begins to punch in the information. There are only three other troopers in the area. Luke and Han survey the situation, checking all of the alarms, laser gates, and camera eyes. Han unfastens one of Chewbacca's electronic cuffs and shrugs to Luke. Suddenly Chewbacca throws up his Hands and lets out with one of his ear-piercing howls. He grabs Han's laser rifle. Han Look out! He's loose! LUKE He's going to pull us all apart. Han Go get him! The startled guards are momentarily dumbfounded. Luke and Han have already pulled out their laser pistols and are blasting away at the terrifying Wookiee. Their barrage of laserfire misses Chewbacca, but hits the camera eyes, laser gate controls, and the Imperial guards. The officer is the last of the guards to fall under the laserfire just as he is about to push the alarm system. Han rushes to the comlink system, which is screeching questions about what is going on. He quickly checks the computer readout. Han We've got to find out which cell this princess of yours is in. Here it is... cell twenty-one-eight-seven. You go get her. I'll hold them here. Luke races down one of the cell corridors. Han speaks into the buzzing comlink. Han (sounding official) Everything is under control. Situation normal. INTERCOM VOICE What happened? Han (getting nervous) Uh... had a slight weapons malfunction. But, uh, everything's perfectly all right now. We're fine. We're all fine here, now, tHank you. How are you? INTERCOM VOICE We're sending a squad up. Han Uh, uh, negative. We had a reactor leak here now. Give us a few minutes to lock it down. Large leak... very dangerous. INTERCOM VOICE Who is this? What's your operating number? Han blasts the comlink and it explodes. Han Boring conversation anyway. (yelling down the hall) Luke! We're going to have company! INT. DEATH STAR - CELL ROW Luke stops in front of one of the cells and blasts the door away with a laser pistol. When the smoke clears, Luke sees the dazzling young princess-senator. She had been sleeping and is now looking at him with an uncomprehending look on her face. Luke is stunned by her incredible beauty and stands staring at her with his mouth Hanging open. LEIA (finally) Aren't you a little short to be a stormtrooper? Luke takes off his helmet, coming out of it. LUKE What? Oh... the uniform. I'm Luke Skywalker. I'm here to rescue you. LEIA You're who? LUKE I'm here to rescue you. I've got your R2 unit. I'm here with Ben Kenobi. LEIA Ben Kenobi is here! Where is he? LUKE Come on! INT. DEATH STAR - CONFERENCE ROOM Darth Vader paces the room as Governor Tarkin sits at the far end of the conference table. VADER He is here... TARKIN Obi-Wan Kenobi! What makes you think so? VADER A tremor in the Force. The last time I felt it was in the presence of my old master. TARKIN Surely he must be dead by now. VADER Don't underestimate the power of the Force. TARKIN The Jedi are extinct, their fire has gone out of the universe. You, my friend, are all that's left of their religion. There is a quiet buzz on the comlink. TARKIN Yes. INTERCOM VOICE Governor Tarkin, we have an emergency alert in detention block A A-twenty- three. TARKIN The princess! Put all sections on alert! VADER Obi-Wan is here. The Force is with him. TARKIN If you're right, he must not be allowed to escape. VADER Escape is not his plan. I must face him alone. INT. DEATH STAR - DETENTION AREA - HALLWAY An ominous buzzing sound is heard on the other side of the elevator door. Han Chewie! Chewbacca responds with a growling noise. Han Get behind me! Get behind me! A series of explosions knock a hole in the elevator door through which several Imperial troops begin to emerge. Han and Chewie fire laser pistols at them through the smoke and flame. They turn and run down the cell hallway, meeting up with Luke and Leia rushing toward them. Han Can't get out that way. LEIA Looks like you managed to cut off our only escape route. Han (sarcastically) Maybe you'd like it back in your cell, Your Highness. Luke takes a small comlink transmitter from his belt as they continue to excHange fire with stormtroopers making their way down the corridor. LUKE See-Threepio! See-Threepio! THREEPIO (over comlink) Yes sir? LUKE We've been cut off! Are there any other ways out of the cell bay?... What was that? I didn't copy! INT. DEATH STAR - MAIN BAY GANTRY - CONTROL TOWER Threepio paces the control center as little Artoo beeps and whistles a blue streak. Threepio yells into the small comlink transmitter. THREEPIO I said, all systems have been alerted to your presence, sir. The main entrance seems to be the only way in or out; all other information on your level is restricted. Someone begins banging on the door. TROOPER VOICE Open up in there! THREEPIO Oh, no! INT. DEATH STAR - DETENTION CORRIDOR Luke and Leia crouch together in an alcove for protection as they continue to excHange fire with troops. Han and Chewbacca are barely able to keep the stormtroopers at bay at the far and of the hallway. The laserfire is very intense, and smoke fills the narrow cell corridor. LUKE There isn't any other way out. Han I can't hold them off forever! Now what? LEIA This is some rescue. When you came in here, didn't you have a plan for getting out? Han (pointing to Luke) He's the brains, sweetheart. Luke manages a sheepish grin and shrugs his shoulders. LUKE Well, I didn't... The princess grabs Luke gun and fires at a small grate in the wall next to Han, almost frying him. Han What the hell are you doing? LEIA Somebody has to save our skins. Into the garbage chute, wise guy. She jumps through the narrow opening as Han and Chewbacca look on in amazement. Chewbacca sniffs the garbage chute and says something. Han Get in there you big furry oaf! I don't care what you smell! Get in there and don't worry about it. Han gives him a kick and the Wookiee disappears into the tiny opening. Luke and Han continue firing as they work their way toward the opening. Han Wonderful girl! Either I'm going to kill her or I'm beginning to like her. Get in there! Luke ducks laserfire as he jumps into the darkness. Han fires off a couple of quick blasts creating a smokey cover, then slides into the chute himself and is gone. INT. DEATH STAR - GARBAGE ROOM Han tumbles into the large room filled with garbage and muck. Luke is already stumbling around looking for an exit. He finds a small hatchway and struggles to get it open. It won't budge. Han (sarcastically) Oh! The garbage chute was a really wonderful idea. What an incredible smell you've discovered! Let's get out of here! Get away from there... LUKE No! wait! Han draws his laser pistol and fires at the hatch. The laserbolt ricochets wildly around the small metal room. Everyone dives for cover in the garbage as the bolt explodes almost on top of them. Leia climbs out of the garbage with a rather grim look on her face. LUKE Will you forget it? I already tried it. It's magnetically sealed! LEIA Put that thing away! You're going to get us all killed. Han Absolutely, Your Worship. Look, I had everything under control until you led us down here. You know, it's not going to take them long to figure out what happened to us. LEIA It could be worse... A loud, horrible, inhuman moan works its way up from the murky depths. Chewbacca lets out a terrified howl and begins to back away. Han and Luke stand fast with their laser pistols drawn. The Wookiee is cowering near one of the walls. Han It's worse. LUKE There's something alive in here! Han That's your imagination. LUKE Something just moves past my leg! Look! Did you see that? Han What? LUKE Help! Suddenly Luke is yanked under the garbage. Han Luke! Luke! Luke! Solo tries to get to Luke. Luke surfaces with a gasp of air and thrashing of limbs. A membrane tentacle is wrapped around his throat. LEIA Luke! Leia extends a long pipe toward him. LEIA Luke, Luke, grab a hold of this. LUKE Blast it, will you! My gun's jammed. Han Where? LUKE Anywhere! Oh!! Solo fires his gun downward. Luke is pulled back into the muck by the slimy tentacle. Han Luke! Luke! Suddenly the walls of the garbage receptacle shudder and move in a couple of inches. Then everything is deathly quiet. Han and Leia give each other a worried look as Chewbacca howls in the corner. With a rush of bubbles and muck Luke suddenly bobs to the surface. LEIA Grab him! Luke seems to be released by the thing. LEIA What happened? LUKE I don't know, it just let go of me and disappeared... Han I've got a very bad feeling about this. Before anyone can say anything the walls begin to rumble and edge toward the Rebels. LUKE The walls are moving! LEIA Don't just stand there. Try to brace it with something. They place poles and long metal beams between the closing walls, but they are simply snapped and bent as the giant trashmasher rumbles on. The situation doesn't look too good. LUKE Wait a minute! Luke pulls out his comlink. LUKE Threepio! Come in Threepio! Threepio! Where could he be? INT. DEATH STAR - MAIN GANTRY - COMMAND OFFICE A soft buzzer and the muted voice of Luke calling out for See-Threepio can be heard on Threepio's Hand comlink, which is sitting on the deserted computer console. Artoo and Threepio are nowhere in sight. Suddenly there is a great explosion and the door of the control tower flies across the floor. Four armed stormtroopers enter the chamber. FIRST TROOPER Take over! (pointing to the dead officer) See to him! Look there! A trooper pushes a button and the supply cabinet door slides open. See-Threepio and Artoo-Detoo are inside. Artoo follows his bronze companion out into the office. THREEPIO They're madmen! They're heading for the prison level. If you hurry, you might catch them. FIRST OFFICER (to his troops) Follow me! You stand guard. The troops hustle off down the hallway, leaving a guard to watch over the command office. THREEPIO (to Artoo) Come on! The guard aims a blaster at them. THREEPIO Oh! All this excitement has overrun the circuits of my counterpart here. If you don't mind, I'd like to take him down to maintenance. TROOPER All right. The guard nods and Threepio, with little Artoo in tow, hurries out the door. INT. DEATH STAR - GARBAGE ROOM As the walls rumble closed, the room gets smaller and smaller. Chewie is whining and trying to hold a wall back with his giant paws. Han is leaning back against the other wall. Garbage is snapping and popping. Luke is trying to reach Threepio. LUKE Threepio! Come in, Threepio! Threepio! Han and Leia try to brace the contracting walls with a pole. Leia begins to sink into the trash. Han Get to the top! LEIA I can't LUKE Where could he be? Threepio! Threepio, will you come in? INT. DEATH STAR - MAIN FORWARD BAY - SERVICE PANEL THREEPIO They aren't here! Something must have happened to them. See if they've been captured. Little Artoo carefully plugs his claw arm into a new wall socket and a complex array of electronic sounds spew from the tiny robot. THREEPIO Hurry! INT. DEATH STAR - GARBAGE ROOM The walls are only feet apart. Leia and Han are braced against the walls. The princess is frightened. They look at each other. Leia reaches out and takes Han's Hand and she holds it tightly. She's terrified and suddenly groans as she feels the first crushing pressure against her body. Han One thing's for sure. We're all going to be a lot thinner! (to Leia) Get on top of it! LEIA I'm trying! INT. DEATH STAR - MAIN FORWARD BAY - SERVICE PANEL THREEPIO (to Artoo) THank goodness, they haven't found them! Where could they be? Artoo frantically beeps something to See-Threepio. THREEPIO Use the comlink? Oh, my! I forgot I turned it off! INT. DEATH STAR - GARBAGE ROOM Meanwhile, Luke is lying on his side, trying to keep his head above the rising ooze. Luke comlink begins to buzz and he rips it off his belt. INT. DEATH STAR - MAIN FORWARD BAY - SERVICE PANEL Muffled sounds of Luke voice over the comlink can be heard, but not distinctly. THREEPIO Are you there, sir? INT. DEATH STAR - GARBAGE ROOM LUKE Threepio! INT. DEATH STAR - MAIN FORWARD BAY - SERVICE PANEL THREEPIO We've had some problems... LUKE (over comlink) Will you shut up and listen to me? Shut down all garbage mashers on the detention level, will you? Do you copy? INT. DEATH STAR - GARBAGE ROOM LUKE Shut down all the garbage mashers on the detention level. INT. DEATH STAR - MAIN FORWARD BAY - SERVICE PANEL LUKE (over comlink) Shut down all the garbage mashers on the detention level. THREEPIO (to Artoo) No. Shut them all down! Hurry! Threepio holds his head in agony as he hears the incredible screaming and hollering from Luke comlink. THREEPIO Listen to them! They're dying, Artoo! Curse my metal body! I wasn't fast enough. It's all my fault! My poor master! LUKE (over comlink) Threepio, we're all right! INT. DEATH STAR - GARBAGE ROOM The screaming and hollering is the sound of joyous relief. The walls have stopped moving. Han, Chewie and Leia embrace in the background. LUKE We're all right. You did great. Luke moves to the pressure sensitive hatch, looking for a number. LUKE Hey... hey, open the pressure maintenance hatch on unit number... where are we? INT. DEATH STAR - MAIN FORWARD BAY - SERVICE PANEL Han (over comlink) Three-two-six-eight-two-seven. INT. DEATH STAR - TRACTOR BEAM - POWER GENERATOR TRENCH Ben enters a humming service trench that powers the huge tractor beam. The trench seems to be a hundred miles deep. The clacking sound of huge switching devices can be heard. The old Jedi edges his his way along a narrow ledge leading to a control panel that connects two large cables. He carefully makes several adjustments in the computer terminal, and several lights on the board go from red to blue. INT. DEATH STAR - UNUSED HALLWAY The group exits the garbage room into a dusty, unused hallway. Han and Luke remove the trooper suits and strap on the blaster belts. Han If we can just avoid any more female advice, we ought to be able to get out of here. Luke smiles and scratches his head as he takes a blaster from Solo. LUKE Well, let's get moving! Chewie begins growling and points to the hatch to the garbage room, as he runs away and then stops howling. Han (to Chewie) Where are you going? The Dia Nogu bangs against the hatch and a long, slimy tentacle works its way out of the doorway searching for a victim. Han aims his pistol. LEIA No, wait. They'll hear! Han fires at the doorway. The noise of the blast echoes relentlessly throughout the empty passageway. Luke simply shakes his head in disgust. Han (to Chewie) Come here, you big coward! Chewie shakes his head "no." Han Chewie! Come here! LEIA Listen. I don't know who you are, or where you came from, but from now on, you do as I tell you. Okay? Han is stunned at the command of the petite young girl. Han Look, Your Worshipfulness, let's get one thing straight! I take orders from one person! Me! LEIA It's a wonder you're still alive. (looking at Chewie) Will somebody get this big walking carpet out of my way? Han watches her start away. He looks at Luke. Han No reward is worth this. They follow her, moving swiftly down the deserted corridor. INT. DEATH STAR - POWER TRENCH Suddenly a door behind Ben slides open and a detachment of stormtroopers marches to the power trench. Ben instantly slips into the shadows as an Officer moves to within a few feet of him. OFFICER Secure this area until the alert is canceled. FIRST TROOPER Give me regular reports. All but two of the stormtroopers leave. FIRST TROOPER Do you know what's going on? SECOND TROOPER Maybe it's another drill. Ben moves around the tractor beam, watching the stormtroopers as they turn their backs to him. Ben gestures with his Hand toward them, as the troops think they hear something in the other hallway. With the help of the Force, Ben deftly slips past the troopers and into the main hallway. SECOND TROOPER What was that? FIRST TROOPER Oh, it's nothing. Don't worry about it. INT. DEATH STAR - HALLWAY Luke, Han, Chewbacca, and Leia run down an empty hallway and stop before a bay window overlooking the pirateship. Troopers are milling about the ship. Luke takes out his pocket comlink. Han (looking at his ship) There she is. LUKE See-Threepio, do you copy? THREEPIO (voice) For the moment. Uh, we're in the main Hangar across from the ship. LUKE We're right above you. Stand by. Han is watching the dozen or so troops moving in and out of the pirateship. Leia moves towards Han, touches his arm and points out the window to the ship. LEIA You came in that thing? You're braver that I thought. Han Nice! Come on! Han gives her a dirty look, and they start off down the hallway. They round a corner and run right into twenty Imperial stormtroopers heading toward them. Both groups are taken by surprise and stop in their tracks. FIRST TROOPER It's them! Blast them! Before even thinking, Han draws his laser pistol and charges the troops, firing. His blaster knocks one of the stormtroopers into the air. Chewie follows his captain down the corridor, stepping over the fallen trooper on the floor. Han (to Luke and Leia) Get back to the ship! LUKE Where are you going? Come back! Han has already rounded a corner and does not hear. LEIA He certainly has courage. LUKE What good will it do us if he gets himself killed? Come on! Luke is furious but doesn't have time to think about it for muted alarms begin to go off down on the Hangar deck. Luke and Leia start off toward the starship Hangar. INT. DEATH STAR - SUBHALLWAY Han chases the stormtroopers down a long subhallway. He is yelling and brandishing his laser pistol. The troops reach a dead end and are forced to turn and fight. Han stops a few feet from them and assumes a defensive position. The troops begin to raise their laser guns. Soon all ten troopers are moving into an attack position in front of the lone starpirate. Han's determined look begins to fade as the troops begin to advance. Solo jumps backward as they fire at him. INT. DEATH STAR - SUBHALLWAY Chewbacca runs down the subhallway in a last-ditch attempt to save his bold captain. Suddenly he hears the firing of laser guns and yelling. Around the corner shoots Han, pirate extraordinaire, running for his life, followed by a host of furious stormtroopers. Chewbacca turns and starts running the other way also. INT. DEATH STAR - SUBHALLWAY Luke fires his laser pistol wildly as he and Leia rush down a narrow subhallway, chased by several stormtroopers. They quickly reach the end of the subhallway and race through an open hatchway. INT. DEATH STAR - CENTRAL CORE SHAFT Luke and Leia race through the hatch onto a narrow bridge that spans a huge, deep shaft that seems to go into infinity. The bridge has been retracted into the wall of the shaft, and Luke almost rushes into the abyss. He loses his balance off the end of the bridge as Leia, behind him, takes hold of his arm and pulls him back. LUKE (gasping) I think we took a wrong turn. Blasts from the stormtroopers' laser guns explode nearby reminding them of the oncoming danger. Luke fires back at the advancing troops. Leia reaches over and hits a switch that pops the hatch door shut with a resounding boom, leaving them precariously perched on a short piece of bridge overHang. Laserfire from the troopers continues to hit the steel door. LEIA There's no lock! Luke blasts the controls with his laser pistol. LUKE That oughta hold it for a while. LEIA Quick, we've got to get across. Find the control that extends the bridge. LUKE Oh, I think I just blasted it. Luke looks at the blasted bridge control while the stormtroopers on the opposite side of the door begin making ominous drilling and pounding sounds. LEIA They're coming through! Luke notices something on his stormtrooper belt, when laserfire hits the wall behind him. Luke aims his laser pistol at a stormtrooper perched on a higher bridge overHang across the abyss from them. They excHange fire. Two more troops appear on another overHang, also firing. A trooper is hit, and grabs at his chest. Another trooper standing on the bridge overHang is hit by Luke laserfire, and plummets down the shaft. Troopers move back off the bridge; Luke Hands the gun to Leia. LUKE Here, hold this. Luke pulls a thin nylon cable from his trooper utility belt. It has a grappler hook on it. A trooper appears on a bridge overHang and fires at Luke and Leia. As Luke works with the rope, Leia returns the laser volley. Another trooper appears and fires at them, as Leia returns his fire as well. Suddenly, the hatch door begins to open, revealing the feet of more troops. LEIA Here they come! Leia hits one of the stormtroopers on the bridge above, and he falls into the abyss. Luke tosses the rope across the gorge and it wraps itself around an outcropping of pipes. He tugs on the rope to make sure it is secure, then grabs the princess in his arms. Leia looks at Luke, then kisses him quickly on the lips. Luke is very surprised. LEIA For luck! Luke pushes off and they swing across the treacherous abyss to the corresponding hatchway on the opposite side. Just as Luke and Leia reach the far side of the canyon, the stormtroopers break through the hatch and begin to fire at the escaping duo. Luke returns the fire before ducking into the tiny subhallway. INT. DEATH STAR - NARROW PASSAGEWAY Ben hides in the shadows of the narrow passageway as several stormtroopers rush past him in the main hallway. He checks to make sure they're gone, then runs down the hallway in the opposite direction. Darth Vader appears at the far end of the hallway and starts after the old Jedi. INT. DEATH STAR - MAIN FORWARD BAY Threepio looks around at the troops milling about the pirateship entry ramp. THREEPIO Where could they be? Artoo, plugged into the computer socket, turns his dome left and right, beeping a response. INT. DEATH STAR - CORRIDOR - BLAST SHIELDS DOOR Han and Chewbacca run down a long corridor with several troopers hot on their trail. TROOPER Close the blast doors! At the end of the hallway, blast doors begin to close in front of them. The young starpilot and his furry companion race past the huge doors just as they are closing, and manage to get off a couple off laserblasts at the pursuing troops before the doors slam shut. TROOPER Open the blast doors! Open the blast doors! INT. DEATH STAR - HALLWAY LEADING TO MAIN FORWARD BAY Ben hurries along one of the tunnels leading to the Hangar where the pirateship waits. Just before he reaches the Hangar, Darth Vader steps into view at the end of the tunnel, not ten feet away. Vader lights his saber. Ben also ignites his and steps slowly forward. VADER I've been waiting for you, Obi-Wan. We meet again, at last. The circle is now complete. Ben Kenobi moves with elegant ease into a classical offensive position. The fearsome Dark Knight takes a defensive stance. VADER When I left you, I was but the learner; now I am the master. BEN Only a master of evil, Darth. The two Galactic warriors stand perfectly still for a few moments, sizing each other up and waiting for the right moment. Ben seems to be under increasing pressure and strain, as if an invisible weight were being placed upon him. He shakes his head and, blinking, tries to clear his eyes. Ben makes a sudden lunge at the huge warrior but is checked by a lightning movement of The Sith. A masterful slash stroke by Vader is blocked by the old Jedi. Another of the Jedi's blows is blocked, then countered. Ben moves around the Dark Lord and starts backing into the massive starship Hangar. The two powerful warriors stand motionless for a few moments with laser swords locked in mid-air, creating a low buzzing sound. VADER Your powers are weak, old man. BEN You can't win, Darth. If you strike me down, I shall become more powerful tHan you can possibly imagine. Their lightsabers continue to meet in combat. INT. DEATH STAR - MAIN FORWARD BAY Han Solo and Chewbacca, their weapons in Hand, lean back against the wall surveying the forward bay, watching the Imperial stormtroopers make their rounds of the Hangar. Han Didn't we just leave this party? Chewbacca growls a reply, as Luke and the princess join them. Han What kept you? LEIA We ran into some old friends. LUKE Is the ship all right? Han Seems okay, if we can get to it. Just hope the old man got the tractor beam out of commission. INT. DEATH STAR - HALLWAY Vader and Ben Kenobi continue their powerful duel. As they hit their lightsabers together, lightning flashes on impact. Troopers look on in interest as the old Jedi and Dark Lord of The Sith fight. Suddenly Luke spots the battle from his group's vantage point. LUKE Look! Luke, Leia, Han, and Chewie look up and see Ben and Vader emerging from the hallways on the far side of the docking bay. INT. DEATH STAR - DOCKING BAY Threepio and Artoo-Detoo are in the center of the Death Star's Imperial docking bay. THREEPIO Come on, Artoo, we're going! Threepio ducks out of sight as the seven stormtroopers who were guarding the starship rush past them heading towards Ben and The Sith Knight. He pulls on Artoo. INT. DEATH STAR - HALLWAY Solo, Chewie, Luke, and Leia tensely watch the duel. The troops rush toward the battling knights. Han Now's our cHance! Go! They start for the Millennium Falcon. Ben sees the troops charging toward him and realizes that he is trapped. Vader takes advantage of Ben's momentary distraction and brings his mighty lightsaber down on the old man. Ben manages to deflect the blow and swiftly turns around. The old Jedi Knight looks over his shoulder at Luke, lifts his sword from Vader's then watches his opponent with a serene look on his face. Vader brings his sword down, cutting old Ben in half. Ben's cloak falls to the floor in two parts, but Ben is not in it. Vader is puzzled at Ben's disappearance and pokes at the empty cloak. As the guards are distracted, the adventurers and the robots reach the starship. Luke sees Ben cut in two and starts for him. Aghast, he yells out. LUKE No! The stormtroopers turn toward Luke and begin firing at him. The robots are already moving up the ramp into the Millennium Falcon, while Luke, transfixed by anger and awe, returns their fire. Solo joins in the laserfire. Vader looks up and advances toward them, as one of his troopers is struck down. Han (to Luke) Come on! LEIA Come on! Luke, its too late! Han Blast the door! Kid! Luke fires his pistol at the door control panel, and it explodes. The door begins to slide shut. Three troopers charge forward firing laser bolts, as the door slides to a close behind them, shutting Vader and the other troops out of the docking bay. A stormtrooper lies dead at the feet of his onrushing compatriots. Luke starts for the advancing troops, as Solo and Leia move up the ramp into the pirateship. He fires, hitting a stormtrooper, who crumbles to the floor. BEN'S VOICE Run, Luke! Run! Luke looks around to see where the voice came from. He turns toward the pirateship, ducking Imperial gunfire from the troopers and races into the ship. INT. MILLENNIUM FALCON - COCKPIT Han pulls back on the controls and the ship begins to move. The dull thud of laser bolts bouncing off the outside of the ship as Chewie adjusts his controls. Han I hope the old man got that tractor beam out if commission, or this is going to be a real short trip. Okay, hit it! Chewbacca growls in agreement. EXT. MILLENNIUM FALCON The Millennium Falcon powers away from the Death Star docking bay, makes a spectacular turn and disappears into the vastness of space. INT. MILLENNIUM FALCON - CENTRAL HOLD AREA Luke, saddened by the loss of Obi-Wan Kenobi, stares off blankly as the robots look on. Leia puts a blanket around him protectively, and Luke turns and looks up at her. She sits down beside him. INT. MILLENNIUM FALCON - COCKPIT Solo spots approaching enemy ships. Han (to Chewie) We're coming up on the sentry ships. Hold 'em off! Angle the deflector shields while I charge up the main guns! INT. MILLENNIUM FALCON - CENTRAL HOLD AREA Luke looks downward sadly, shaking his head back and forth, as the princess smiles comfortingly at him. LUKE I can't believe he's gone. Artoo-Detoo beeps a reply. LEIA There wasn't anything you could have done. Han rushes into the hold area where Luke is sitting with the princess. Han (to Luke) Come on, buddy, we're not out of this yet! INT. MILLENNIUM FALCON - GUNPORTS - COCKPIT Solo climbs into his attack position in the topside gunport. INT. MILLENNIUM FALCON - HOLD AREA Luke gets up and moves out toward the gunports as Leia heads for the cockpit. INT. MILLENNIUM FALCON - GUNPORTS - COCKPIT Luke climbs down the ladder into the gunport cockpit, settling into one of the two main laser cannons mounted in large rotating turrets on either side of the ship. INT. MILLENNIUM FALCON - SOLO'S GUNPORT Han adjusts his headset as he sits before the controls of his laser cannon, then speaks into the attached microphone. Han (to Luke) You in, kid? Okay, stay sharp! INT. MILLENNIUM FALCON - GUNPORTS - COCKPIT Chewbacca and Princess Leia search the heavens for attacking TIE fighters. The Wookiee pulls back on the speed controls as the ship bounces slightly. INT. MILLENNIUM FALCON - SOLO'S GUNPORT - COCKPIT Computer graphic readouts form on Solo's target screen, as Han reaches for controls. INT. MILLENNIUM FALCON - GUNPORT - COCKPIT Luke sits in readiness for the attack, his Hand on the laser cannon's control button. INT. MILLENNIUM FALCON - COCKPIT. Chewbacca spots the enemy ships and barks. LEIA (into intercom) Here they come! INT. MILLENNIUM FALCON - COCKPIT - POV (POINT OF VIEW) - SPACE The Imperial TIE fighters move towards the Millennium Falcon, one each veering off to the left and right of the pirateship. INT. TIE FIGHTER - COCKPIT The stars whip past behind the Imperial pilot as he adjusts his maneuvering joy stick. EXT. MILLENNIUM FALCON - IN SPACE The TIE fighter races past the Falcon, firing laser beams as it passes. INT. MILLENNIUM FALCON - HOLD AREA Threepio is seated in the hold area, next to Artoo-Detoo. The pirateship bounces and vibrates as the power goes out in the room and then comes back on. INT. MILLENNIUM FALCON - COCKPIT - GUNPORTS A TIE fighter maneuvers in front of Han, who follows it and fires at it with the laser cannon. Luke does likewise, as the fighter streaks into view. The ship has suffered a minor hit, and bounces slightly. EXT. SPACE Two TIE fighters dive down toward the pirateship. INT. MILLENNIUM FALCON - GUNPORTS Luke fires at an unseen fighter. LUKE They're coming in too fast! EXT. SPACE - MILLENNIUM FALCON/TIE FIGHTERS Pan with pirateship as two TIE fighters charge through the background. Laserbolts streak from all the craft. INT. MILLENNIUM FALCON - CHEWBACCA The ship shudders as a laserbolt hits very close to the cockpit. The Wookiee chatters something to Leia. EXT. TIE FIGHTER - SPACE Full shot of a TIE fighter as it moves fast through the frame, firing on the pirate starship. EXT. SPACE - TIE FIGHTERS The two TIE fighters fire a barrage of laserbeams at the pirateship. INT. MILLENNIUM FALCON - MAIN PASSAGEWAY A laserbolt streaks into the side of the pirateship. The ship lurches violently, throwing poor Threepio into a cabinet fill of small computer chips. THREEPIO Oooh! INT. MILLENNIUM FALCON - COCKPIT - GUNPORTS Leia watches the computer readout as Chewbacca manipulates the ship's controls. LEIA We've lost lateral controls. Han Don't worry, she'll hold together. An enemy laserbolt hits the pirateship's control panel, causing it to blow out in a shower of sparks. Han (to ship) You hear me, baby? Hold together! Artoo-Detoo advances toward the smoking sparking control panel, dousing the inferno by spraying it with fire retardant beeping all the while. INT. MILLENNIUM FALCON - GUNPORT Luke swivels in his gun mount, following the TIE fighter with his laser cannon. INT. MILLENNIUM FALCON - GUNPORT Solo aims his laser cannon at the enemy fighter. EXT. SPACE A TIE fighter streaks in front of the starship. INT. MILLENNIUM FALCON - COCKPIT Leia watches the TIE fighter ship fly over. EXT. SPACE A TIE fighter heads right for the pirateship, then zooms overhead. INT. MILLENNIUM FALCON - GUNPORTS Luke follows the TIE fighter across his field of view, firing laserbeams from his cannon. EXT. TIE FIGHTER A TIE fighter dives past the pirateship. INT. MILLENNIUM FALCON - GUNPORTS Luke fires at a TIE fighter. At his port, Han follows a fighter in his sights, releasing a blast of laserfire. He connects, and the fighter explodes into fiery dust. Han laughs victoriously. EXT. SPACE Two TIE fighters move toward and over the Millennium Falcon, unleashing a barrage of laserbolts at the ship. INT. MILLENNIUM FALCON - GUNPORTS Another TIE fighter moves in on the pirateship and Luke, smiling, fires the laser cannon at it, scoring a spectacular direct hit. LUKE Got him! I got him! Han turns and gives Luke a victory wave which Luke gleefully returns. Han Great kid! Don't get cocky. Han turns back to his laser cannon. EXT. SPACE Two more TIE fighters cross in front of the pirateship. INT. MILLENNIUM FALCON - COCKPIT While Chewbacca manipulates the controls, Leia turns, looking over her shoulder out the ports. LEIA There are still two more of them out there! EXT. SPACE A TIE fighter moves up over the pirateship, firing laserblasts at it. INT. MILLENNIUM FALCON - GUNPORTS Luke and Han look into their respective projected target screens. An Imperial fighter crosses Solo's port, and Han swivels in his chair, following it with blasts from his laser cannon. Another fighter crosses Luke port, and he reacts in a like manner, the glow of his target screen lighting his face. EXT. SPACE The TIE fighter zooms toward the pirateship, firing destructive blasts at it. INT. MILLENNIUM FALCON - GUNPORTS Luke fires a laserblast at the approaching enemy fighter, and it bursts into a spectacular explosion. Luke projected screen gives a readout of the hit. The pirateship bounces slightly as it is struck by the enemy fire. EXT. SPACE - TIE FIGHTER The last of the attacking Imperial TIE fighters looms in, firing upon the Falcon. INT. MILLENNIUM FALCON - GUNPORT Solo swivels behind his cannon, his aim describing the arc of the TIE fighter. The fighter comes closer, firing at the pirateship, but a well-aimed blast from Solo's laser cannon hits the attacker, which blows up in a small atomic shower of burning fragments. LUKE (laughing) That's it! We did it! The princess jumps up and gives Chewie a congratulatory hug. LEIA We did it! INT. MILLENNIUM FALCON - PASSAGEWAY Threepio lies on the floor of the ship, completely tangled in the smoking, sparking wires. THREEPIO Help! I think I'm melting! (to Artoo) This is all your fault. Artoo turns his dome from side to side, beeping in response. EXT. SPACE - MILLENNIUM FALCON The victorious Millennium Falcon moves off majestically through space. INT. DEATH STAR - CONTROL ROOM Darth Vader strides into the control room, where Tarkin is watching the huge view screen. A sea of stars is before him. TARKIN Are they away? VADER They have just made the jump into hyperspace. TARKIN You're sure the homing beacon is secure aboard their ship? I'm taking an awful risk, Vader. This had better work. INT. MILLENNIUM FALCON - COCKPIT Han, removes his gloves and smiling, is at the controls of the ship. Chewie moves into the aft section to check the damage. Leia is seated near Han. Han Not a bad bit of rescuing, huh? You know, sometimes I even amaze myself. LEIA That doesn't sound too hard. Besides, they let us go. It's the only explanation for the ease of our escape. Han Easy... you call that easy? LEIA Their tracking us! Han Not this ship, sister. Frustrated, Leia shakes her head. LEIA At least the information in Artoo is still intact. Han What's so important? What's he carrying? LEIA The technical readouts of that battle station. I only hope that when the data is analyzed, a weakness can be found. It's not over yet! Han It is for me, sister! Look, I ain't in this for your revolution, and I'm not in it for you, Princess. I expect to be well paid. I'm in it for the money! LEIA You needn't worry about your reward. If money is all that you love, then that's what you'll receive! She angrily turns, and as she starts out of the cockpit, passes Luke coming in. LEIA Your friend is quite a mercenary. I wonder if he really cares about anything... or anyone. LUKE I care! Luke, shaking his head, sits in the copilot seat. He and Han stare out at the vast blackness of space. LUKE So... what do you think of her, Han? Han I'm trying not to, kid! LUKE (under his breath) Good... Han Still, she's got a lot of spirit. I don't know, what do you think? Do you think a princess and a guy like me... LUKE No! Luke says it with finality and looks away. Han smiles at young Luke jealousy. EXT. SPACE AROUND FOURTH MOON OF YAVIN The battered pirateship drifts into orbit around the planet Yavin and proceeds to one of its tiny green moons. EXT. FOURTH MOON OF YAVIN The pirateship soars over the dense jungle. EXT. MASSASSI OUTPOST An alert guard, his laser gun in Hand, scans the countryside. He sets the gun down and looks toward the temple, barely visible in the foliage. EXT. MASSASSI OUTPOST - JUNGLE TEMPLE Rotting in a forest of gargantuan trees, an ancient temple lies shrouded in an eerie mist. The air is heavy with the fantastic cries of unimaginable creatures. Han, Luke and the others are greeted by the Rebel troops. Luke and the group ride into the massive temple on an armored military speeder. INT. MASSASSI - MAIN HanGAR DECK The military speeder stops in a huge spaceship Hangar, set up in the interior of the crumbling temple. Willard, the commander of the Rebel forces, rushes up to the group and gives Leia a big hug. Every one is pleased to see her. WILLARD (holding Leia) You're safe! We had feared the worst. Willard composes himself, steps back and bows formally. WILLARD When we heard about Alderaan, we were afraid that you were... lost along with your father. LEIA We don't have time for our sorrows, Commander. The battle station has surely tracked us here. (looking pointedly to Han) It's the only explanation for the ease of our escape. You must use the information in this R2 unit to plan the attack. It is our only hope. EXT. SPACE The surface of the Death Star ominously approaches the red planet Yavin. INT. DEATH STAR - CONTROL ROOM Grand Moff Tarkin and Lord Vader are interrupted in their discussion by the buzz of the comlink. Tarkin moves to answer the call. TARKIN Yes. DEATH STAR INTERCOM VOICE We are approaching the planet Yavin. The Rebel base is on a moon on the far side. We are preparing to orbit the planet. EXT. YAVIN - JUNGLE A lone guard stands in a tower high above the Yavin landscape, surveying the countryside. A mist Hangs over the jungle of twisted green. INT. MASSASSI - WAR ROOM BRIEFING AREA Dodonna stands before a large electronic wall display. Leia and several other senators are to one side of the giant readout. The low-ceilinged room is filled with starpilots, navigators, and a sprinkling of R2-type robots. Everyone is listening intently to what Dodonna is saying. Han and Chewbacca are standing near the back. DODONNA The battle station is heavily shielded and carries a firepower greater tHan half the star fleet. It's defenses are designed around a direct large- scale assault. A small one-man fighter should be able to penetrate the outer defense. Gold Leader, a rough looking man in his early thirties, stands and addresses Dodonna. GOLD LEADER Pardon me for asking, sir, but what good are snub fighters going to be against that? DODONNA Well, the Empire doesn't consider a small one-man fighter to be any threat, or they'd have a tighter defense. An analysis of the plans provided by Princess Leia has demonstrated a weakness in the battle station. Artoo-Detoo stands next to a similar robot, makes beeping sounds, and turns his head from right to left. DODONNA The approach will not be easy. You are required to maneuver straight down this trench and skim the surface to this point. The target area is only two meters wide. It's a small thermal exhaust port, right below the main port. The shaft leads directly to the reactor system. A precise hit will start a chain reaction which should destroy the station. A murmer of disbelief runs through the room. DODONNA Only a precise hit will set up a chain reaction. The shaft is ray- shielded, so you'll have to use proton torpedoes. Luke is sitting next to Wedge Antilles, a hotshot pilot about sixteen years old. WEDGE That's impossible, even for a computer. LUKE It's not impossible. I used to bull's- eye womp rats in my T-sixteen back home. They're not much bigger tHan two meters. DODONNA Man your ships! And may the Force be with you! The group rises and begins to leave. EXT. SPACE The Death Star begins to move around the planet toward the tiny green moon. INT. DEATH STAR Tarkin and Vader watch the computer projected screen with interest, as a circle of lights intertwines around one another on the screen showing it's position in relation to Yavin and the forth moon. DEATH STAR INTERCOM VOICE Orbiting the planet at maximum velocity. The moon with the Rebel base will be in range in thirty minutes. VADER This will be a day long remembered. It has seen the end of Kenobi and it will soon see the end of the Rebellion. INT. MASSASSI OUTPOST - MAIN HanGAR DECK Luke, Threepio and little Artoo enter the huge spaceship Hangar and hurry along a long line of gleaming spacefighters. Flight crews rush around loading last-minute armaments and unlocking power couplings. In an area isolated from this activity Luke finds Han and Chewbacca loading small boxes onto an armored speeder. MAN'S VOICE (over loudspeaker) All flight trooper, man your stations. All flight troops, man your stations. Han is deliberately ignoring the activity of the fighter pilots' preparation. Luke is quite saddened at the sight of his friend's departure. LUKE So... you got your reward and you're just leaving then? Han That's right, yeah! I got some old debts I've got to pay off with this stuff. Even if I didn't, you don't think I'd be fool enough to stick around here, do you? Why don't you come with us? You're pretty good in a fight. I could use you. LUKE (getting angry) Come on! Why don't you take a look around? You know what's about to happen, what they're up against. They could use a good pilot like you. You're turning your back on them. Han What good's a reward if you ain't around to use it? Besides, attacking that battle station ain't my idea of courage. It's more like suicide. LUKE All right. Well, take care of yourself, Han. I guess that's what you're best at, isn't it? Luke goes off and Han hesitates, then calls to him. Han Hey, Luke... may the Force be with you! Luke turns and sees Han wink at him. Luke lifts his Hand in a small wave and then goes off. Han turns to Chewie who growls at his captain, Han What're you lookin' at? I know what I'm doing. INT. MAIN HanGAR DECK - Luke SHIP Luke, Leia, and Dodonna meet under a huge space fighter. LEIA What's wrong? LUKE Oh, it's Han! I don't know, I really thought he'd cHange his mind. LEIA He's got to follow his own path. No one can choose it for him. LUKE I only wish Ben were here. Leia gives Luke a little kiss, turns, and goes off. As Luke heads for his ship, another pilot rushes up to him and grabs his arm. BIGGS Luke! I don't believe it! How'd you get here... are you going out with us?! LUKE Biggs! Of course, I'll be up there with you! Listen, have I got some stories to tell... Red Leader, a rugged Handsome man in his forties, comes up behind Luke and Biggs. He has the confident smile of a born leader. RED LEADER Are you... Luke Skywalker? Have you been checked out on the Incom T-sixty- five? BIGGS Sir, Luke is the best bushpilot in the outer rim territories. Red Leader pats Luke on the back as they stop in front of his fighter. RED LEADER I met your father once when I was just a boy, he was a great pilot. You'll do all right. If you've got half of your father's skill, you'll do better tHan all right. LUKE THank you, sir. I'll try. Red Leader hurries to his own ship. BIGGS I've got to get aboard. Listen, you'll tell me your stories when we come back. All right? LUKE I told you I'd make it someday, Biggs. BIGGS (going off) You did, all right. It's going to be like old times, Luke. We're a couple of shooting stars that'll never be stopped! Luke laughs and shakes his head in agreement. He heads for his ship. As Luke begins to climb up the ladder into his sleek, deadly spaceship, the crew chief, who is working on the craft, points to little Artoo, who is being hoisted into a socket on the back of the fighter. CHIEF This R2 unit of your seems a bit beat up. Do you want a new one? LUKE Not on your life! That little droid and I have been through a lot together. (to Artoo) You okay, Artoo? The crewmen lower Artoo-Detoo into the craft. Now a part of the exterior shell of the starship, the little droid beeps that he is fine. Luke climbs up into the cockpit of his fighter and puts an his helmet. Threepio looks on from the floor of the massive Hangar as the crewmen secure his little electronic partner into Luke X-wing. It's an emotional-filled moment as Artoo beeps good-bye. CHIEF Okay, easy she goes! THREEPIO Hang on tight,Artoo, you've got to come back. Artoo beeps in agreement. THREEPIO You wouldn't want my life to get boring, would you? Artoo whistles his reply. All final preparations are made for the approaching battle. The Hangar is buzzing with the last minute activity as the pilots and crewmen alike make their final adjustments. The hum of activity is occasionally trespassed by the distorted voice of the loudspeaker issuing commands. Coupling hoses are disconnected from the ships as they are fueled. Cockpit shields roll smoothly into place over each pilot. A signalman, holding red guiding lights, directs the ships. Luke, a trace of a smile gracing his lips, peers about through his goggles. BEN'S VOICE Luke, the Force will be with you. Luke is confused at the voice and taps his headphones. EXT. MASSASSI OUTPOST - JUNGLE All that can be seen of the fortress is a lone guard standing on a small pedestal jutting out above the dense jungle. The muted gruesome crying sounds that naturally permeate this eerie purgatory are overwhelmed by the thundering din of ion rockets as four silver starships catapult from the foliage in a tight formation and disappears into the morning cloud cover. INT. MASSASSI OUTPOST - WAR ROOM The princess, Threepio, and a field commander sit quietly before the giant display showing the planet Yavin and its four moons. The red dot that represents the Death Star moves ever closer to the system. A series of green dots appear around the fourth moon. A din of indistinct chatter fills the war room. MASSASSI INTERCOM VOICE Stand-by alert. Death Star approaching. Estimated time to firing range, fifteen minutes. EXT. SPACE The Death Star slowly moves behind the massive yellow surface of Yavin in the foreground, as many X-wing fighters flying in formation zoom toward us and out of the frame. EXT. SPACE - ANOTHER ANGLE Light from a distant sun creates an eerie atmospheric glow around a huge planet, Yavin. Rebel fighters flying in formation settle ominously in the foreground and very slowly pull away. INT. RED LEADER STARSHIP - COCKPIT Red Leader lowers his visor and adjusts his gun sights, looking to each side at his wing men. RED LEADER All wings report in. INT. ANOTHER COCKPIT One of the Rebel fighters checks in through his mike. RED TEN Red Ten standing by. INT. BIGGS' COCKPIT Biggs checks his fighter's controls, alert and ready for combat. RED SEVEN (over Biggs' headset) Red Seven standing by. BIGGS Red Three standing by. INT. PORKINS' COCKPIT PORKINS Red Six standing by. RED NINE (over headset) Red Nine standing by. INT. WEDGE'S FIGHTER - COCKPIT WEDGE Red Two standing by. INT. Luke X-WING FIGHTER - COCKPIT RED ELEVEN (over headset) Red Eleven standing by. LUKE Red Five standing by. EXT. Luke X-WING FIGHTER Artoo-Detoo, in position outside of the fighter, turns his head from side to side and makes beeping sounds. INT. RED LEADER'S FIGHTER - COCKPIT RED LEADER Lock S-foils in attack position. EXT. SPACE The group of X-wing fighters move in formation toward the Death Star, unfolding the wings and locking them in the "X" position. INT. BIGGS' COCKPIT READ LEADER (over headset) We're passing through their magnetic field. INT. RED LEADER'S COCKPIT RED LEADER Hold tight! INT. Luke X-WING FIGHTER - COCKPIT Luke adjusts his controls as he concentrates on the approaching Death Star. The ship begins to be buffeted slightly. RED LEADER (over headset) Switch your deflectors on. INT. ANOTHER COCKPIT RED LEADER (over headset) Double front! EXT. SPACE The fighters, now X-shaped darts, move in formation. The Death Star now appears to be a small moon growing rapidly in size as the Rebel fighters approach. Complex patterns on the metallic surface begin to become visible. A large dish antenna is built into the surface on one side. INT. WEDGE'S COCKPIT Wedge is amazed and slightly frightened at the awesome spectacle. WEDGE Look at the size of that thing! RED LEADER (over headset) Cut the chatter, Red Two. INT. RED LEADER'S COCKPIT RED LEADER Accelerate to attack speed. This is it, boys! EXT. SPACE As the fighters move closer to the Death Star, the awesome size of the gargantuan Imperial fortress is revealed. Half of the deadly space station is in shadow and this area sparkles with thousands of small lights running in thin lines and occasionally grouped in large clusters; somewhat like a city at night as seen from a weather satellite. INT. GOLD LEADER'S COCKPIT GOLD LEADER Red Leader, this is Gold Leader. RED LEADER (over headset) I copy, Gold Leader. GOLD LEADER We're starting for the target shaft now. INT. RED LEADER'S COCKPIT Red Leader looks around at his wingmen; the Death Star looming in from behind. Two Y-wing fighters bob back and forth in the background. He moves his computer targeting device into position. RED LEADER We're in position. I'm going to cut across the axis and try and draw their fire. EXT. SPACE Two squads of Rebel fighters peel off. The X-wings dive towards the Death Star surface. A thousand lights glow across the dark grey expanse of the huge station. INT. DEATH STAR Alarm sirens scream as soldiers scramble to large turbo- powered laser gun emplacements. Electronic drivers rotate the huge guns into position as crew adjust their targeting devices. EXT. SPACE AROUND THE DEATH STAR Laserbolts streak through the star-filled night. The Rebel X- wing fighters move in toward the Imperial base, as the Death Star aims its massive laser guns at the Rebel forces and fires. INT. MASSASSI OUTPOST - WAR ROOM Princess Leia listens to the battle over the intercom. Threepio is at her side. WEDGE (over war room speaker system) Heavy fire, boss! Twenty-degrees. RED LEADER (over speaker) I see it. Stay low. EXT. SPACE An X-wing zooms across the surface of the Death Star. INT. DEATH STAR Technical crews scurry here and there loading last-minute armaments and unlocking power cables. INT. WEDGE'S COCKPIT Wedge maneuvers his fighter toward the menacing Death Star. EXT. SPACE X-wings continue in their attack course on the Death Star. INT. Luke X-WING FIGHTER - COCKPIT Luke nosedives radically, starting his attack on the monstrous fortress. The Death Star surface streaks past the cockpit window. LUKE This is Red Five; I'm going in! EXT. SPACE Luke X-wing races toward the Death Star. Laserbolts streak from Luke weapons, creating a huge fireball explosion on the dim surface. INT. Luke X-WING FIGHTER - COCKPIT Terror crosses Luke face as he realizes he won't be able to pull out in time to avoid the fireball. BIGGS (over headset) Luke, pull up! EXT. SURFACE OF DEATH STAR Luke ship emerges from the fireball, with the leading edges of his wings slightly scorched. INT. BIGGS' COCKPIT BIGGS Are you all right? INT. Luke X-WING FIGHTER - COCKPIT Luke adjusts his controls and breathes a sigh of relief. Flak bursts outside the cockpit window. LUKE I got a little cooked, but I'm okay. EXT. SURFACE OF THE DEATH STAR Rebel fighters continue to strafe the Death Star's surface with laserbolts. INT. DEATH STAR Walls buckle and cave in. Troops and equipment are blown in all directions. Stormtroopers stagger out of the rubble. Standing in the middle of the chaos, a vision of calm and foreboding, is Darth Vader. One of his Astro-Officers rushes up to him. ASTRO-OFFICER We count thirty Rebel ships, Lord Vader. But they're so small they're evading our turbo-lasers! VADER We'll have to destroy them ship to ship. Get the crews to their fighters. INT. DEATH STAR Smoke belches from the giant laser guns as they wind up their turbine generators to create sufficient power. The crew rushes about preparing for another blast. Even the troopers head gear is not adequate to protect them from the overwhelming noise of the monstrous weapon. One troopers bangs his helmet with his Hand in an attempt to stop the ringing. INT. READ LEADER'S X-WING FIGHTER - COCKPIT - TRAVELING Red Leader flies through a heavy hail of flak. RED LEADER Luke, let me know when you're going in. INT. Luke X-WING - COCKPIT - TRAVELING The Red Leader's X-wing flies past Luke as he puts his nose down and starts his attack dive. LUKE I'm on my way in now... RED LEADER Watch yourself! There's a lot of fire coming from the right side of that deflection tower. LUKE I'm on it. EXT. SURFACE OF THE DEATH STAR Luke flings his X-wing into a twisting dive across the horizon and down onto the dim grey surface. EXT. Luke X-WING TRAVELING A shot hurls from Luke guns. Laserbolts streak toward the onrushing Death Star surface. Several small radar emplacements erupt in flame. Laserfire erupts from a protruding tower on the surface. INT. Luke X-WING - COCKPIT - TRAVELING The blurry Death Star surface races past the cockpit window as a big smile sweeps across Luke face at the success of his run. Flak thunders on all sides of him. EXT. SURFACE OF THE DEATH STAR The Death Star superstructure races past Luke as he maneuvers his craft through a wall of laserfire and peels away from the surface towards the heavens. INT. DEATH STAR The thunder and smoke of the big guns reverberate throughout the massive structure. Many soldiers rush about in the smoke and chaos, silhouetted by the almost continual flash of explosions. INT. BIGGS' COCKPIT - TRAVELING Biggs dives through a forest of radar domes, antennae, and gun towers as he shoots low across the Death Star surface. A dense barrage of laserfire streaks by on all sides. INT. DEATH STAR Imperial star pilots dash in unison to a line of small auxiliary hatches that lead to Imperial TIE fighters. INT. MASSASSI OUTPOST - WAR ROOM Princess Leia, surrounded by her generals and aides, paces nervously before a lighted computer table. On all sides technicians work in front of many lighted glass walls. Dodonna watches quietly from one corner. One of the officers working over a screen speaks into his headset. CONTROL OFFICER Squad leaders, we've picked up a new group of signals. Enemy fighters coming your way. INT. Luke X-WING - COCKPIT - TRAVELING Luke looks around to see if he can spot the approaching Imperial fighters. LUKE My scope's negative. I don't see anything. INT. RED LEADER'S X-WING - COCKPIT - TRAVELING The Death Star's surface sweeps past as Red Leader searches the sky for the Imperial fighters. Flak pounds at his ship. RED LEADER Keep up your visual scanning. With all this jamming, they'll be on top of you before your scope can pick them up. EXT. SURFACE OF THE DEATH STAR Silhouetted against the rim lights of the Death Star horizon, four ferocious Imperial TIE ships dive on the Rebel fighters. Two of the TIE fighters peel off and drop out of frame. Pan with the remaining two TIE ships. INT. BIGGS' COCKPIT - TRAVELING Biggs panics when he discovers a TIE ship on his tail. The horizon in the background twists around as he peels off, hoping to lose the Imperial fighter. INT. RED LEADER'S COCKPIT RED LEADER Biggs! You've picked one up... watch it! BIGGS I can't see it! Where is he?! EXT. SPACE AROUND THE DEATH STAR Biggs zooms off the surface and into space, closely followed by an Imperial TIE fighter. The TIE ship fires several laserbolts at Biggs, but misses. INT. BIGGS' COCKPIT - TRAVELING Biggs see the TIE ship behind him and swings around, trying to avoid him. BIGGS He's on me tight, I can't shake him... I can't shake him. EXT. SPACE AROUND THE DEATH STAR Biggs, flying at high altitude, peels off and dives toward the Death Star surface, but he is unable to lose the TIE fighter, who sticks close to his tail. INT. X-WING FIGHTER - COCKPIT - TRAVELING Luke is flying upside down. He rotates his ship around to normal attitude as he comes out of his dive. LUKE Hang on, Biggs, I'm coming in. EXT. SPACE AROUND THE DEATH STAR Biggs and the tailing TIE ship dive for the surface, now followed by a fast-gaining Luke. After Biggs dives out of sight, Luke chases the Imperial fighter. EXT. SURFACE AROUND THE DEATH STAR In the foreground, the Imperial fighter races across the Death Star's surface, closely followed by Luke in the background. INT. Luke X-WING FIGHTER - COCKPIT - TRAVELING There is a shot from Luke X-wing of the TIE ship exploding in a mass of flames. LUKE Got him! INT. DEATH STAR Darth Vader strides purposefully down a Death Star corridor, flanked by Imperial stormtroopers. VADER Several fighters have broken off from the main group. Come with me! INT. MASSASSI OUTPOST - WAR ROOM A concerned Princess Leia, Threepio, Dodonna, and other officers of the Rebellion stand around the huge round readout screen, listening to the ship-to-ship communication on the room's loudspeaker. BIGGS (over speaker) Pull in! Luke... pull in! WEDGE (over speaker) Watch your back, Luke! INT. Luke X-WING FIGHTER - COCKPIT WEDGE (over headset) Watch your back! Fighter's above you, coming in! EXT. SPACE Luke ship soars away from the Death Star's surface as he spots the tailing TIE fighter. INT. TIE FIGHTER'S COCKPIT The TIE pilot takes aim at Luke X-wing. EXT. SPACE The Imperial TIE fighter pilot scores a hit on Luke ship. Fire breaks out on the right side of the X-wing. INT. Luke X-WING FIGHTER - COCKPIT Luke looks out of his cockpit at the flames on his ship. LUKE I'm hit, but not bad. EXT. Luke X-WING FIGHTER Smoke pours out from behind Artoo-Detoo. Luke VOICE Artoo, see what you can do with it. Hang on back there. Green laserfire moves past the beeping little robot as his head turns. INT. Luke X-WING - COCKPIT Luke nervously works his controls. RED LEADER (over headset) Red Six... INT. MASSASSI OUTPOST - WAR ROOM In the war room, Leia stands frozen as she listens and worries about Luke. RED LEADER (over speaker) Can you see Red Five? RED TEN (over speaker) There's a heavy fire zone on this side. Red Five, where are you? INT. Luke X-WING - COCKPIT Luke spots the TIE fighter behind him and soars away from the Death Star surface. LUKE I can't shake him! EXT. SURFACE OF THE DEATH STAR Luke ship soars closer to the surface of the Death Star, an Imperial TIE fighter closing in on him in hot pursuit. INT. WEDGE'S COCKPIT The Death Star whips below Wedge. WEDGE I'm on him, Luke! INT. Luke X-WING - COCKPIT WEDGE (over headset) Hold on! EXT. SURFACE OF THE DEATH STAR Wedge dives across the horizon toward Luke and the TIE fighter. INT. WEDGE'S COCKPIT Wedge moves his X-wing in rapidly. INT. Luke X-WING - COCKPIT Luke reacts frantically. LUKE Blast it! Wedge where are you? INT. TIE FIGHTER - COCKPIT The fighter pilot watches Wedge's X-wing approach. Another X- wing joins him, and both unleash a volley of laserfire on the Imperial fighter. EXT. SPACE The TIE fighter explodes, filling the screen with white light. Luke ship can be seen far in the distance. INT. Luke X-WING - COCKPIT Luke looks about in relief. LUKE THanks, Wedge. INT. MASSASSI OUTPOST - WAR ROOM Leia, Threepio, Dodonna and other Rebel officers are listening to the Rebel Fighter's radio transmissions over the war room intercom. BIGGS (over speaker) Good shooting, Wedge! GOLD LEADER (over speaker) Red Leader... INT. GOLD LEADER'S Y-WING - COCKPIT Gold Leader peels off and starts toward the long trenches at the Death Star surface pole. GOLD LEADER This is Gold Leader. We're starting out attack run. EXT. SPACE AROUND THE DEATH STAR Three Y-wing fighters of the Gold group dive out of the stars toward the Death Star surface. INT. MASSASSI OUTPOST - WAR ROOM Leia and the others are grouped around the screen, as technicians move about attending to their duties. RED LEADER (over speaker) I copy, Gold Leader. Move into position. EXT. SPACE AROUND THE DEATH STAR Three Imperial TIE ships in precise formation dive toward the Death Star surface. INT. DARTH VADER'S COCKPIT Darth Vader calmly adjusts his control stick as the stars whip past in the window above his head. VADER Stay in attack formation! INT. MASSASSI OUTPOST - WAR ROOM Technicians are seated at the computer readout table. GOLD LEADER (over speaker) The exhaust post is... INT. GOLD LEADER'S Y-WING - COCKPIT GOLD LEADER ...marked and locked in! EXT. SPACE AROUND THE DEATH STAR Gold Leader approaches the surface and pulls out to skim the surface of the huge station. The ship moves into a deep trench, firing laserbolts. The surface streaks past as laserfire is returned by the Death Star. INT. GOLD FIVE'S Y-WING - COCKPIT - TRAVELING Gold Five is a pilot in his early fifties with a very battered helmet that looks like it's been through many battles. He looks around to see if enemy ships are near. His fighter is buffeted by Imperial flak. INT. GOLD LEADER'S Y-WING - COCKPIT Gold Leader races down the enormous trench that leads to the exhaust port. Laserbolts blast toward him in increasing numbers, occasionally exploding near the ship causing it to bounce about. GOLD LEADER Switch power to front deflector screens. EXT. SURFACE OF THE DEATH STAR Three Y-wing skim the Death Star surface deep in the trench, as laserbolts streak past on all sides. EXT. DEATH STAR SURFACE - GUN EMPLACEMENTS An exterior surface gun blazes away at the oncoming Rebel fighters. INT. GOLD LEADER'S Y-WING - COCKPIT GOLD LEADER How many guns do you think, Gold Five. INT. MASSASSI OUTPOST - WAR ROOM GOLD FIVE (over speaker) I'd say about twenty guns. Some on the surface, some on the towers. Leia, Threepio, and the technicians view the projected target screen, as red and blue target lights glow. The red target near the center blinks on and off. MASSASSI INTERCOM VOICE (over speaker) Death Star will be in range in five minutes. EXT. SURFACE OF THE DEATH STAR The three Y-wing fighters race toward camera and zoom overhead through a hail of laserfire. INT. GOLD LEADER'S Y-WING - COCKPIT Gold Leader pulls his computer targeting device down in front of his eye. Laserbolts continue to batter the Rebel craft. GOLD LEADER Switching to targeting computer. INT. GOLD TWO'S Y-WING - COCKPIT Gold Two, a younger pilot about Luke age, pulls down his targeting eye viewer and adjusts it. His ship shudders under intense laser barrage. GOLD TWO Computer's locked. Getting a signal. As the fighters begin to approach the target area, suddenly all the laserfire stops. An eerie clam clings over the trench as the surface whips past in a blur. GOLD TWO The guns... they've stopped! EXT. GOLD FIVE'S COCKPIT Gold Five looks behind him. GOLD FIVE Stabilize your read deflectors. Watch for enemy fighters. INT. GOLD LEADER'S Y-WING - COCKPIT GOLD LEADER They've coming in! Three marks at two ten. EXT. SPACE AROUND THE DEATH STAR Three Imperial TIE ships, Darth Vader in the center flanked by two wingmen, dive in precise formation almost vertically toward the Death Star surface. INT. DARTH VADER'S COCKPIT Darth Vader calmly adjusts his control stick as the stars zoom by. VADER I'll take them myself! Cover me! WINGMAN'S VOICE (over speaker) Yes, sir. EXT. SPACE AROUND THE DEATH STAR Three TIE fighters zoom across the surface of the Death Star. INT. DARTH VADER'S COCKPIT Vader lines up Gold Two in his targeting computer. Vader's Hands grip the control stick as he presses the button. INT. GOLD LEADER'S Y-WING - COCKPIT The cockpit explodes around Gold Two. His head falls forward. EXT. SPACE AROUND THE DEATH STAR As Gold Two's ship explodes, debris is flung out into space. INT. GOLD LEADER'S Y-WING - COCKPIT Gold Leader looks over his shoulder at the scene. EXT. DEATH STAR TRENCH The three TIE fighters race along in the trench in a tight formation. INT. GOLD LEADER'S Y-WING - COCKPIT Gold Leader panics. GOLD LEADER (into mike) I can't maneuver! INT. GOLD FIVE'S Y-WING - COCKPIT Gold Five, the old veteran, trys to calm Gold Leader. GOLD FIVE Stay on target. INT. GOLD LEADER'S Y-WING - COCKPIT The Death Star races by outside the cockpit window as he adjusts his targeting device. GOLD LEADER We're too close. INT. GOLD FIVE'S Y-WING - COCKPIT The older pilot remains calm. GOLD FIVE Stay on target! INT. GOLD LEADER'S Y-WING - COCKPIT Now he's really panicked. GOLD LEADER Loosen up! INT. DARTH VADER'S COCKPIT Vader calmly adjusts his targeting computer and pushes the fire button. INT. GOLD LEADER'S Y-WING - COCKPIT Gold Leader's ship is hit by Vader's laser. EXT. SURFACE OF THE DEATH STAR Gold Leader explodes in a ball of flames, throwing debris in all directions. INT. GOLD FIVE'S Y-WING - COCKPIT Gold Five moves in on the exhaust port. GOLD FIVE Gold Five to Red Leader... INT. Luke X-WING FIGHTER - COCKPIT Luke looks over his shoulder at the action outside of his cockpit. GOLD FIVE (over headset) Lost Tiree, lost Dutch. INT. RED LEADER'S COCKPIT RED LEADER I copy, Gold Five. INT. GOLD FIVE'S Y-WING - COCKPIT GOLD FIVE They came from behind... EXT. SURFACE OF THE DEATH STAR One of the engines explodes on Gold Five's Y-wing fighter, blazing out of control. He dives past the horizon toward the Death Star's surface, passing a TIE fighter during his descent. Gold Five, a veteran of countless campaigns, spins toward his death. INT. Luke X-WING FIGHTER - COCKPIT Luke looks nervously about him at the explosive battle. INT. DEATH STAR - CONTROL ROOM Grant Moff Tarkin and a Chief Officer stand in the Death Star's control room. OFFICER We've analyzed their attack, sir, and there is a danger. Should I have your ship standing by? TARKIN Evacuate? In out moment of triumph? I think you overestimate their cHances! Tarkin turns to the computer readout screen. Flames move around the green disk at the center of the screen, as numbers read across the bottom. VOICE (over speaker) Rebel base, three minutes and closing. INT. READ LEADER'S COCKPIT Red Leader looks over at his wingmen. RED LEADER Red Group, this is Red Leader. INT. MASSASSI OUTPOST - WAR ROOM Dodonna moves to the intercom as he fiddles with the computer keys. RED LEADER (over speaker) Rendezvous at mark six point one. WEDGE (over speaker) This is Red Two. Flying toward you. BIGGS (over speaker) Red Three, standing by. INT. RED LEADER'S COCKPIT DODONNA (over headset) Red Leader, this is Base One. Keep half your group out of range for the next run. INT. Luke X-WING FIGHTER - COCKPIT RED LEADER'S VOICE (over headset) Copy, Base One. Luke, take Red Two and Three. Hold up here and wait for my signal... to start your run. Luke nods his head. EXT. SPACE AROUND THE DEATH STAR The X-wing fighters of Luke, Biggs, and Wedge fly in formation high above the Death Star's surface. INT. Luke X-WING FIGHTER - COCKPIT Luke peers out from his cockpit. EXT. SURFACE OF THE DEATH STAR Two X-wings move across the surface of the Death Star. Red Leader's X-wing drops down to the surface leading to the exhaust port. INT. RED LEADER'S COCKPIT Red Leader looks around to watch for the TIE fighters. He begins to perspire. RED LEADER This is it! EXT. SPACE Red Leader roams down the trench of the Death Star as lasers streak across the black heavens. EXT. DEATH STAR SURFACE - GUN EMPLACEMENTS A huge remote-control laser cannon fires at the approaching Rebel fighters. EXT. DEATH STAR TRENCH The Rebel fighters evade the Imperial laser blasts. INT. RED TEN'S COCKPIT Red Ten looks around for the Imperial fighters. RED TEN We should be able to see it by now. EXT. DEATH STAR TRENCH From the cockpits of the Rebel pilots, the surface of the Death Star streaks by, with Imperial laserfire shooting toward them. INT. RED LEADER'S COCKPIT RED LEADER Keep your eyes open for those fighters! INT. RED TEN'S COCKPIT RED TEN There's too much interference! EXT. SPACE - DEATH STAR TRENCH Three X-wing fighters move in formation down the Death Star trench. RED TEN'S VOICE Red Five, can you see them from where you are? INT. Luke X-WING FIGHTER - COCKPIT Luke looks down at the Death Star surface below. LUKE No sign of any... wait! INT. RED TEN'S COCKPIT Red Ten looks up and sees the Imperial fighters. LUKE (over headset) Coming in point three five. RED TEN I see them. EXT. SURFACE OF THE DEATH STAR Three TIE fighters, Vader flanked by two wingmen, dive in a tight formation. The sun reflects off their dominate solar fins as they loop toward the Death Star's surface. INT. RED LEADER'S COCKPIT Red Leader pulls his targeting device in front of his eyes and makes several adjustments. RED LEADER I'm in range. EXT. SURFACE OF THE DEATH STAR Red Leader's X-wing moves up the Death Star trench. INT. RED LEADER'S COCKPIT RED LEADER Target's coming up! Red Leader looks at his computer target readout screen. He then looks into his targeting device. RED LEADER Just hold them off for a few seconds. INT. DARTH VADER'S COCKPIT Vader adjusts his control lever and dives on the X-wing fighters. VADER Close up formation. EXT. DEATH STAR TRENCH The three TIE fighters move in formation across the Death Star surface. INT. RED LEADER'S COCKPIT Red Leader lines up his target on the targeting device cross hairs. EXT. SURFACE OF THE DEATH STAR Vader and his wingmen zoom down the trench. INT. DARTH VADER'S COCKPIT Vader rapidly approaches the two X-wings of Red Ten and Red Twelve. Vader's laser cannon flashes below the view of the front porthole. the X-wings show in the center of Vader's computer screen. EXT. SPACE Red Twelve's X-wing fighter is hit by Vader's laserfire, and it explodes into flames against the trench. INT. RED TEN'S COCKPIT Red Ten works at his controls furiously, trying to avoid Vader's fighter behind him. RED TEN: You'd better let her loose. INT. RED LEADER'S COCKPIT Red Leader is concentrating on his targeting device. RED LEADER Almost there! INT. RED TEN'S COCKPIT. Red Ten panics. RED TEN I can't hold them! EXT. SURFACE OF THE DEATH STAR Vader and his wingmen whip through the trench in pursuit of the Rebel fighters. INT. DARTH VADER'S COCKPIT Vader cooly pushes the fire button on his control stick. INT. RED TEN'S COCKPIT Darth Vader's well-aimed laserfire proves to be unavoidable, and strikes Red Ten's ship. Red Ten screams in anguish and pain. EXT. SPACE AROUND THE DEATH STAR Red Ten's ship explodes and bursts into flames. INT. RED LEADER'S COCKPIT Grimly, Red Leader takes careful aim and watches his computer targeting device, which shows the target lined up in the cross hairs, and fires. INT. RED LEADER'S COCKPIT RED LEADER It's away! INT. DEATH STAR An armed Imperial stormtrooper is knocked to the floor from the attack explosion. Other troopers scurrying about the corridors are knocked against the wall and lose their balance. INT. MASSASSI OUTPOST - WAR ROOM Leia and the others stare at the computer screen. RED NINE'S VOICE (over speaker) It's a hit! RED LEADER (over speaker) Negative. INT. RED LEADER'S COCKPIT Red Leader looks back at the receding Death Star. Tiny explosions are visible in the distance. RED LEADER Negative! It didn't go in. It just impacted on the surface. EXT. SPACE AROUND THE DEATH STAR - TIE FIGHTER Darth Vader peels off in pursuit as Red Leader's X-wing passes the Death Star horizon. INT. DARTH VADER'S COCKPIT Vader swings his ship around for the next kill. INT. RED LEADER'S COCKPIT LUKE (over headset) Red Leader, we're right above you. Turn to point... INT. Luke X-WING FIGHTER - COCKPIT Luke tries to spot Red Leader. He looks down at the Death Star surface. LUKE ...oh-five; we'll cover for you. RED LEADER (over headset) Stay there... INT. RED LEADER'S COCKPIT A wary Red Leader looks about nervously. RED LEADER ...I just lost my starboard engine. INT. Luke X-WING FIGHTER - COCKPIT Luke looks excitedly toward Red Leader's X-wing. RED LEADER (over headset) Get set to make your attack run. INT. DARTH VADER'S COCKPIT Vader's gloved Hands make contact with the control sticks, and he presses their firing buttons. INT. RED LEADER'S COCKPIT Red Leader fights to gain control of his ship. EXT. SPACE AROUND THE DEATH STAR Laserbolts are flung from Vader's TIE fighter, connecting with Red Leader's Rebel X-wing fighter. Red Leader buys it, creating a tremendous explosion far below. He screams and is destroyed. INT. Luke X-WING FIGHTER - COCKPIT Luke looks out the window of his X-wing at the explosion far below. For the first time, he feels the helplessness of his situation. INT. DEATH STAR Grand Moff Tarkin casts a sinister eye at the computer screen. DEATH STAR INTERCOM VOICE Rebel base, one minute and closing. INT. MASSASSI OUTPOST - WAR ROOM Dodonna and Princess Leia, with Threepio beside them, listen intently to the talk between the pilots. The room is grim after Red Leader's death. Princess Leia nervously paces the room. LUKE (over speaker) Biggs, Wedge, let's close it up. We're going in. We're going in full throttle. INT. WEDGE'S COCKPIT The horizon twists as Wedge begins to pull out. WEDGE Right with you, boss. EXT. SPACE AROUND THE DEATH STAR The two X-wings peel off against a background of stars and dive toward the Death Star. INT. BIGGS' COCKPIT BIGGS Luke, at that speed will you be able to pull out in time? INT. Luke X-WING FIGHTER - COCKPIT LUKE It'll be just like Beggar's Canyon back home. EXT. SPACE AROUND THE DEATH STAR The three X-wings move in, unleashing a barrage of laserfire. Laserbolts are returned from the Death Star. INT. BIGGS' COCKPIT Luke lifelong friend struggles with his controls. BIGGS We'll stay back far enough to cover you. INT. Luke COCKPIT Flak and laserbolts flash outside Luke cockpit window. WEDGE (over headset) My scope shows the tower, but I can't see the exhaust port! Are you sure the computer can hit it? EXT. DEATH STAR - GUN EMPLACEMENTS The Death Star laser cannon slowly rotates as it shoots laserbolts. INT. Luke X-WING FIGHTER - COCKPIT Luke looks around for the Imperial TIE fighters. He thinks for a moment and then moves his targeting device into position. LUKE Watch yourself! Increase speed full throttle! INT. WEDGE'S COCKPIT Wedge looks excitedly about for any sign of the TIE fighters. WEDGE What about the tower? INT. Luke X-WING FIGHTER - COCKPIT LUKE You worry about those fighters! I'll worry about the tower! EXT. DEATH STAR SURFACE Luke X-wing streaks through the trench, firing lasers. INT. Luke X-WING FIGHTER - COCKPIT Luke breaks into a nervous sweat as the laserfire is returned, knicking one of his wings close to the engine. LUKE (to Artoo) Artoo... that, that stabilizer's broken loose again! See if you can't lock it down! EXT. Luke X-WING FIGHTER Artoo works to repair the damages. The canyon wall rushes by in the background, making his delicate task seem even more precarious. EXT. DEATH STAR Two laser cannons are firing on the Rebel fighters. INT. WEDGE'S COCKPIT Wedge looks up and sees the TIE ships. INT. Luke X-WING FIGHTER - COCKPIT Luke targeting device marks off the distance to the target. EXT. SPACE AROUND THE DEATH STAR Vader and his wingmen zoom closer. INT. DARTH VADER'S COCKPIT Vader adjusts his controls and fires laserbolts at two X- wings flying down the trench. He scores a direct hit on Wedge. INT. MASSASSI OUTPOST - WAR ROOM Leia and the others are grouped around the computer board. WEDGE (over speaker) I'm hit! I can't stay with you. LUKE (over speaker) Get clear, Wedge. INT. Luke X-WING FIGHTER - COCKPIT LUKE You can't do any more good back there! INT. WEDGE'S COCKPIT WEDGE Sorry! EXT. SPACE AROUND THE DEATH STAR Wedge pulls his crippled X-wing back away from the battle. INT. DARTH VADER'S COCKPIT Vader watches the escape but issues a command to his wingmen. VADER Let him go! Stay on the leader! EXT. SPACE AROUND THE DEATH STAR Luke X-wing speeds down the trench; the three TIE fighters, still in perfect unbroken formation, tail close behind. INT. BIGGS' COCKPIT Biggs looks around at the TIE fighters. He is worried. BIGGS Hurry, Luke, they're coming in much faster this time. I can't hold them! EXT. SPACE AROUND THE DEATH STAR The three TIE fighters move ever closer, closing in on Luke and Biggs. INT. Luke X-WING FIGHTER - COCKPIT Luke looks back anxiously at little Artoo. LUKE Artoo, try and increase the power! EXT. Luke X-WING FIGHTER Ignoring the bumpy ride, flak, and lasers, a beeping Artoo- Detoo struggles to increase the power, his dome turning from side to side. EXT. SPACE AROUND THE DEATH STAR Stealthily, the TIE formation creeps closer. INT. DARTH VADER'S COCKPIT Vader adjusts his control stick. INT. BIGGS' COCKPIT Biggs looks around at the TIE fighters. INT. Luke X-WING FIGHTER Luke looks into his targeting device. He moves it away for a moment and ponders its use. He looks back into the computer targeter. BIGGS (over headset) Hurry up, Luke! EXT. SPACE AROUND THE DEATH STAR Vader and his wingmen race through the Death Star trench. Biggs moves in to cover for Luke, but Vader gains on him. INT. BIGGS' COCKPIT Biggs sees the TIE fighter aiming at him. BIGGS Wait! INT. DARTH VADER'S COCKPIT Vader squeezes the fire button on his controls. INT. BIGGS' COCKPIT Biggs' cockpit explodes around him, lighting him in red. EXT. SURFACE OF THE DEATH STAR Biggs' ship bursts into a million flaming bits and scatters across the surface. INT. MASSASSI OUTPOST - WAR ROOM Leia and the others stare at the computer board. INT. Luke X-WING COCKPIT Luke is stunned by Biggs' death. His eyes are watering, but his anger is also growing. INT. DEATH STAR - CONTROL ROOM Grand Moff Tarkin watches the projected target screen with satisfaction. DEATH STAR INTERCOM VOICE Rebel base, thirty seconds and closing. INT. DARTH VADER'S COCKPIT Vader takes aim on Luke and talks to the wingmen. VADER I'm on the leader. EXT. SURFACE OF THE DEATH STAR - Luke SHIP Luke ship streaks through the trench of the Death Star. INT. MASSASSI OUTPOST - WAR ROOM Princess Leia returns her general's worried and doubtful glances with solid, grim determination. Threepio seems nervous. THREEPIO Hang on, Artoo! INT. Luke X-WING - COCKPIT Luke concentrates on his targeting device. EXT. SURFACE OF THE DEATH STAR Three TIE fighters charge away down the trench toward Luke. INT. DARTH VADER'S COCKPIT Vader's finger's curls around the control stick. INT. Luke X-WING - COCKPIT Luke adjusts the lens of his targeting device. EXT. SURFACE OF THE DEATH STAR Luke ship charges down the trench. INT. Luke X-WING - COCKPIT Luke lines up the yellow cross-hair lines of the targeting device's screen. He looks into the targeting device, then starts at a voice he hears. BEN'S VOICE Use the Force, Luke. EXT. SURFACE OF THE DEATH STAR The Death Star trench zooms by. INT. Luke X-WING - COCKPIT Luke looks up, then starts to look back into the targeting device. He has second thoughts. BEN'S VOICE Let go, Luke. A grim determination sweeps across Luke face as he closes his eyes and starts to mumble Ben's training to himself. EXT. SURFACE OF THE DEATH STAR Luke fighter streaks through the trench. INT. DARTH VADER'S COCKPIT VADER The Force is strong with this one! EXT. SURFACE OF THE DEATH STAR Vader follows Luke X-wing down the trench. INT. Luke X-WING - COCKPIT Luke looks to the targeting device, then away as he hears Ben's voice. BEN'S VOICE Luke, trust me. Luke Hand reaches for the control panel and presses the button. The targeting device moves away. INT. MASSASSI OUTPOST - WAR ROOM Leia and the others stand watching the projected screen. BASE VOICE (over speaker) His computer's off. Luke, you switched off your targeting computer. What's wrong? LUKE (over speaker) Nothing. I'm all right. EXT. SURFACE OF THE DEATH STAR Luke ship streaks ever close to the exhaust port. INT. Luke X-WING - COCKPIT Luke looks at the Death Star surface streaking by. EXT. Luke X-WING FIGHTER Artoo-Detoo turns his head from side to side, beeping in anticipation. EXT. SURFACE OF THE DEATH STAR The three TIE fighters, manned by Vader and his two wingmen, follow Luke X-wing down the trench. INT. DARTH VADER'S COCKPIT Vader maneuvers his controls as he looks at his doomed target. He presses the fire buttons on his control sticks. Laserfire shoots toward Luke X-wing fighter. EXT. Luke X-WING FIGHTER A large burst of Vader's laserfire engulfs Artoo. The arms go limp on the smoking little droid as he makes a high-pitched sound. INT. Luke X-WING FIGHTER - COCKPIT Luke looks frantically back over his shoulder at Artoo. EXT. Luke X-WING FIGHTER Smoke billows out around little Artoo and sparks begin to fly. LUKE I've lost Artoo! Artoo's beeping sounds die out. INT. MASSASSI OUTPOST - WAR ROOM Leia and the others stare intently at the projected screen, while Threepio watches the Princess. Lights representing the Death Star and targets glow brightly. MASSASSI INTERCOM VOICE The Death Star has cleared the planet. The Death Star has cleared the planet. INT. DEATH STAR - CONTROL ROOM Tarkin glares at the projected target screen. DEATH STAR INTERCOM VOICE Rebel base, in range. TARKIN You may fire when ready. DEATH STAR INTERCOM VOICE Commence primary ignition. An officer reaches up and pushes buttons on the control panel, as green lighted buttons turn to red. EXT. SURFACE OF THE DEATH STAR The three TIE fighters zoom down the Death Star trench in pursuit of Luke, never breaking formation. INT. Luke COCKPIT Luke looks anxiously at the exhaust port. INT. DARTH VADER'S COCKPIT Vader adjusts his control sticks, checking his projected targeting screen. EXT. SURFACE OF THE DEATH STAR Luke ship barrels down the trench. INT. DARTH VADER'S COCKPIT Vader's targeting computer swings around into position. Vader takes careful aim on Luke X-wing fighter. VADER I have you now. He pushes the fire buttons. EXT. SURFACE OF THE DEATH STAR The three TIE fighters move in on Luke. As Vader's center fighter unleashes a volley of laserfire, one of the TIE ships at his side is hit and explodes into flame. The two remaining ships continue to move in. INT. Luke X-WING FIGHTER - COCKPIT Luke looks about, wondering whose laserfire destroyed Vader's wingman. INT. DARTH VADER'S COCKPIT Vader is taken by surprise, and looks out from his cockpit. VADER What? INT. DARTH VADER'S WINGMAN - COCKPIT Vader's wingman searches around him trying to locate the unknown attacker. INT. MILLENNIUM FALCON - COCKPIT Han and Chewbacca grin from ear to ear. Han (yelling) Yahoo! EXT. SPACE AROUND THE DEATH STAR The Millennium Falcon heads right at the two TIE fighters. It's a collision course. INT. WINGMAN'S COCKPIT The wingman spots the pirateship coming at him and warns the Dark Lord. WINGMAN Look out! EXT. DEATH STAR TRENCH Vader's wingman panics at the sight of the oncoming pirate starship and veers radically to one side, colliding with Vader's TIE fighter in the process. Vader's wingman crashes into the side wall of the trench and explodes. Vader's damaged ship spins out of the trench with a damaged wing. EXT. SPACE AROUND THE DEATH STAR Vader's ship spins out of control with a bent solar fin, heading for deep space. INT. DARTH VADER'S COCKPIT Vader turns round and round in circles as his ship spins into space. EXT. SURFACE OF THE DEATH STAR Solo's ship moves in toward the Death Star trench. INT. MILLENNIUM FALCON - COCKPIT Solo, smiling, speaks to Luke over his headset mike. Han (into mike) You're all clear, kid. INT. MASSASSI OUTPOST - WAR ROOM Leia and the others listen to Solo's transmission. Han (over speaker) Now let's blow this thing and go home! INT. Luke X-WING FIGHTER - COCKPIT Luke looks up and smiles. He concentrates on the exhaust port, then fires his laser torpedoes. EXT. SURFACE OF THE DEATH STAR Luke torpedoes shoot toward the port and seems to simply disappear into the surface and not explode. But the shots do find their mark and have gone into the exhaust port and are heading for the main reactor. INT. Luke X-WING FIGHTER - COCKPIT Luke throws his head back in relief. INT. DEATH STAR An Imperial soldier runs to the control panel board and pulls the attack lever as the board behind him lights up. INTERCOM VOICE Stand by to fire at Rebel base. EXT. SPACE AROUND THE DEATH STAR Two X-wings, a Y-wing, and the pirateship race toward Yavin in the distance. INT. DEATH STAR Several Imperial soldiers, flanking a pensive Grand Moff Tarkin, busily push control levers and buttons. INTERCOM VOICE Standing by. The rumble of a distant explosion begins. EXT. SPACE AROUND THE DEATH STAR The Rebel ships race out of sight, leaving the moon-like Death Star alone against a blanket of stars. Several small flashes appear on the surface. The Death Star bursts into a supernova, creating a spectacular heavenly display. INT. MILLENNIUM FALCON - COCKPIT Han Great shot, kid. That was one in a million. INT. Luke X-WING FIGHTER - COCKPIT Luke is at ease, and his eyes are closed. BEN'S VOICE Remember, the Force will be with you... always. The ship rocks back and forth. EXT. DARTH VADER'S TIE FIGHTER Vader's ship spins off into space. EXT. SPACE The Rebel ships race toward the fourth moon of Yavin. INT. MASSASSI OUTPOST - MAIN HanGAR Luke climbs out of his starship fighter and is cheered by a throng of ground crew and pilots. Luke climbs down the ladder as they all welcome him with laughter, cheers, and shouting. Princess Leia rushes toward him. LEIA Luke! Luke! Luke! She throws her arms around Luke and hugs him as they dance around in a circle. Solo runs in toward Luke and they embrace one another, slapping each other on the back. Han (laughing) Hey! Hey! LUKE (laughing) I knew you'd come back! I just knew it! Han Well, I wasn't gonna let you get all the credit and take all the reward. Luke and Han look at one another, as Solo playfully shoves at Luke face. Leia moves in between them. LEIA (laughing) Hey, I knew there was more to you tHan money. Luke looks toward the ship. LUKE Oh, no! The fried little Artoo-Detoo is lifted off the back of the fighter and carried off under the worried eyes of Threepio. THREEPIO Oh, my! Artoo! Can you hear me? Say something! (to mecHanic) You can repair him, can't you? TECHNICIAN We'll get to work on him right away. THREEPIO You must repair him! Sir, if any of my circuits or gears will help, I'll gladly donate them. LUKE He'll be all right. INT. MASSASSI OUTPOST - MAIN THRONE ROOM Luke, Han, and Chewbacca enter the huge ruins of the main temple. Hundreds of troops are lined up in neat rows. Banners are flying and at the far end stands a vision in white, the beautiful young Senator Leia. Luke and the others solemnly march up the long aisle and kneel before Senator Leia. From one side of the temple marches a shined-up and fully repaired Artoo-Detoo. He waddles up to the group and stands next to an equally pristine Threepio, who is rather awestruck by the whole event. Chewbacca is confused. Dodonna and several other dignitaries sit on the left of the Princess Leia. Leia is dressed in a long white dress and is staggeringly beautiful. She rises and places a gold medallion around Han's neck. He winks at her. She then repeats the ceremony with Luke, who is moved by the event. They turn and face the assembled troops, who all bow before them. Chewbacca growls and Artoo beeps with happiness. FADE OUT: END CREDITS OVER STARS THE END